@@ -50,7 +50,7 @@ if (isset($_POST['action']) && isset($_POST['id'])) {
     }
     $answer = [];
 
-    session_write_close();
+    Session::writeClose();
     switch ($_POST['action']) {
         case Agent::ACTION_INVENTORY:
             $answer = $agent->requestInventory();
