@@ -7,7 +7,7 @@
  *
  * http://glpi-project.org
  *
- * @copyright 2015-2022 Teclib' and contributors.
+ * @copyright 2015-2023 Teclib' and contributors.
  * @copyright 2003-2014 by the INDEPNET Development Team.
  * @licence   https://www.gnu.org/licenses/gpl-3.0.html
  *
@@ -37,6 +37,9 @@
  * @since 0.84
  */
 
+/** @var \DBmysql $DB */
+global $DB;
+
 $AJAX_INCLUDE = 1;
 
 include('../inc/includes.php');
@@ -46,7 +49,6 @@ Html::header_nocache();
 
 Session::checkRight("networking", UPDATE);
 
-/** @global DBmysql $DB */
 // Make a select box
 if (
     class_exists($_POST["itemtype"])
