@@ -37,6 +37,9 @@
  * @since 0.84
  */
 
+/** @var array $CFG_GLPI */
+global $CFG_GLPI;
+
 include('../inc/includes.php');
 
 header("Content-Type: text/html; charset=UTF-8");
@@ -44,8 +47,6 @@ Html::header_nocache();
 
 Session::checkRight("networking", UPDATE);
 
-/** @global array $CFG_GLPI */
-
 // Make a select box
 if (class_exists($_POST["itemtype"])) {
     $rand     = mt_rand();
