@@ -33,13 +33,14 @@
  * ---------------------------------------------------------------------
  */
 
+/** @var array $CFG_GLPI */
+global $CFG_GLPI;
+
 include('../inc/includes.php');
 
 header("Content-Type: text/html; charset=UTF-8");
 Html::header_nocache();
 
-/** @global array $CFG_GLPI */
-
 try {
     $ma = new MassiveAction($_POST, $_GET, 'specialize');
 } catch (\Throwable $e) {
