@@ -33,6 +33,9 @@
  * ---------------------------------------------------------------------
  */
 
+/** @var \DBmysql $DB */
+global $DB;
+
 if (strpos($_SERVER['PHP_SELF'], "dropdownTypeCertificates.php")) {
     $AJAX_INCLUDE = 1;
     include('../inc/includes.php');
@@ -46,8 +49,6 @@ Session::checkCentralAccess();
 // Make a select box
 $used = [];
 
-/** @global DBmysql $DB */
-
 // Clean used array
 if (
     isset($_POST['used'])
