@@ -33,18 +33,11 @@
  * ---------------------------------------------------------------------
  */
 
+$SECURITY_STRATEGY = 'faq_access';
+
 include('../inc/includes.php');
 Html::header_nocache();
 
-/** @global array $CFG_GLPI */
-
-if (
-    !$CFG_GLPI["use_public_faq"]
-    && !Session::haveRightsOr('knowbase', [KnowbaseItem::READFAQ, READ])
-) {
-    exit;
-}
-
 $_SESSION['kb_cat_id'] = $_REQUEST['cat_id'] ?? 0;
 
 switch ($_REQUEST['action']) {
