@@ -33,6 +33,9 @@
  * ---------------------------------------------------------------------
  */
 
+/** @var array $_UREQUEST */
+global $_UREQUEST;
+
 $AJAX_INCLUDE = 1;
 include('../inc/includes.php');
 
@@ -42,8 +45,6 @@ Html::header_nocache();
 
 Session::checkLoginUser();
 
-/** @global array $_UREQUEST */
-
 $mailcollector = new MailCollector();
 
 if (isset($_REQUEST['action'])) {
