@@ -39,6 +39,9 @@
 
 use Glpi\Toolbox\Sanitizer;
 
+/** @var array $CFG_GLPI */
+global $CFG_GLPI;
+
 include('../inc/includes.php');
 
 header("Content-Type: text/html; charset=UTF-8");
@@ -46,8 +49,6 @@ Html::header_nocache();
 
 Session::checkLoginUser();
 
-/** @global array $CFG_GLPI */
-
 try {
     $ma = new MassiveAction($_POST, $_GET, 'initial');
 } catch (\Throwable $e) {
