@@ -33,6 +33,9 @@
  * ---------------------------------------------------------------------
  */
 
+/** @var array $CFG_GLPI */
+global $CFG_GLPI;
+
 // Direct access to file
 if (strpos($_SERVER['PHP_SELF'], "ruleaction.php")) {
     include('../inc/includes.php');
@@ -44,8 +47,6 @@ if (strpos($_SERVER['PHP_SELF'], "ruleaction.php")) {
 
 Session::checkLoginUser();
 
-/** @global array $CFG_GLPI */
-
 // Non define case
 if (isset($_POST["sub_type"]) && class_exists($_POST["sub_type"])) {
     if (!isset($_POST["field"])) {
