@@ -37,6 +37,9 @@
  * @since 0.85
  */
 
+/** @var \DBmysql $DB */
+global $DB;
+
 include('../inc/includes.php');
 
 header("Content-Type: text/html; charset=UTF-8");
@@ -44,8 +47,6 @@ Html::header_nocache();
 
 Session::checkCentralAccess();
 
-/** @global DBmysql $DB */
-
 // Make a select box
 if (
     $_POST['items_id']
