@@ -33,14 +33,15 @@
  * ---------------------------------------------------------------------
  */
 
+/** @var array $CFG_GLPI */
+global $CFG_GLPI;
+
 include('../inc/includes.php');
 header("Content-Type: text/html; charset=UTF-8");
 Html::header_nocache();
 
 Session::checkRight("transfer", READ);
 
-/** @global array $CFG_GLPI */
-
 if (isset($_POST["id"]) && ($_POST["id"] > 0)) {
     $transfer = new Transfer();
     $transfer->showForm(
