@@ -7,7 +7,7 @@
  *
  * http://glpi-project.org
  *
- * @copyright 2015-2022 Teclib' and contributors.
+ * @copyright 2015-2023 Teclib' and contributors.
  * @copyright 2003-2014 by the INDEPNET Development Team.
  * @licence   https://www.gnu.org/licenses/gpl-3.0.html
  *
@@ -39,6 +39,9 @@
 
 use Glpi\Event;
 
+/** @var array $CFG_GLPI */
+global $CFG_GLPI;
+
 if (!defined('GLPI_ROOT')) {
     include('../inc/includes.php');
 }
@@ -46,7 +49,7 @@ if (!defined('GLPI_ROOT')) {
 $link = new Change_Group();
 $item = new Change();
 
-Session ::checkLoginUser();
+Session::checkLoginUser();
 
 if (isset($_POST['delete'])) {
     $link->check($_POST['id'], DELETE);
