@@ -39,6 +39,9 @@
 
 use Glpi\Event;
 
+/** @var array $CFG_GLPI */
+global $CFG_GLPI;
+
 if (!defined('GLPI_ROOT')) {
     include('../inc/includes.php');
 }
