@@ -40,6 +40,9 @@
 
 use Glpi\Event;
 
+/** @var \DBmysql $DB */
+global $DB;
+
 // autoload include in objecttask.form (tickettask, problemtask,...)
 if (!defined('GLPI_ROOT')) {
     die("Sorry. You can't access this file directly");
