@@ -33,14 +33,13 @@
  * ---------------------------------------------------------------------
  */
 
-/**
- * Filename was previously states.php
- * @since 0.84
- */
+use Glpi\Dashboard\Dashboard;
+
+/** @var array $CFG_GLPI */
+global $CFG_GLPI;
 
 include('../inc/includes.php');
 
-
 Session::checkCentralAccess();
 $default = Glpi\Dashboard\Grid::getDefaultDashboardForMenu('assets');
 
@@ -49,9 +48,15 @@ if ($default == "") {
     Html::redirect($CFG_GLPI["root_doc"] . "/front/computer.php");
 }
 
+$dashboard = new Dashboard($default);
+if (!$dashboard->canViewCurrent()) {
+    Html::displayRightError();
+    exit();
+}
+
 Html::header(__('Assets Dashboard'), $_SERVER['PHP_SELF'], "assets", "dashboard");
 
-$dashboard = new Glpi\Dashboard\Grid($default);
-$dashboard->showDefault();
+$grid = new Glpi\Dashboard\Grid($default);
+$grid->showDefault();
 
 Html::footer();
