@@ -35,6 +35,9 @@
 
 use Glpi\Dashboard\Dashboard;
 
+/** @var array $CFG_GLPI */
+global $CFG_GLPI;
+
 include('../inc/includes.php');
 
 
