@@ -7,7 +7,7 @@
  *
  * http://glpi-project.org
  *
- * @copyright 2015-2022 Teclib' and contributors.
+ * @copyright 2015-2023 Teclib' and contributors.
  * @copyright 2003-2014 by the INDEPNET Development Team.
  * @licence   https://www.gnu.org/licenses/gpl-3.0.html
  *
@@ -33,6 +33,11 @@
  * ---------------------------------------------------------------------
  */
 
+/** @var array $CFG_GLPI */
+global $CFG_GLPI;
+
+$SECURITY_STRATEGY = 'no_check'; // Anonymous access may be allowed by configuration.
+
 include('../inc/includes.php');
 
 if ((int)$CFG_GLPI['use_anonymous_helpdesk'] === 0) {
