@@ -39,6 +39,9 @@
 
 use Glpi\Event;
 
+/** @var array $CFG_GLPI */
+global $CFG_GLPI;
+
 include('../inc/includes.php');
 
 Session::checkRight("networking", READ);
