@@ -33,6 +33,9 @@
  * ---------------------------------------------------------------------
  */
 
+/** @var array $CFG_GLPI */
+global $CFG_GLPI;
+
 include('../inc/includes.php');
 
 Session::checkRight("reports", READ);
@@ -91,7 +94,17 @@ $valeurgraphtot      = [];
  **/
 function display_infocoms_report($itemtype, $begin, $end)
 {
-    global $DB, $valeurtot, $valeurnettetot, $valeurnettegraphtot, $valeurgraphtot, $CFG_GLPI, $stat, $chart_opts;
+    /**
+     * @var array $CFG_GLPI
+     * @var \DBmysql $DB
+     * @var int $valeurtot
+     * @var int $valeurnettetot
+     * @var array $valeurnettegraphtot
+     * @var array $valeurgraphtot
+     * @var \Stat $stat
+     * @var array $chart_opts
+     */
+    global $CFG_GLPI, $DB, $valeurtot, $valeurnettetot, $valeurnettegraphtot, $valeurgraphtot, $stat, $chart_opts;
 
     $itemtable = getTableForItemType($itemtype);
     if ($DB->fieldExists($itemtable, "ticket_tco", false)) { // those are in the std infocom report
