@@ -35,6 +35,9 @@
 
 use Glpi\Socket;
 
+/** @var array $CFG_GLPI */
+global $CFG_GLPI;
+
 include('../inc/includes.php');
 
 Session::checkRight("reports", READ);
