@@ -7,7 +7,7 @@
  *
  * http://glpi-project.org
  *
- * @copyright 2015-2022 Teclib' and contributors.
+ * @copyright 2015-2023 Teclib' and contributors.
  * @copyright 2003-2014 by the INDEPNET Development Team.
  * @licence   https://www.gnu.org/licenses/gpl-3.0.html
  *
@@ -49,6 +49,6 @@ if (!isset($_GET["id"])) {
 
 Report::title();
 
-State::showSummary($_SERVER['PHP_SELF']);
+State::showSummary();
 
 Html::footer();
