@@ -38,6 +38,12 @@ use Glpi\Stat\Data\Graph\StatDataSatisfactionSurvey;
 use Glpi\Stat\Data\Graph\StatDataTicketAverageTime;
 use Glpi\Stat\Data\Graph\StatDataTicketNumber;
 
+/**
+ * @var array $CFG_GLPI
+ * @var \DBmysql $DB
+ */
+global $CFG_GLPI, $DB;
+
 include('../inc/includes.php');
 
 Html::header(__('Statistics'), $_SERVER['PHP_SELF'], "helpdesk", "stat");
@@ -81,6 +87,10 @@ if (Session::haveRight('user', READ)) {
     $showuserlink = 1;
 }
 
+$val1   = null;
+$val2   = null;
+$values = [];
+
 switch ($_GET["type"]) {
     case "technicien":
         $val1    = $_GET["id"];
