@@ -35,6 +35,12 @@
 
 use Glpi\Event;
 
+/**
+ * @var array $CFG_GLPI
+ * @var \DBmysql $DB
+ */
+global $CFG_GLPI, $DB;
+
 include('../inc/includes.php');
 
 Session::checkLoginUser();
