@@ -847,6 +847,7 @@ $RELATION = [
         'glpi_budgets'                   => 'locations_id',
         'glpi_cartridgeitems'            => 'locations_id',
         'glpi_certificates'              => 'locations_id',
+        'glpi_changes'                   => 'locations_id',
         'glpi_computers'                 => 'locations_id',
         'glpi_contracts'                 => 'locations_id',
         'glpi_consumableitems'           => 'locations_id',
@@ -882,6 +883,7 @@ $RELATION = [
         'glpi_peripherals'               => 'locations_id',
         'glpi_phones'                    => 'locations_id',
         'glpi_printers'                  => 'locations_id',
+        'glpi_problems'                  => 'locations_id',
         'glpi_racks'                     => 'locations_id',
         'glpi_sockets'                   => 'locations_id',
         'glpi_softwarelicenses'          => 'locations_id',
@@ -1035,7 +1037,7 @@ $RELATION = [
     ],
 
     'glpi_operatingsystems' => [
-        '_glpi_items_operatingsystems' => 'operatingsystems_id',
+        'glpi_items_operatingsystems' => 'operatingsystems_id',
         'glpi_softwareversions'        => 'operatingsystems_id',
     ],
 
@@ -1624,6 +1626,7 @@ $define_mapping_entry = static function (string $source_table, string $target_ta
 };
 
 // Add polymorphic relations based on configuration.
+/** @var array $CFG_GLPI */
 global $CFG_GLPI;
 $specifically_managed_types = [
     Agent::class, // FIXME Agent should be a CommonDBChild with $mustBeAttached=true
