@@ -34,9 +34,7 @@
  */
 
 /**
- * @var DB $DB
- * @var Migration $migration
+ * @var \Migration $migration
  */
 
-
-$migration->addField('glpi_transfers', 'lock_updated_fields', "int", ['value' => '0']);
+$migration->addField('glpi_transfers', 'keep_location', "int", ['value' => '1']);
