@@ -33,23 +33,11 @@
  * ---------------------------------------------------------------------
  */
 
-/**
- * @var DB $DB
- * @var Migration $migration
- */
-$migration->addConfig(["entities_id_default" => 0], 'inventory');
+use Glpi\Inventory\Conf;
 
-$config = \Config::getConfigurationValues('inventory');
-if (isset($config['stale_agents_action']) && is_numeric($config['stale_agents_action'])) {
-    //convert stale_agents_action to an array
-    $DB->update(
-        'glpi_configs',
-        [
-            'value' => exportArrayToDB([$config['stale_agents_action']])
-        ],
-        [
-            'context' => 'inventory',
-            'name' => 'stale_agents_action'
-        ]
-    );
-}
+/**
+ * @var \Migration $migration
+ */
+
+//new right value for inventory
+$migration->updateRight('inventory', READ | Conf::IMPORTFROMFILE | Conf::UPDATECONFIG, ['config' => UPDATE, 'inventory' => READ]);
