@@ -34,12 +34,9 @@
  */
 
 /**
- * @var DB $DB
- * @var Migration $migration
+ * @var \Migration $migration
  */
 
-
-// Remove '' default values on glpi_impactcontexts.positions
-// MySQL does not allow default values on TEXT fields, while MariaDB does
-// Default was removed in installation file GLPI 9.5.4, see #8415
-$migration->changeField('glpi_impactcontexts', 'positions', 'positions', 'mediumtext NOT NULL');
+// This key may be missing from database on GLPI instances that were migrated to 10.0 version
+// prior to #9703 (so prior to 10.0.0-beta).
+$migration->addKey('glpi_refusedequipments', 'autoupdatesystems_id');
