@@ -33,5 +33,12 @@
  * ---------------------------------------------------------------------
  */
 
-// Drop unexpected `['0' => 'system_user']` config added by buggy 9.5.x -> 10.0.0 migration.
-Config::deleteConfigurationValues('core', ['0']);
+/**
+ * @var \Migration $migration
+ */
+
+$migration->displayMessage('Add new configurations / user preferences');
+$migration->addConfig([
+    'use_flat_dropdowntree_on_search_result'   => 1,
+]);
+$migration->addField('glpi_users', 'use_flat_dropdowntree_on_search_result', 'tinyint DEFAULT NULL');
