@@ -33,6 +33,12 @@
  * ---------------------------------------------------------------------
  */
 
+/**
+ * @var array $ADDTODISPLAYPREF
+ * @var \DBmysql $DB
+ * @var \Migration $migration
+ */
+
 if (!$DB->tableExists('glpi_appliances')) {
     $query = "CREATE TABLE `glpi_appliances` (
          `id` int NOT NULL auto_increment,
@@ -72,7 +78,7 @@ if (!$DB->tableExists('glpi_appliances')) {
          KEY `serial` (`serial`),
          KEY `otherserial` (`otherserial`)
       ) ENGINE=InnoDB  DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;";
-    $DB->queryOrDie($query, "9.5 add table glpi_appliances");
+    $DB->doQueryOrDie($query, "9.5 add table glpi_appliances");
 }
 
 if (!$DB->tableExists('glpi_appliances_items')) {
@@ -86,7 +92,7 @@ if (!$DB->tableExists('glpi_appliances_items')) {
          KEY `appliances_id` (`appliances_id`),
          KEY `item` (`itemtype`,`items_id`)
       ) ENGINE=InnoDB  DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;";
-    $DB->queryOrDie($query, "9.5 add table glpi_appliances_items");
+    $DB->doQueryOrDie($query, "9.5 add table glpi_appliances_items");
 }
 
 if (!$DB->tableExists('glpi_appliancetypes')) {
@@ -102,7 +108,7 @@ if (!$DB->tableExists('glpi_appliancetypes')) {
          KEY `entities_id` (`entities_id`),
          UNIQUE (`externalidentifier`)
       ) ENGINE=InnoDB  DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;";
-    $DB->queryOrDie($query, "9.5 add table glpi_appliancetypes");
+    $DB->doQueryOrDie($query, "9.5 add table glpi_appliancetypes");
 }
 
 if (!$DB->tableExists('glpi_applianceenvironments')) {
@@ -113,7 +119,7 @@ if (!$DB->tableExists('glpi_applianceenvironments')) {
          PRIMARY KEY (`id`),
          KEY `name` (`name`)
       ) ENGINE=InnoDB  DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;";
-    $DB->queryOrDie($query, "9.5 add table glpi_applianceenvironments");
+    $DB->doQueryOrDie($query, "9.5 add table glpi_applianceenvironments");
 }
 
 if (!$DB->tableExists('glpi_appliancerelations')) {
@@ -125,7 +131,7 @@ if (!$DB->tableExists('glpi_appliancerelations')) {
          KEY `appliances_items_id` (`appliances_items_id`),
          KEY `relations_id` (`relations_id`)
       ) ENGINE=InnoDB  DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;";
-    $DB->queryOrDie($query, "9.5 add table glpi_appliancerelations");
+    $DB->doQueryOrDie($query, "9.5 add table glpi_appliancerelations");
 }
 
 $migration->addRight('appliance', ALLSTANDARDRIGHT);
