@@ -36,8 +36,8 @@
 use Glpi\Socket;
 
 /**
- * @var DB $DB
- * @var Migration $migration
+ * @var \DBmysql $DB
+ * @var \Migration $migration
  */
 
 $default_charset = DBConnection::getDefaultCharset();
@@ -56,7 +56,7 @@ if (!$DB->tableExists('glpi_cabletypes')) {
       KEY `date_mod` (`date_mod`),
       KEY `date_creation` (`date_creation`)
     ) ENGINE=InnoDB DEFAULT CHARSET = {$default_charset} COLLATE = {$default_collation} ROW_FORMAT=DYNAMIC;";
-    $DB->queryOrDie($query, "10.0 add table glpi_cabletypes");
+    $DB->doQueryOrDie($query, "10.0 add table glpi_cabletypes");
 }
 
 if (!$DB->tableExists('glpi_cablestrands')) {
@@ -71,7 +71,7 @@ if (!$DB->tableExists('glpi_cablestrands')) {
       KEY `date_mod` (`date_mod`),
       KEY `date_creation` (`date_creation`)
     ) ENGINE=InnoDB DEFAULT CHARSET = {$default_charset} COLLATE = {$default_collation} ROW_FORMAT=DYNAMIC;";
-    $DB->queryOrDie($query, "10.0 add table glpi_cablestrands");
+    $DB->doQueryOrDie($query, "10.0 add table glpi_cablestrands");
 }
 
 if (!$DB->tableExists('glpi_socketmodels')) {
@@ -86,7 +86,7 @@ if (!$DB->tableExists('glpi_socketmodels')) {
       KEY `date_mod` (`date_mod`),
       KEY `date_creation` (`date_creation`)
     ) ENGINE=InnoDB DEFAULT CHARSET= {$default_charset} COLLATE = {$default_collation} ROW_FORMAT=DYNAMIC;";
-    $DB->queryOrDie($query, "10.0 add table glpi_socketmodels");
+    $DB->doQueryOrDie($query, "10.0 add table glpi_socketmodels");
 }
 
 if (!$DB->tableExists('glpi_cables')) {
@@ -131,7 +131,7 @@ if (!$DB->tableExists('glpi_cables')) {
       KEY `date_mod` (`date_mod`),
       KEY `date_creation` (`date_creation`)
     ) ENGINE=InnoDB DEFAULT CHARSET = {$default_charset} COLLATE = {$default_collation} ROW_FORMAT=DYNAMIC;";
-    $DB->queryOrDie($query, "10.0 add table glpi_cables");
+    $DB->doQueryOrDie($query, "10.0 add table glpi_cables");
 }
 $migration->addField('glpi_states', 'is_visible_cable', 'bool', [
     'value' => 1,
@@ -164,7 +164,7 @@ if (!$DB->tableExists('glpi_sockets')) {
       KEY `date_mod` (`date_mod`),
       KEY `date_creation` (`date_creation`)
     ) ENGINE=InnoDB DEFAULT CHARSET = {$default_charset} COLLATE = {$default_collation} ROW_FORMAT=DYNAMIC;";
-    $DB->queryOrDie($query, "10.0 add table glpi_sockets");
+    $DB->doQueryOrDie($query, "10.0 add table glpi_sockets");
 }
 
 if ($DB->tableExists('glpi_netpoints')) {
@@ -243,7 +243,7 @@ if (!$DB->tableExists('glpi_networkportfiberchanneltypes')) {
       KEY `date_mod` (`date_mod`),
       KEY `date_creation` (`date_creation`)
       ) ENGINE = InnoDB DEFAULT CHARSET = {$default_charset} COLLATE = {$default_collation} ROW_FORMAT=DYNAMIC;";
-    $DB->queryOrDie($query, "10.0 add table glpi_networkportfiberchanneltypes");
+    $DB->doQueryOrDie($query, "10.0 add table glpi_networkportfiberchanneltypes");
 }
 
 $migration->addField('glpi_networkportfiberchannels', 'networkportfiberchanneltypes_id', "int {$default_key_sign} NOT NULL DEFAULT '0'", ['after' => 'items_devicenetworkcards_id']);
