@@ -34,8 +34,7 @@
  */
 
 /**
- * @var DB $DB
- * @var Migration $migration
+ * @var \DBmysql $DB
  */
 
 $default_charset = DBConnection::getDefaultCharset();
@@ -57,5 +56,5 @@ if (!$DB->tableExists('glpi_projecttasklinks')) {
        KEY `projecttasks_id_source` (`projecttasks_id_source`),
        KEY `projecttasks_id_target` (`projecttasks_id_target`)
       ) ENGINE = InnoDB ROW_FORMAT = DYNAMIC DEFAULT CHARSET = {$default_charset} COLLATE = {$default_collation};";
-    $DB->queryOrDie($query, "Adding table glpi_projecttasklinks");
+    $DB->doQueryOrDie($query, "Adding table glpi_projecttasklinks");
 }
