@@ -34,8 +34,8 @@
  */
 
 /**
- * @var DB $DB
- * @var Migration $migration
+ * @var \DBmysql $DB
+ * @var \Migration $migration
  */
 
 $default_charset = DBConnection::getDefaultCharset();
@@ -61,7 +61,7 @@ if (!$DB->tableExists('glpi_pendingreasons')) {
          KEY `is_recursive` (`is_recursive`),
          KEY `solutiontemplates_id` (`solutiontemplates_id`)
       ) ENGINE = InnoDB ROW_FORMAT = DYNAMIC DEFAULT CHARSET = $default_charset COLLATE = $default_collation;";
-    $DB->queryOrDie($query, "10.0 add table glpi_pendingreasons");
+    $DB->doQueryOrDie($query, "10.0 add table glpi_pendingreasons");
 }
 
 // Add pending reason items table
@@ -80,7 +80,7 @@ if (!$DB->tableExists('glpi_pendingreasons_items')) {
          KEY `pendingreasons_id` (`pendingreasons_id`),
          KEY `item` (`itemtype`,`items_id`)
       ) ENGINE = InnoDB ROW_FORMAT = DYNAMIC DEFAULT CHARSET = $default_charset COLLATE = $default_collation;";
-    $DB->queryOrDie($query, "10.0 add table glpi_pendingreasons_items");
+    $DB->doQueryOrDie($query, "10.0 add table glpi_pendingreasons_items");
 }
 
 // Add pendingreason right
