@@ -69,6 +69,8 @@ class Agent extends CommonDBTM
 
     private static $found_address = false;
 
+    public $history_blacklist = ['last_contact'];
+
     public static function getTypeName($nb = 0)
     {
         return _n('Agent', 'Agents', $nb);
@@ -357,6 +359,7 @@ class Agent extends CommonDBTM
      */
     public function showForm($id, array $options = [])
     {
+        /** @var array $CFG_GLPI */
         global $CFG_GLPI;
 
         if (!empty($id)) {
@@ -388,6 +391,7 @@ class Agent extends CommonDBTM
      */
     public function handleAgent($metadata)
     {
+        /** @var array $CFG_GLPI */
         global $CFG_GLPI;
 
         $deviceid = $metadata['deviceid'];
@@ -504,6 +508,7 @@ class Agent extends CommonDBTM
 
     public function prepareInputForAdd($input)
     {
+        /** @var array $CFG_GLPI */
         global $CFG_GLPI;
 
         if (isset($CFG_GLPI['threads_networkdiscovery']) && !isset($input['threads_networkdiscovery'])) {
@@ -547,6 +552,7 @@ class Agent extends CommonDBTM
      */
     public function guessAddresses(): array
     {
+        /** @var \DBmysql $DB */
         global $DB;
 
         $addresses = [];
@@ -683,6 +689,7 @@ class Agent extends CommonDBTM
      */
     public function requestAgent($endpoint): Response
     {
+        /** @var array $CFG_GLPI */
         global $CFG_GLPI;
 
         if (self::$found_address !== false) {
@@ -821,6 +828,10 @@ class Agent extends CommonDBTM
      */
     public static function cronCleanoldagents($task = null)
     {
+        /**
+         * @var \DBmysql $DB
+         * @var array $PLUGIN_HOOKS
+         */
         global $DB, $PLUGIN_HOOKS;
 
         $config = \Config::getConfigurationValues('inventory');
