@@ -276,6 +276,7 @@ JAVASCRIPT;
         $orientation = 'vertical',
         $options = []
     ) {
+        /** @var array $CFG_GLPI */
         global $CFG_GLPI;
 
         if (count($tabs) === 0) {
@@ -357,7 +358,8 @@ JAVASCRIPT;
             echo  "</div>"; // .tab-content
             echo "</div>"; // .container-fluid
             $js = "
-         var loadTabContents = function (tablink, force_reload = false) {
+         var url_hash = window.location.hash;
+         var loadTabContents = function (tablink, force_reload = false, update_session_tab = true) {
             const href_url_params = new URLSearchParams($(tablink).prop('href'));
             var url = tablink.attr('href');
             var target = tablink.attr('data-bs-target');
@@ -371,7 +373,20 @@ JAVASCRIPT;
                      tab_key: href_url_params.get('_glpi_tab'),
                      withtemplate: " . (int)($_GET['withtemplate'] ?? 0) . "
                   }
-               );
+               ).done(function() {
+                    // try to restore the scroll on a specific anchor
+                    if (url_hash.length > 0) {
+                        // as we load content by ajax, when full page was ready, the anchor was not present
+                        // se we recall it to force the scroll.
+                        window.location.href = url_hash;
+
+                        // animate item with a flash
+                        $(url_hash).addClass('animate__animated animate__shakeX animate__slower');
+
+                        // unset hash (to avoid scrolling when changing tabs)
+                        url_hash   = '';
+                    }
+               });
             }
             if ($(target).html() && !force_reload) {
                 updateCurrentTab();
@@ -384,7 +399,9 @@ JAVASCRIPT;
 
                $(target).closest('main').trigger('glpi.tab.loaded');
 
-               updateCurrentTab();
+               if (update_session_tab) {
+                   updateCurrentTab();
+               }
             });
          };
 
@@ -401,13 +418,20 @@ JAVASCRIPT;
          };
 
          $(function() {
+            // Keep track of the first load which will be the tab stored in the
+            // session.
+            // In this case, it is useless to send a request to the
+            // updatecurrenttab endpoint as we already are on this tab
+            let first_load = true;
+
             $('a[data-bs-toggle=\"tab\"]').on('shown.bs.tab', function(e) {
                e.preventDefault();
-               loadTabContents($(this));
+               loadTabContents($(this), false, !first_load);
             });
 
             // load initial tab
             $('a[data-bs-target=\"#{$active_id}\"]').tab('show');
+            first_load = false;
 
             // select events in responsive mode
             $('#$tabdiv_id-select').on('change', function (e) {
