@@ -7,7 +7,7 @@
  *
  * http://glpi-project.org
  *
- * @copyright 2015-2022 Teclib' and contributors.
+ * @copyright 2015-2023 Teclib' and contributors.
  * @copyright 2003-2014 by the INDEPNET Development Team.
  * @licence   https://www.gnu.org/licenses/gpl-3.0.html
  *
@@ -157,6 +157,7 @@ class ErrorHandler
         static $instance = null;
 
         if ($instance === null) {
+            /** @var \Psr\Log\LoggerInterface $PHPLOGGER */
             global $PHPLOGGER;
             $instance = new self($PHPLOGGER);
         }
@@ -473,10 +474,19 @@ class ErrorHandler
             return;
         }
 
-        $this->logger->log(
-            $log_level,
-            '  *** ' . $type . ': ' . $description . (!empty($trace) ? "\n" . $trace : '')
-        );
+        try {
+            $this->logger->log(
+                $log_level,
+                '  *** ' . $type . ': ' . $description . (!empty($trace) ? "\n" . $trace : '')
+            );
+        } catch (\Throwable $e) {
+            $this->outputDebugMessage(
+                'Error',
+                'An error has occurred, but the trace of this error could not recorded because of a problem accessing the log file.',
+                LogLevel::CRITICAL,
+                true
+            );
+        }
     }
 
     /**
