@@ -64,6 +64,12 @@ class Auth extends CommonGLPI
      */
     public $user_found = false;
 
+    /**
+     * Indicated if an error occurs during connection to the user LDAP.
+     * @var boolean
+     */
+    public $user_ldap_error = false;
+
     /** @var resource|boolean LDAP connection descriptor */
     public $ldap_connection;
     /** @var bool Store user LDAP dn */
@@ -140,6 +146,7 @@ class Auth extends CommonGLPI
      */
     public function userExists($options = [])
     {
+        /** @var \DBmysql $DB */
         global $DB;
 
         $result = $DB->request(
@@ -227,20 +234,23 @@ class Auth extends CommonGLPI
     }
 
     /**
-     * Find a user in a LDAP and return is BaseDN
+     * Find a user in LDAP
      * Based on GRR auth system
      *
-     * @param string $ldap_method ldap_method array to use
-     * @param string $login       User Login
-     * @param string $password    User Password
+     * @param string    $ldap_method ldap_method array to use
+     * @param string    $login       User Login
+     * @param string    $password    User Password
+     * @param bool|null $error       Boolean flag that will be set to `true` if a LDAP error occurs during connection
      *
-     * @return string basedn of the user / false if not founded
+     * @return false|array
      */
-    public function connection_ldap($ldap_method, $login, $password)
+    public function connection_ldap($ldap_method, $login, $password, ?bool &$error = null)
     {
+        $error = false;
 
        // we prevent some delay...
         if (empty($ldap_method['host'])) {
+            $error = true;
             return false;
         }
 
@@ -258,7 +268,7 @@ class Auth extends CommonGLPI
                 $params['fields']['sync_field'] = $ldap_method['sync_field'];
             }
             try {
-                $infos = AuthLDAP::searchUserDn($this->ldap_connection, [
+                $info = AuthLDAP::searchUserDn($this->ldap_connection, [
                     'basedn'            => $ldap_method['basedn'],
                     'login_field'       => $ldap_method['login_field'],
                     'search_parameters' => $params,
@@ -271,19 +281,30 @@ class Auth extends CommonGLPI
                 ]);
             } catch (\Throwable $e) {
                 ErrorHandler::getInstance()->handleException($e, true);
-                $this->addToError(__('Unable to connect to the LDAP directory'));
+                $info = false;
+            }
+
+            $ldap_errno = ldap_errno($this->ldap_connection);
+            if ($info === false) {
+                if ($ldap_errno > 0 && $ldap_errno !== 32) {
+                    $this->addToError(__('Unable to connect to the LDAP directory'));
+                    $error = true;
+                } else {
+                    // 32 = LDAP_NO_SUCH_OBJECT => This should not be considered as a connection error, as it just means that user was not found.
+                    $this->addToError(__('Incorrect username or password'));
+                }
                 return false;
             }
 
-            $dn = $infos['dn'];
+            $dn = $info['dn'];
             $this->user_found = $dn != '';
 
             $bind_result = $this->user_found ? @ldap_bind($this->ldap_connection, $dn, $password) : false;
 
             if ($this->user_found && $bind_result !== false) {
                 //Hook to implement to restrict access by checking the ldap directory
-                if (Plugin::doHookFunction(Hooks::RESTRICT_LDAP_AUTH, $infos)) {
-                    return $infos;
+                if (Plugin::doHookFunction(Hooks::RESTRICT_LDAP_AUTH, $info)) {
+                    return $info;
                 }
                 $this->addToError(__('User not authorized to connect in GLPI'));
                 //Use is present by has no right to connect because of a plugin
@@ -295,8 +316,9 @@ class Auth extends CommonGLPI
                 return false;
             }
         } else {
-            $this->addToError(__('Unable to connect to the LDAP directory'));
             //Directory is not available
+            $this->addToError(__('Unable to connect to the LDAP directory'));
+            $error = true;
             return false;
         }
     }
@@ -377,6 +399,10 @@ class Auth extends CommonGLPI
      */
     public function connection_db($name, $password)
     {
+        /**
+         * @var array $CFG_GLPI
+         * @var \DBmysql $DB
+         */
         global $CFG_GLPI, $DB;
 
         $pass_expiration_delay = (int)$CFG_GLPI['password_expiration_delay'];
@@ -490,6 +516,7 @@ class Auth extends CommonGLPI
      */
     public function getAlternateAuthSystemsUserLogin($authtype = 0)
     {
+        /** @var array $CFG_GLPI */
         global $CFG_GLPI;
 
         switch ($authtype) {
@@ -499,8 +526,14 @@ class Auth extends CommonGLPI
                     return false;
                 }
 
-                if (version_compare(phpCAS::getVersion(), '1.6.0', '<')) {
-                    // Prior to version 1.6.0, 5th argument was `$changeSessionID`.
+                // Adapt phpCAS::client() signature.
+                // A new signature has been introduced in 1.6.0 version of the official package.
+                // This new signature has been backported in the `1.3.6-1` version of the debian package,
+                // so we have to check for method argument names too.
+                $has_service_base_url_arg = version_compare(phpCAS::getVersion(), '1.6.0', '>=')
+                    || ((new ReflectionMethod(phpCAS::class, 'client'))->getParameters()[4]->getName() ?? null) === 'service_base_url';
+                if (!$has_service_base_url_arg) {
+                    // Prior to version 1.6.0, `$service_base_url` argument was not present, and 5th argument was `$changeSessionID`.
                     phpCAS::client(
                         constant($CFG_GLPI["cas_version"]),
                         $CFG_GLPI["cas_host"],
@@ -509,7 +542,8 @@ class Auth extends CommonGLPI
                         false
                     );
                 } else {
-                    // Starting from version 1.6.0, 5th argument is `$service_base_url`.
+                    // Starting from version 1.6.0, `$service_base_url` argument was added at 5th position, and `$changeSessionID`
+                    // was moved at 6th position.
                     phpCAS::client(
                         constant($CFG_GLPI["cas_version"]),
                         $CFG_GLPI["cas_host"],
@@ -738,7 +772,11 @@ class Auth extends CommonGLPI
      */
     public function login($login_name, $login_password, $noauto = false, $remember_me = false, $login_auth = '')
     {
-        global $DB, $CFG_GLPI;
+        /**
+         * @var array $CFG_GLPI
+         * @var \DBmysql $DB
+         */
+        global $CFG_GLPI, $DB;
 
         $this->getAuthMethods();
         $this->user_present  = 1;
@@ -927,7 +965,8 @@ class Auth extends CommonGLPI
                                 $login_password,
                                 $this->user->fields["auths_id"]
                             );
-                            if ($this->ldap_connection !== false && (!$this->auth_succeded && !$this->user_found)) {
+                            if ($this->user_ldap_error === false && !$this->auth_succeded && !$this->user_found) {
+                                 // Mark user as deleted, unless an error occured during connection to user LDAP server.
                                  $search_params = [
                                      'name'     => addslashes($login_name),
                                      'authtype' => $this::LDAP
@@ -1087,6 +1126,7 @@ class Auth extends CommonGLPI
      */
     public static function dropdown($options = [])
     {
+        /** @var \DBmysql $DB */
         global $DB;
 
         $p = [
@@ -1283,6 +1323,7 @@ class Auth extends CommonGLPI
     public static function useAuthExt()
     {
 
+        /** @var array $CFG_GLPI */
         global $CFG_GLPI;
 
        //Get all the ldap directories
@@ -1335,10 +1376,11 @@ class Auth extends CommonGLPI
      *                                (false by default)
      * @param string  $redirect_string redirect string if exists (default '')
      *
-     * @return void|integer nothing if redirect is true, else Auth system ID
+     * @return false|integer nothing if redirect is true, else Auth system ID
      */
     public static function checkAlternateAuthSystems($redirect = false, $redirect_string = '')
     {
+        /** @var array $CFG_GLPI */
         global $CFG_GLPI;
 
         if (isset($_GET["noAUTO"]) || isset($_POST["noAUTO"])) {
@@ -1366,8 +1408,7 @@ class Auth extends CommonGLPI
         $ssovariable = Dropdown::getDropdownName('glpi_ssovariables', $CFG_GLPI["ssovariables_id"]);
         if (
             $CFG_GLPI["ssovariables_id"]
-            && ((isset($_SERVER[$ssovariable]) && !empty($_SERVER[$ssovariable]))
-              /*|| (isset($_REQUEST[$ssovariable]) && !empty($_REQUEST[$ssovariable]))*/)
+            && !empty($_SERVER[$ssovariable])
         ) {
             if ($redirect) {
                 Html::redirect($CFG_GLPI["root_doc"] . "/front/login.php" . $redir_string);
@@ -1411,6 +1452,7 @@ class Auth extends CommonGLPI
      */
     public static function redirectIfAuthenticated($redirect = null)
     {
+        /** @var array $CFG_GLPI */
         global $CFG_GLPI;
 
         if (!Session::getLoginUserID()) {
@@ -1458,7 +1500,11 @@ class Auth extends CommonGLPI
      */
     public static function showSynchronizationForm(User $user)
     {
-        global $DB, $CFG_GLPI;
+        /**
+         * @var array $CFG_GLPI
+         * @var \DBmysql $DB
+         */
+        global $CFG_GLPI, $DB;
 
         if (Session::haveRight("user", User::UPDATEAUTHENT)) {
             echo "<form method='post' action='" . Toolbox::getItemTypeFormURL('User') . "'>";
@@ -1483,7 +1529,7 @@ class Auth extends CommonGLPI
                             'name' => 'force_ldap_resynch'
                         ]);
 
-                        if (strlen($authldap->fields['sync_field']) > 0) {
+                        if (strlen($authldap->fields['sync_field'] ?? "") > 0) {
                             echo Html::submit("<i class='fas fa-broom'></i><span>" . __s('Clean LDAP fields and force synchronisation') . "</span>", [
                                 'name' => 'clean_ldap_fields'
                             ]);
@@ -1525,7 +1571,10 @@ class Auth extends CommonGLPI
      */
     public static function isValidLogin($login)
     {
-        return $login !== null && preg_match("/^[[:alnum:]'@.\-_ ]+$/iu", $login);
+        return $login !== null && (
+            preg_match("/^[[:alnum:]'@.\-_ ]+$/iu", $login)
+            || filter_var($login, FILTER_VALIDATE_EMAIL) != false
+        );
     }
 
     public function getTabNameForItem(CommonGLPI $item, $withtemplate = 0)
@@ -1570,6 +1619,7 @@ class Auth extends CommonGLPI
      */
     public static function showOtherAuthList()
     {
+        /** @var array $CFG_GLPI */
         global $CFG_GLPI;
 
         if (!Config::canUpdate()) {
@@ -1776,6 +1826,7 @@ class Auth extends CommonGLPI
      */
     public static function getLoginAuthMethods()
     {
+        /** @var \DBmysql $DB */
         global $DB;
 
         $elements = [
@@ -1855,6 +1906,7 @@ class Auth extends CommonGLPI
      */
     public static function setRememberMeCookie(string $cookie_value): void
     {
+        /** @var array $CFG_GLPI */
         global $CFG_GLPI;
 
         $cookie_name     = session_name() . '_rememberme';
