@@ -133,7 +133,7 @@ class Cartridge extends CommonDBRelation
     }
 
 
-    public function post_updateItem($history = 1)
+    public function post_updateItem($history = true)
     {
 
         if (in_array('pages', $this->updates)) {
@@ -239,8 +239,9 @@ class Cartridge extends CommonDBRelation
      * @param integer $history
      * @return bool
      */
-    public function backToStock(array $input, $history = 1)
+    public function backToStock(array $input, $history = true)
     {
+        /** @var \DBmysql $DB */
         global $DB;
 
         $result = $DB->update(
@@ -275,6 +276,7 @@ class Cartridge extends CommonDBRelation
      **/
     public function install($pID, $tID)
     {
+        /** @var \DBmysql $DB */
         global $DB;
 
        // Get first unused cartridge
@@ -328,6 +330,7 @@ class Cartridge extends CommonDBRelation
      **/
     public function uninstall($ID)
     {
+        /** @var \DBmysql $DB */
         global $DB;
 
         if ($this->getFromDB($ID)) {
@@ -486,6 +489,7 @@ class Cartridge extends CommonDBRelation
      **/
     public static function getTotalNumber($tID)
     {
+        /** @var \DBmysql $DB */
         global $DB;
 
         $row = $DB->request([
@@ -508,6 +512,7 @@ class Cartridge extends CommonDBRelation
      **/
     public static function getTotalNumberForPrinter($pID)
     {
+        /** @var \DBmysql $DB */
         global $DB;
 
         $row = $DB->request([
@@ -528,6 +533,7 @@ class Cartridge extends CommonDBRelation
      **/
     public static function getUsedNumber($tID)
     {
+        /** @var \DBmysql $DB */
         global $DB;
 
         $row = $DB->request([
@@ -557,6 +563,7 @@ class Cartridge extends CommonDBRelation
      **/
     public static function getUsedNumberForPrinter($pID)
     {
+        /** @var \DBmysql $DB */
         global $DB;
 
         $result = $DB->request([
@@ -581,6 +588,7 @@ class Cartridge extends CommonDBRelation
      **/
     public static function getOldNumber($tID)
     {
+        /** @var \DBmysql $DB */
         global $DB;
 
         $result = $DB->request([
@@ -606,6 +614,7 @@ class Cartridge extends CommonDBRelation
      **/
     public static function getOldNumberForPrinter($pID)
     {
+        /** @var \DBmysql $DB */
         global $DB;
 
         $result = $DB->request([
@@ -629,6 +638,7 @@ class Cartridge extends CommonDBRelation
      **/
     public static function getUnusedNumber($tID)
     {
+        /** @var \DBmysql $DB */
         global $DB;
 
         $result = $DB->request([
@@ -651,6 +661,7 @@ class Cartridge extends CommonDBRelation
      */
     public static function getStockTarget(int $tID): int
     {
+        /** @var \DBmysql $DB */
         global $DB;
 
         $it = $DB->request([
@@ -674,6 +685,7 @@ class Cartridge extends CommonDBRelation
      */
     public static function getAlarmThreshold(int $tID): int
     {
+        /** @var \DBmysql $DB */
         global $DB;
 
         $it = $DB->request([
@@ -720,6 +732,7 @@ class Cartridge extends CommonDBRelation
      **/
     public static function showForCartridgeItem(CartridgeItem $cartitem, $show_old = 0)
     {
+        /** @var \DBmysql $DB */
         global $DB;
 
         $tID = $cartitem->getField('id');
@@ -974,7 +987,11 @@ class Cartridge extends CommonDBRelation
      **/
     public static function showForPrinter(Printer $printer, $old = 0)
     {
-        global $DB, $CFG_GLPI;
+        /**
+         * @var array $CFG_GLPI
+         * @var \DBmysql $DB
+         */
+        global $CFG_GLPI, $DB;
 
         $instID = $printer->getField('id');
         if (!self::canView()) {
@@ -1302,7 +1319,11 @@ class Cartridge extends CommonDBRelation
      */
     public static function getNotificationParameters($entity = 0)
     {
-        global $DB, $CFG_GLPI;
+        /**
+         * @var array $CFG_GLPI
+         * @var \DBmysql $DB
+         */
+        global $CFG_GLPI, $DB;
 
        //Look for parameters for this entity
         $iterator = $DB->request([
