@@ -36,7 +36,9 @@
 use Glpi\Application\View\TemplateRenderer;
 use Glpi\Event;
 use Glpi\Plugin\Hooks;
+use Glpi\System\Requirement\PhpSupportedVersion;
 use Glpi\System\Requirement\SafeDocumentRoot;
+use Glpi\System\Requirement\SessionsSecurityConfiguration;
 
 /**
  * Central class
@@ -445,7 +447,11 @@ class Central extends CommonGLPI
 
     private static function getMessages(): array
     {
-        global $DB, $CFG_GLPI;
+        /**
+         * @var array $CFG_GLPI
+         * @var \DBmysql $DB
+         */
+        global $CFG_GLPI, $DB;
 
         $messages = [];
 
@@ -515,11 +521,17 @@ class Central extends CommonGLPI
                 . ' '
                 . sprintf(__('Run the "%1$s" command to migrate them.'), 'php bin/console migration:unsigned_keys');
             }
-        }
 
-        $safe_doc_root_requirement = new SafeDocumentRoot();
-        if (!$safe_doc_root_requirement->isValidated()) {
-            $messages['warnings'] = array_merge(($messages['warnings'] ?? []), $safe_doc_root_requirement->getValidationMessages());
+            $security_requirements = [
+                new PhpSupportedVersion(),
+                new SafeDocumentRoot(),
+                new SessionsSecurityConfiguration(),
+            ];
+            foreach ($security_requirements as $requirement) {
+                if (!$requirement->isValidated()) {
+                    $messages['warnings'] = array_merge(($messages['warnings'] ?? []), $requirement->getValidationMessages());
+                }
+            }
         }
 
         if ($DB->isSlave() && !$DB->first_connection) {
