@@ -550,7 +550,7 @@ abstract class CommonDBChild extends CommonDBConnexity
      *
      * @return void
      **/
-    public function post_updateItem($history = 1)
+    public function post_updateItem($history = true)
     {
 
         if (
@@ -791,7 +791,7 @@ abstract class CommonDBChild extends CommonDBConnexity
      * @param string  $field_name  the name of the HTML field inside Item's form
      * @param integer $id          id of the child
      *
-     * @return void
+     * @return string|void
      **/
     public function showChildForItemForm($canedit, $field_name, $id, bool $display = true)
     {
@@ -832,7 +832,7 @@ abstract class CommonDBChild extends CommonDBConnexity
      * @param boolean      $display     true display or false to return the button HTML code
      *
      *
-     * @return void|string the button HTML code if $display is true, void otherwise
+     * @return void|false|string the button HTML code if $display is true, void otherwise
      **/
     public static function showAddChildButtonForItemForm(
         CommonDBTM $item,
@@ -901,6 +901,7 @@ abstract class CommonDBChild extends CommonDBConnexity
      **/
     public static function showChildsForItemForm(CommonDBTM $item, $field_name, $canedit = null, bool $display = true)
     {
+        /** @var \DBmysql $DB */
         global $DB;
 
         $items_id = $item->getID();
@@ -923,11 +924,6 @@ abstract class CommonDBChild extends CommonDBConnexity
         $lower_name = strtolower(get_called_class());
         $div_id     = "add_" . $lower_name . "_to_" . $item->getType() . "_" . $items_id;
 
-       // To be sure not to load bad datas from this table
-        if ($items_id == 0) {
-            $items_id = -99;
-        }
-
         $query = [
             'FROM'   => static::getTable(),
             'WHERE'  => [
