@@ -65,6 +65,7 @@ abstract class CommonDevice extends CommonDropdown
      **/
     public static function getDeviceTypes()
     {
+        /** @var array $CFG_GLPI */
         global $CFG_GLPI;
 
         return $CFG_GLPI['device_types'];
@@ -73,15 +74,15 @@ abstract class CommonDevice extends CommonDropdown
 
 
     /**
-     * Get the assiociated item_device associated with this device
-     * This method can be override, for instance by the plugin
+     * Get the associated item_device associated with this device
+     * This method can be overridden, for instance by the plugin
      *
      * @since 0.85
      * @since 9.3 added the $devicetype parameter
      *
      * @param string $devicetype class name of device type, defaults to called class name
      *
-     * @return array of the types of CommonDevice available
+     * @return string
      **/
     public static function getItem_DeviceType($devicetype = null)
     {
@@ -193,6 +194,7 @@ abstract class CommonDevice extends CommonDropdown
      **/
     public function canUnrecurs()
     {
+        /** @var \DBmysql $DB */
         global $DB;
 
         $ID = $this->fields['id'];
@@ -470,6 +472,7 @@ abstract class CommonDevice extends CommonDropdown
      **/
     public function import(array $input)
     {
+        /** @var \DBmysql $DB */
         global $DB;
 
         $with_history = $input['with_history'] ?? true;
@@ -605,7 +608,7 @@ abstract class CommonDevice extends CommonDropdown
      * @since 0.85
      * @see CommonDBTM::post_updateItem()
      **/
-    public function post_updateItem($history = 1)
+    public function post_updateItem($history = true)
     {
 
         $this->post_workOnItem();
@@ -614,6 +617,7 @@ abstract class CommonDevice extends CommonDropdown
 
     public static function getFormURL($full = true)
     {
+        /** @var array $CFG_GLPI */
         global $CFG_GLPI;
 
         $dir = ($full ? $CFG_GLPI['root_doc'] : '');
@@ -625,6 +629,7 @@ abstract class CommonDevice extends CommonDropdown
 
     public static function getSearchURL($full = true)
     {
+        /** @var array $CFG_GLPI */
         global $CFG_GLPI;
 
         $dir = ($full ? $CFG_GLPI['root_doc'] : '');
