@@ -7,7 +7,7 @@
  *
  * http://glpi-project.org
  *
- * @copyright 2015-2022 Teclib' and contributors.
+ * @copyright 2015-2023 Teclib' and contributors.
  * @copyright 2003-2014 by the INDEPNET Development Team.
  * @licence   https://www.gnu.org/licenses/gpl-3.0.html
  *
@@ -199,6 +199,7 @@ abstract class CommonITILCost extends CommonDBChild
 
     public static function rawSearchOptionsToAdd()
     {
+        /** @var \DBmysql $DB */
         global $DB;
 
         $tab = [];
@@ -354,6 +355,7 @@ abstract class CommonITILCost extends CommonDBChild
      **/
     public function getTotalActionTimeForItem($items_id)
     {
+        /** @var \DBmysql $DB */
         global $DB;
 
         $result = $DB->request([
@@ -372,6 +374,7 @@ abstract class CommonITILCost extends CommonDBChild
      **/
     public function getLastCostForItem($items_id)
     {
+        /** @var \DBmysql $DB */
         global $DB;
 
         $result = $DB->request([
@@ -396,16 +399,17 @@ abstract class CommonITILCost extends CommonDBChild
      **/
     public function showForm($ID, array $options = [])
     {
-
-        if (isset($options['parent']) && !empty($options['parent'])) {
-            $item = $options['parent'];
+        if (!($ID > 0) && !isset($options['parent']) || !($options['parent'] instanceof CommonDBTM)) {
+            // parent is mandatory in new item form
+            trigger_error('Parent item must be defined in `$options["parent"]`.', E_USER_WARNING);
+            return false;
         }
 
         if ($ID > 0) {
             $this->check($ID, READ);
         } else {
            // Create item
-            $options[static::$items_id] = $item->getField('id');
+            $options[static::$items_id] = $options['parent']->fields["id"];
             $this->check(-1, CREATE, $options);
             $this->initBasedOnPrevious();
         }
@@ -439,7 +443,10 @@ abstract class CommonITILCost extends CommonDBChild
         echo "<td>" . __('Duration') . "</td>";
         echo "<td>";
         Dropdown::showTimeStamp('actiontime', ['value'           => $this->fields['actiontime'],
-            'addfirstminutes' => true
+            'addfirstminutes'      => true,
+            'min'                  => DAY_TIMESTAMP,
+            'max'                  => DAY_TIMESTAMP * 50,
+            'step'                 => DAY_TIMESTAMP,
         ]);
         echo "</td>";
         echo "<td>" . __('End date') . "</td>";
@@ -493,11 +500,15 @@ abstract class CommonITILCost extends CommonDBChild
      * @param $item                  CommonITILObject object or Project
      * @param $withtemplate boolean  Template or basic item (default 0)
      *
-     * @return number total cost
+     * @return false|integer total cost
      **/
     public static function showForObject($item, $withtemplate = 0)
     {
-        global $DB, $CFG_GLPI;
+        /**
+         * @var array $CFG_GLPI
+         * @var \DBmysql $DB
+         */
+        global $CFG_GLPI, $DB;
 
         $forproject = false;
         if (is_a($item, 'Project', true)) {
@@ -699,6 +710,7 @@ abstract class CommonITILCost extends CommonDBChild
      **/
     public static function getCostsSummary($type, $ID)
     {
+        /** @var \DBmysql $DB */
         global $DB;
 
         $result = $DB->request(
