@@ -383,7 +383,7 @@ abstract class CommonITILRecurrent extends CommonDropdown
         ?int $create_before,
         ?int $calendars_id
     ): string {
-        $now = time();
+        $now = strtotime(Session::getCurrentTime());
         $periodicity_pattern = '/([0-9]+)(MONTH|YEAR)/';
 
         if ($begin_date === null || DateTime::createFromFormat('Y-m-d H:i:s', $begin_date) === false) {
@@ -411,7 +411,7 @@ abstract class CommonITILRecurrent extends CommonDropdown
         $matches = [];
         if (preg_match($periodicity_pattern, $periodicity, $matches)) {
             $periodicity_as_interval = "{$matches[1]} {$matches[2]}";
-            $periodicity_in_seconds  = $matches[1]
+            $periodicity_in_seconds  = (int)$matches[1]
             * MONTH_TIMESTAMP
             * ('YEAR' === $matches[2] ? 12 : 1);
         } else if ($periodicity % DAY_TIMESTAMP == 0) {
@@ -462,10 +462,28 @@ abstract class CommonITILRecurrent extends CommonDropdown
                 }
                // Jump to next working hour if occurence is outside working hours.
                 if (!$calendar->isAWorkingHour($occurence_time)) {
-                    $occurence_date = $calendar->computeEndDate(
-                        date('Y-m-d', $occurence_time),
-                        0 // 0 second delay to get the first working "second"
-                    );
+                    $tmp_search_time = null;
+
+                    // Find the first calendar segment that is after the current date
+                    do {
+                        if ($tmp_search_time === null) {
+                            // On the first iteration, we work with the start of the day
+                            $tmp_search_time = date('Y-m-d', $occurence_time);
+                        } else {
+                            // If we iterate a second time, this mean the date returned was too early
+                            // We will add the periodicity once again to try to get a valid date
+                            $tmp_search_time = date(
+                                'Y-m-d H:i:s',
+                                strtotime("+ $periodicity_as_interval", strtotime($occurence_date))
+                            );
+                        }
+
+                        $occurence_date = $calendar->computeEndDate(
+                            $tmp_search_time,
+                            0 // 0 second delay to get the first working "second"
+                        );
+                    } while ($occurence_date < date('Y-m-d H:i:s', $now));
+
                     $occurence_time = strtotime($occurence_date);
                 }
                 $creation_time  = $occurence_time - $create_before;
@@ -553,9 +571,11 @@ abstract class CommonITILRecurrent extends CommonDropdown
     /**
      * Create an item based on the specified template
      *
+     * @param CommonITILObject|null $created_item   Will contain the created item instance
+     *
      * @return boolean
      */
-    public function createItem()
+    public function createItem(?CommonITILObject &$created_item = null)
     {
         $result = false;
         $concrete_class = static::getConcreteClass();
@@ -577,6 +597,10 @@ abstract class CommonITILRecurrent extends CommonDropdown
             $predefined = $fields->getPredefinedFields($this->fields[$tmpl_fk], true);
             $input = $this->handlePredefinedFields($predefined, $input);
 
+            if (array_key_exists('status', $predefined)) {
+                $input['_do_not_compute_status'] = true;
+            }
+
            // Set entity
             $input['entities_id'] = $this->fields['entities_id'];
             $input['_auto_import'] = true;
@@ -586,6 +610,7 @@ abstract class CommonITILRecurrent extends CommonDropdown
             $input  = Toolbox::addslashes_deep($input);
 
             if ($items_id = $item->add($input)) {
+                $created_item = $item;
                 $msg = sprintf(
                     __('%s %d successfully created'),
                     $concrete_class::getTypeName(1),
