@@ -196,6 +196,7 @@ abstract class CommonITILValidation extends CommonDBChild
      **/
     public static function canValidate($items_id)
     {
+        /** @var \DBmysql $DB */
         global $DB;
 
         $iterator = $DB->request([
@@ -218,7 +219,7 @@ abstract class CommonITILValidation extends CommonDBChild
 
     public function getTabNameForItem(CommonGLPI $item, $withtemplate = 0)
     {
-
+        /** @var CommonDBTM $item */
         $hidetab = false;
        // Hide if no rights on validations
         if (!static::canView()) {
@@ -295,6 +296,7 @@ abstract class CommonITILValidation extends CommonDBChild
 
     public function post_addItem()
     {
+        /** @var array $CFG_GLPI */
         global $CFG_GLPI;
 
         // Handle rich-text images
@@ -411,8 +413,9 @@ abstract class CommonITILValidation extends CommonDBChild
     }
 
 
-    public function post_updateItem($history = 1)
+    public function post_updateItem($history = true)
     {
+        /** @var array $CFG_GLPI */
         global $CFG_GLPI;
 
         $item    = new static::$itemtype();
@@ -480,7 +483,7 @@ abstract class CommonITILValidation extends CommonDBChild
      **/
     public function getHistoryChangeWhenUpdateField($field)
     {
-
+        $result = [];
         if ($field == 'status') {
             $username = getUserName($this->fields["users_id_validate"]);
 
@@ -492,9 +495,8 @@ abstract class CommonITILValidation extends CommonDBChild
                //TRANS: %s is the username
                 $result[2] = sprintf(__('Update the approval request to %s'), $username);
             }
-            return $result;
         }
-        return false;
+        return $result;
     }
 
 
@@ -660,6 +662,7 @@ abstract class CommonITILValidation extends CommonDBChild
      **/
     public static function getNumberToValidate($users_id)
     {
+        /** @var \DBmysql $DB */
         global $DB;
 
         $row = $DB->request([
@@ -683,6 +686,7 @@ abstract class CommonITILValidation extends CommonDBChild
      **/
     public static function getTicketStatusNumber($items_id, $status)
     {
+        /** @var \DBmysql $DB */
         global $DB;
 
         $row = $DB->request([
@@ -710,6 +714,7 @@ abstract class CommonITILValidation extends CommonDBChild
      **/
     public static function alreadyExists($items_id, $users_id)
     {
+        /** @var \DBmysql $DB */
         global $DB;
 
         $iterator = $DB->request([
@@ -735,6 +740,7 @@ abstract class CommonITILValidation extends CommonDBChild
     public static function showFormMassiveAction()
     {
 
+        /** @var array $CFG_GLPI */
         global $CFG_GLPI;
 
         $types            = ['user'  => User::getTypeName(1),
@@ -842,7 +848,11 @@ abstract class CommonITILValidation extends CommonDBChild
      **/
     public function showSummary(CommonDBTM $item)
     {
-        global $DB, $CFG_GLPI;
+        /**
+         * @var array $CFG_GLPI
+         * @var \DBmysql $DB
+         */
+        global $CFG_GLPI, $DB;
 
         if (
             !Session::haveRightsOr(
@@ -929,6 +939,7 @@ abstract class CommonITILValidation extends CommonDBChild
            "</th></tr>";
 
         if ($canadd) {
+            /** @var CommonITILObject $item */
             if (
                 !in_array($item->fields['status'], array_merge(
                     $item->getSolvedStatusArray(),
@@ -1368,6 +1379,7 @@ abstract class CommonITILValidation extends CommonDBChild
      **/
     public static function dropdownValidator(array $options = [])
     {
+        /** @var array $CFG_GLPI */
         global $CFG_GLPI;
 
         $params = [
@@ -1599,6 +1611,7 @@ abstract class CommonITILValidation extends CommonDBChild
      */
     public static function alertValidation(CommonITILObject $item, $type)
     {
+        /** @var array $CFG_GLPI */
         global $CFG_GLPI;
 
        // No alert for new item
