@@ -35,10 +35,11 @@
 
 namespace Glpi\Console\Database;
 
+use Glpi\Console\Command\ConfigurationCommandInterface;
 use Symfony\Component\Console\Input\InputInterface;
 use Symfony\Component\Console\Output\OutputInterface;
 
-class ConfigureCommand extends AbstractConfigureCommand
+class ConfigureCommand extends AbstractConfigureCommand implements ConfigurationCommandInterface
 {
     protected function configure()
     {
@@ -56,4 +57,9 @@ class ConfigureCommand extends AbstractConfigureCommand
 
         return 0; // Success if configuration throw no EarlyExitException
     }
+
+    public function getConfigurationFilesToUpdate(InputInterface $input): array
+    {
+        return ['config_db.php'];
+    }
 }
