@@ -231,7 +231,7 @@ class AppliancesPluginToCoreCommand extends AbstractCommand
         ];
 
         foreach ($core_tables as $table) {
-            $result = $this->db->query('TRUNCATE ' . $this->db->quoteName($table));
+            $result = $this->db->doQuery('TRUNCATE ' . $this->db->quoteName($table));
 
             if (!$result) {
                 throw new \Symfony\Component\Console\Exception\RuntimeException(
@@ -259,6 +259,7 @@ class AppliancesPluginToCoreCommand extends AbstractCommand
      */
     private function migratePlugin(): bool
     {
+        /** @var array $CFG_GLPI */
         global $CFG_GLPI;
 
        //prevent infocom creation from general setup
@@ -289,7 +290,7 @@ class AppliancesPluginToCoreCommand extends AbstractCommand
         );
 
         $table  = Profile::getTable();
-        $result = $this->db->query(
+        $result = $this->db->doQuery(
             sprintf(
                 "UPDATE %s SET helpdesk_item_type = REPLACE(helpdesk_item_type, '%s', '%s')",
                 $this->db->quoteName($table),
