@@ -121,8 +121,9 @@ class Consumable extends CommonDBChild
      *
      * @return bool
      */
-    public function backToStock(array $input, $history = 1)
+    public function backToStock(array $input, $history = true)
     {
+        /** @var \DBmysql $DB */
         global $DB;
 
         $result = $DB->update(
@@ -165,6 +166,7 @@ class Consumable extends CommonDBChild
      **/
     public function out($ID, $itemtype = '', $items_id = 0)
     {
+        /** @var \DBmysql $DB */
         global $DB;
 
         if (
@@ -192,6 +194,7 @@ class Consumable extends CommonDBChild
 
     public static function showMassiveActionsSubForm(MassiveAction $ma)
     {
+        /** @var array $CFG_GLPI */
         global $CFG_GLPI;
 
         $input = $ma->getInput();
@@ -285,6 +288,7 @@ class Consumable extends CommonDBChild
      **/
     public static function getTotalNumber($tID)
     {
+        /** @var \DBmysql $DB */
         global $DB;
 
         $result = $DB->request([
@@ -305,6 +309,7 @@ class Consumable extends CommonDBChild
      **/
     public static function getOldNumber($tID)
     {
+        /** @var \DBmysql $DB */
         global $DB;
 
         $result = $DB->request([
@@ -328,6 +333,7 @@ class Consumable extends CommonDBChild
      **/
     public static function getUnusedNumber($tID)
     {
+        /** @var \DBmysql $DB */
         global $DB;
 
         $result = $DB->request([
@@ -350,6 +356,7 @@ class Consumable extends CommonDBChild
      */
     public static function getStockTarget(int $tID): int
     {
+        /** @var \DBmysql $DB */
         global $DB;
 
         $it = $DB->request([
@@ -373,6 +380,7 @@ class Consumable extends CommonDBChild
      */
     public static function getAlarmThreshold(int $tID): int
     {
+        /** @var \DBmysql $DB */
         global $DB;
 
         $it = $DB->request([
@@ -438,6 +446,7 @@ class Consumable extends CommonDBChild
      **/
     public static function isNew($cID)
     {
+        /** @var \DBmysql $DB */
         global $DB;
 
         $result = $DB->request([
@@ -461,6 +470,7 @@ class Consumable extends CommonDBChild
      **/
     public static function isOld($cID)
     {
+        /** @var \DBmysql $DB */
         global $DB;
 
         $result = $DB->request([
@@ -540,6 +550,7 @@ class Consumable extends CommonDBChild
      **/
     public static function showForConsumableItem(ConsumableItem $consitem, $show_old = 0)
     {
+        /** @var \DBmysql $DB */
         global $DB;
 
         $tID = $consitem->getField('id');
@@ -686,6 +697,7 @@ class Consumable extends CommonDBChild
      **/
     public static function showSummary()
     {
+        /** @var \DBmysql $DB */
         global $DB;
 
         if (!Consumable::canView()) {
