@@ -176,6 +176,7 @@ class Contract extends CommonDBTM
 
     public static function rawSearchOptionsToAdd()
     {
+        /** @var \DBmysql $DB */
         global $DB;
 
         $tab = [];
@@ -470,6 +471,7 @@ class Contract extends CommonDBTM
 
     public function rawSearchOptions()
     {
+        /** @var \DBmysql $DB */
         global $DB;
 
         $tab = [];
@@ -598,7 +600,6 @@ class Contract extends CommonDBTM
             'table'              => $this->getTable(),
             'field'              => 'periodicity',
             'name'               => __('Periodicity'),
-            'massiveaction'      => false,
             'datatype'           => 'number',
             'min'                => 12,
             'max'                => 60,
@@ -618,7 +619,6 @@ class Contract extends CommonDBTM
             'table'              => $this->getTable(),
             'field'              => 'billing',
             'name'               => __('Invoice period'),
-            'massiveaction'      => false,
             'datatype'           => 'number',
             'min'                => 12,
             'max'                => 60,
@@ -646,7 +646,6 @@ class Contract extends CommonDBTM
             'table'              => $this->getTable(),
             'field'              => 'renewal',
             'name'               => __('Renewal'),
-            'massiveaction'      => false,
             'datatype'           => 'specific',
             'searchtype'         => ['equals', 'notequals']
         ];
@@ -878,7 +877,11 @@ class Contract extends CommonDBTM
      **/
     public static function showCentral(bool $display = true)
     {
-        global $DB,$CFG_GLPI;
+        /**
+         * @var array $CFG_GLPI
+         * @var \DBmysql $DB
+         */
+        global $CFG_GLPI, $DB;
 
         if (!Contract::canView()) {
             return;
@@ -1033,6 +1036,7 @@ class Contract extends CommonDBTM
      **/
     public function getSuppliersNames()
     {
+        /** @var \DBmysql $DB */
         global $DB;
 
         $iterator = $DB->request([
@@ -1071,7 +1075,11 @@ class Contract extends CommonDBTM
      **/
     public static function cronContract(CronTask $task = null)
     {
-        global $DB, $CFG_GLPI;
+        /**
+         * @var array $CFG_GLPI
+         * @var \DBmysql $DB
+         */
+        global $CFG_GLPI, $DB;
 
         if (!$CFG_GLPI["use_notifications"]) {
             return 0;
@@ -1398,6 +1406,7 @@ class Contract extends CommonDBTM
      **/
     public static function dropdown($options = [])
     {
+        /** @var \DBmysql $DB */
         global $DB;
 
        //$name,$entity_restrict=-1,$alreadyused=array(),$nochecklimit=false
@@ -1687,9 +1696,10 @@ class Contract extends CommonDBTM
     public static function getMassiveActionsForItemtype(
         array &$actions,
         $itemtype,
-        $is_deleted = 0,
+        $is_deleted = false,
         CommonDBTM $checkitem = null
     ) {
+        /** @var array $CFG_GLPI */
         global $CFG_GLPI;
 
         if (in_array($itemtype, $CFG_GLPI["contract_types"])) {
@@ -1810,6 +1820,7 @@ class Contract extends CommonDBTM
      */
     public static function getExpiredCriteria()
     {
+        /** @var \DBmysql $DB */
         global $DB;
 
         return ['OR' => [
