@@ -335,6 +335,7 @@ class DBConnection extends CommonDBTM
      **/
     public static function createDBSlaveConfig()
     {
+        /** @var \DBmysql $DB */
         global $DB;
         self::createSlaveConnectionFile(
             "localhost",
@@ -361,6 +362,7 @@ class DBConnection extends CommonDBTM
      **/
     public static function saveDBSlaveConf($host, $user, $password, $DBname)
     {
+        /** @var \DBmysql $DB */
         global $DB;
         self::createSlaveConnectionFile(
             $host,
@@ -391,6 +393,7 @@ class DBConnection extends CommonDBTM
      **/
     public static function switchToSlave()
     {
+        /** @var \DBmysql $DB */
         global $DB;
 
         if (self::isDBSlaveActive()) {
@@ -407,6 +410,7 @@ class DBConnection extends CommonDBTM
      **/
     public static function switchToMaster()
     {
+        /** @var \DBmysql $DB */
         global $DB;
 
         $DB = new DB();
@@ -422,7 +426,11 @@ class DBConnection extends CommonDBTM
      **/
     public static function getReadConnection()
     {
-        global $DB, $CFG_GLPI;
+        /**
+         * @var array $CFG_GLPI
+         * @var \DBmysql $DB
+         */
+        global $CFG_GLPI, $DB;
 
         if (
             $CFG_GLPI['use_slave_for_search']
@@ -491,6 +499,7 @@ class DBConnection extends CommonDBTM
      **/
     public static function establishDBConnection($use_slave, $required, $display = true)
     {
+        /** @var \DBmysql $DB */
         global $DB;
 
         $DB  = null;
@@ -566,7 +575,7 @@ class DBConnection extends CommonDBTM
     {
 
         if ($DBconnection->connected) {
-            $result = $DBconnection->query("SELECT UNIX_TIMESTAMP(MAX(`date_mod`)) AS max_date
+            $result = $DBconnection->doQuery("SELECT UNIX_TIMESTAMP(MAX(`date_mod`)) AS max_date
                                          FROM `glpi_logs`");
             if ($DBconnection->numrows($result) > 0) {
                  return $DBconnection->result($result, 0, "max_date");
@@ -581,6 +590,7 @@ class DBConnection extends CommonDBTM
      **/
     public static function displayMySQLError()
     {
+        /** @var \DBmysql $DB */
         global $DB;
 
         $error = $DB instanceof DBmysql ? $DB->error : 1;
@@ -629,6 +639,7 @@ class DBConnection extends CommonDBTM
      **/
     public static function cronCheckDBreplicate(CronTask $task)
     {
+        /** @var \DBmysql $DB */
         global $DB;
 
        //Lauch cron only is :
@@ -788,6 +799,7 @@ class DBConnection extends CommonDBTM
      */
     public static function getDefaultCharset(): string
     {
+        /** @var \DBmysql $DB */
         global $DB;
 
         if ($DB instanceof DBmysql && !$DB->use_utf8mb4) {
@@ -806,6 +818,7 @@ class DBConnection extends CommonDBTM
      */
     public static function getDefaultCollation(): string
     {
+        /** @var \DBmysql $DB */
         global $DB;
 
         if ($DB instanceof DBmysql && !$DB->use_utf8mb4) {
@@ -824,6 +837,7 @@ class DBConnection extends CommonDBTM
      */
     public static function getDefaultPrimaryKeySignOption(): string
     {
+        /** @var \DBmysql $DB */
         global $DB;
 
         if ($DB instanceof DBmysql && $DB->allow_signed_keys) {
