@@ -343,9 +343,33 @@ class DBmysql
      * @var integer $SQL_TOTAL_REQUEST
      *
      * @return mysqli_result|boolean Query result handler
+     *
+     * @deprecated 10.0.11
      */
     public function query($query)
     {
+        Toolbox::deprecated('Direct query usage is strongly discouraged! Use DB::request() instead.', false);
+        return $this->doQuery($query);
+    }
+
+    /**
+     * Execute a MySQL query
+     *
+     * @param string $query Query to execute
+     *
+     * @var array   $CFG_GLPI
+     * @var array   $DEBUG_SQL
+     * @var integer $SQL_TOTAL_REQUEST
+     *
+     * @return mysqli_result|boolean Query result handler
+     */
+    public function doQuery($query)
+    {
+        /**
+         * @var array $CFG_GLPI
+         * @var array $DEBUG_SQL
+         * @var integer $SQL_TOTAL_REQUEST
+         */
         global $CFG_GLPI, $DEBUG_SQL, $SQL_TOTAL_REQUEST;
 
         //FIXME Remove use of $DEBUG_SQL and $SQL_TOTAL_REQUEST
@@ -444,10 +468,29 @@ class DBmysql
      * @param string $message Explanation of query (default '')
      *
      * @return mysqli_result Query result handler
+     *
+     * @deprecated 10.0.11
      */
     public function queryOrDie($query, $message = '')
     {
-        $res = $this->query($query);
+        Toolbox::deprecated('Direct query usage is strongly discouraged! Use DB::request() instead.', false);
+        return $this->doQueryOrDie($query, $message);
+    }
+
+    /**
+     * Execute a MySQL query and die
+     * (optionnaly with a message) if it fails
+     *
+     * @since 0.84
+     *
+     * @param string $query   Query to execute
+     * @param string $message Explanation of query (default '')
+     *
+     * @return mysqli_result Query result handler
+     */
+    public function doQueryOrDie($query, $message = '')
+    {
+        $res = $this->doQuery($query);
         if (!$res) {
            //TRANS: %1$s is the description, %2$s is the query, %3$s is the error message
             $message = sprintf(
@@ -475,6 +518,11 @@ class DBmysql
      */
     public function prepare($query)
     {
+        /**
+         * @var array $CFG_GLPI
+         * @var array $DEBUG_SQL
+         * @var integer $SQL_TOTAL_REQUEST
+         */
         global $CFG_GLPI, $DEBUG_SQL, $SQL_TOTAL_REQUEST;
 
         $res = $this->dbh->prepare($query);
@@ -908,7 +956,7 @@ class DBmysql
         if (!$this->cache_disabled && $usecache && isset($this->field_cache[$table])) {
             return $this->field_cache[$table];
         }
-        $result = $this->query("SHOW COLUMNS FROM `$table`");
+        $result = $this->doQuery("SHOW COLUMNS FROM `$table`");
         if ($result) {
             if ($this->numrows($result) > 0) {
                 $this->field_cache[$table] = [];
@@ -1029,7 +1077,7 @@ class DBmysql
             $query = trim($query);
             if ($query != '') {
                 $query = htmlentities($query, ENT_COMPAT, 'UTF-8');
-                if (!$this->query($query)) {
+                if (!$this->doQuery($query)) {
                     return false;
                 }
                 if (!isCommandLine()) {
@@ -1048,23 +1096,6 @@ class DBmysql
     /**
      * Instanciate a Simple DBIterator
      *
-     * Examples =
-     *  foreach ($DB->request("select * from glpi_states") as $data) { ... }
-     *  foreach ($DB->request("glpi_states") as $ID => $data) { ... }
-     *  foreach ($DB->request("glpi_states", "ID=1") as $ID => $data) { ... }
-     *  foreach ($DB->request("glpi_states", "", "name") as $ID => $data) { ... }
-     *  foreach ($DB->request("glpi_computers",array("name"=>"SBEI003W","entities_id"=>1),array("serial","otherserial")) { ... }
-     *
-     * Examples =
-     *   array("id"=>NULL)
-     *   array("OR"=>array("id"=>1, "NOT"=>array("state"=>3)));
-     *   array("AND"=>array("id"=>1, array("NOT"=>array("state"=>array(3,4,5),"toto"=>2))))
-     *
-     * FIELDS name or array of field names
-     * ORDER name or array of field names
-     * LIMIT max of row to retrieve
-     * START first row to retrieve
-     *
      * @param string|string[] $tableorsql Table name, array of names or SQL query
      * @param string|string[] $crit       String or array of filed/values, ex array("id"=>1), if empty => all rows
      *                                    (default '')
@@ -1091,9 +1122,9 @@ class DBmysql
     {
        // No translation, used in sysinfo
         $ret = [];
-        $req = $this->request("SELECT @@sql_mode as mode, @@version AS vers, @@version_comment AS stype");
+        $req = $this->doQuery("SELECT @@sql_mode as mode, @@version AS vers, @@version_comment AS stype");
 
-        if (($data = $req->current())) {
+        if (($data = $req->fetch_array())) {
             if ($data['stype']) {
                 $ret['Server Software'] = $data['stype'];
             }
@@ -1127,7 +1158,7 @@ class DBmysql
     {
         $name          = addslashes($this->dbdefault . '.' . $name);
         $query         = "SELECT GET_LOCK('$name', 0)";
-        $result        = $this->query($query);
+        $result        = $this->doQuery($query);
         list($lock_ok) = $this->fetchRow($result);
 
         return (bool)$lock_ok;
@@ -1146,7 +1177,7 @@ class DBmysql
     {
         $name          = addslashes($this->dbdefault . '.' . $name);
         $query         = "SELECT RELEASE_LOCK('$name')";
-        $result        = $this->query($query);
+        $result        = $this->doQuery($query);
         list($lock_ok) = $this->fetchRow($result);
 
         return $lock_ok;
@@ -1288,6 +1319,7 @@ class DBmysql
                 // Values that corresponds to an existing namespaced class are not sanitized (see `Glpi\Toolbox\Sanitizer::sanitize()`).
                 // However, they have to be escaped in SQL queries.
                 // Note: method is called statically, so `$DB` may be not defined yet in edge cases (install process).
+                /** @var \DBmysql $DB */
                 global $DB;
                 $value = $DB instanceof DBmysql && $DB->connected ? $DB->escape($value) : $value;
             }
@@ -1345,7 +1377,7 @@ class DBmysql
      */
     public function insert($table, $params)
     {
-        $result = $this->query(
+        $result = $this->doQuery(
             $this->buildInsert($table, $params)
         );
         return $result;
@@ -1366,7 +1398,7 @@ class DBmysql
     public function insertOrDie($table, $params, $message = '')
     {
         $insert = $this->buildInsert($table, $params);
-        $res = $this->query($insert);
+        $res = $this->doQuery($insert);
         if (!$res) {
            //TRANS: %1$s is the description, %2$s is the query, %3$s is the error message
             $message = sprintf(
@@ -1400,7 +1432,7 @@ class DBmysql
      */
     public function buildUpdate($table, $params, $clauses, array $joins = [])
     {
-       //when no explicit "WHERE", we only have a WHEre clause.
+       //when no explicit "WHERE", we only have a WHERE clause.
         if (!isset($clauses['WHERE'])) {
             $clauses  = ['WHERE' => $clauses];
         } else {
@@ -1421,6 +1453,9 @@ class DBmysql
         if (!count($clauses['WHERE'])) {
             throw new \RuntimeException('Cannot run an UPDATE query without WHERE clause!');
         }
+        if (!count($params)) {
+            throw new \RuntimeException('Cannot run an UPDATE query without parameters!');
+        }
 
         $query  = "UPDATE " . self::quoteName($table);
 
@@ -1465,7 +1500,7 @@ class DBmysql
     public function update($table, $params, $where, array $joins = [])
     {
         $query = $this->buildUpdate($table, $params, $where, $joins);
-        $result = $this->query($query);
+        $result = $this->doQuery($query);
         return $result;
     }
 
@@ -1487,7 +1522,7 @@ class DBmysql
     public function updateOrDie($table, $params, $where, $message = '', array $joins = [])
     {
         $update = $this->buildUpdate($table, $params, $where, $joins);
-        $res = $this->query($update);
+        $res = $this->doQuery($update);
         if (!$res) {
            //TRANS: %1$s is the description, %2$s is the query, %3$s is the error message
             $message = sprintf(
@@ -1576,7 +1611,7 @@ class DBmysql
     public function delete($table, $where, array $joins = [])
     {
         $query = $this->buildDelete($table, $where, $joins);
-        $result = $this->query($query);
+        $result = $this->doQuery($query);
         return $result;
     }
 
@@ -1597,7 +1632,7 @@ class DBmysql
     public function deleteOrDie($table, $where, $message = '', array $joins = [])
     {
         $update = $this->buildDelete($table, $where, $joins);
-        $res = $this->query($update);
+        $res = $this->doQuery($update);
         if (!$res) {
            //TRANS: %1$s is the description, %2$s is the query, %3$s is the error message
             $message = sprintf(
@@ -1647,7 +1682,7 @@ class DBmysql
     public function truncateOrDie($table, $message = '')
     {
         $table_name = $this::quoteName($table);
-        $res = $this->query("TRUNCATE $table_name");
+        $res = $this->doQuery("TRUNCATE $table_name");
         if (!$res) {
            //TRANS: %1$s is the description, %2$s is the query, %3$s is the error message
             $message = sprintf(
@@ -1675,7 +1710,7 @@ class DBmysql
      */
     public function dropTable(string $name, bool $exists = false)
     {
-        $res = $this->query(
+        $res = $this->doQuery(
             $this->buildDrop(
                 $name,
                 'TABLE',
@@ -1695,7 +1730,7 @@ class DBmysql
      */
     public function dropView(string $name, bool $exists = false)
     {
-        $res = $this->query(
+        $res = $this->doQuery(
             $this->buildDrop(
                 $name,
                 'VIEW',
@@ -1718,14 +1753,20 @@ class DBmysql
     {
         $known_types = [
             'TABLE',
-            'VIEW'
+            'VIEW',
+            'INDEX',
+            'FOREIGN KEY',
+            'FIELD'
         ];
         if (!in_array($type, $known_types)) {
             throw new \InvalidArgumentException('Unknown type to drop: ' . $type);
         }
 
         $name = $this::quoteName($name);
-        $query = "DROP $type";
+        $query = 'DROP';
+        if ($type != 'FIELD') {
+            $query .= " $type";
+        }
         if ($exists) {
             $query .= ' IF EXISTS';
         }
@@ -1740,7 +1781,8 @@ class DBmysql
      */
     public function getVersion()
     {
-        $req = $this->request('SELECT version()')->current();
+        $res = $this->doQuery('SELECT version()');
+        $req = $res->fetch_array();
         $raw = $req['version()'];
         return $raw;
     }
@@ -1808,7 +1850,7 @@ class DBmysql
     protected function rollbackTo($name)
     {
         // No proper rollback to savepoint support in mysqli extension?
-        $result = $this->query('ROLLBACK TO ' . self::quoteName($name));
+        $result = $this->doQuery('ROLLBACK TO ' . self::quoteName($name));
         return $result !== false;
     }
 
