@@ -109,7 +109,7 @@ class DBmysqlIterator implements SeekableIterator, Countable
     public function execute($table, $crit = "", $debug = false)
     {
         $this->buildQuery($table, $crit, $debug);
-        $this->res = ($this->conn ? $this->conn->query($this->sql) : false);
+        $this->res = ($this->conn ? $this->conn->doQuery($this->sql) : false);
         $this->count = $this->res instanceof \mysqli_result ? $this->conn->numrows($this->res) : 0;
         $this->setPosition(0);
         return $this;
@@ -131,7 +131,7 @@ class DBmysqlIterator implements SeekableIterator, Countable
 
         $is_legacy = false;
 
-        if (is_string($table) && strpos($table, " ")) {
+        if (is_string($table) && strpos($table, " ") !== false) {
             $names = preg_split('/\s+AS\s+/i', $table);
             if (isset($names[1]) && strpos($names[1], ' ') || !isset($names[1]) || strpos($names[0], ' ')) {
                 $is_legacy = true;
@@ -139,9 +139,10 @@ class DBmysqlIterator implements SeekableIterator, Countable
         }
 
         if ($is_legacy) {
-           //if ($_SESSION['glpi_use_mode'] == Session::DEBUG_MODE) {
-           //   trigger_error("Deprecated usage of SQL in DB/request (full query)", E_USER_DEPRECATED);
-           //}
+            Toolbox::deprecated(
+                'Direct query usage is strongly discouraged!',
+                false
+            );
             $this->sql = $table;
         } else {
            // Modern way
@@ -242,7 +243,7 @@ class DBmysqlIterator implements SeekableIterator, Countable
                     $this->sql .= "" . DBmysql::quoteName($field);
                 } else {
                     if ($distinct) {
-                        trigger_error("With COUNT and DISTINCT, you must specify exactly one field, or use 'COUNT DISTINCT'", E_USER_ERROR);
+                        throw new \LogicException("With COUNT and DISTINCT, you must specify exactly one field, or use 'COUNT DISTINCT'.");
                     }
                     $this->sql .= "*";
                 }
@@ -277,7 +278,7 @@ class DBmysqlIterator implements SeekableIterator, Countable
                     $table = array_map([DBmysql::class, 'quoteName'], $table);
                     $this->sql .= ' FROM ' . implode(", ", $table);
                 } else {
-                    trigger_error("Missing table name", E_USER_ERROR);
+                    throw new \LogicException("Missing table name.");
                 }
             } else if ($table) {
                 if ($table instanceof \AbstractQuery) {
@@ -293,7 +294,7 @@ class DBmysqlIterator implements SeekableIterator, Countable
                 * TODO filter with if ($where || !empty($crit)) {
                 * but not usefull for now, as we CANNOT write something like "SELECT NOW()"
                 */
-                trigger_error("Missing table name", E_USER_ERROR);
+                throw new \LogicException("Missing table name.");
             }
 
            // JOIN
@@ -320,7 +321,7 @@ class DBmysqlIterator implements SeekableIterator, Countable
                     $groupby = array_map([DBmysql::class, 'quoteName'], $groupby);
                     $this->sql .= ' GROUP BY ' . implode(", ", $groupby);
                 } else {
-                    trigger_error("Missing group by field", E_USER_ERROR);
+                    throw new \LogicException("Missing group by field.");
                 }
             } else if ($groupby) {
                 $groupby = DBmysql::quoteName($groupby);
@@ -376,7 +377,7 @@ class DBmysqlIterator implements SeekableIterator, Countable
             } else if ($o instanceof QueryExpression) {
                 $cleanorderby[] = $o->getValue();
             } else {
-                trigger_error("Invalid order clause", E_USER_ERROR);
+                throw new \LogicException("Invalid order clause.");
             }
         }
 
@@ -656,7 +657,7 @@ class DBmysqlIterator implements SeekableIterator, Countable
         $query = '';
         foreach ($joinarray as $jointype => $jointables) {
             if (!in_array($jointype, ['JOIN', 'LEFT JOIN', 'INNER JOIN', 'RIGHT JOIN'])) {
-                throw new \RuntimeException('BAD JOIN');
+                throw new \LogicException(sprintf('Invalid JOIN type `%s`.', $jointype));
             }
 
             if ($jointype == 'JOIN') {
@@ -664,7 +665,7 @@ class DBmysqlIterator implements SeekableIterator, Countable
             }
 
             if (!is_array($jointables)) {
-                trigger_error("BAD JOIN, value must be [ table => criteria ]", E_USER_ERROR);
+                throw new \LogicException("BAD JOIN, value must be [ table => criteria ].");
                 continue;
             }
 
@@ -680,7 +681,7 @@ class DBmysqlIterator implements SeekableIterator, Countable
                     $jointablekey = $jointablecrit['TABLE'];
                     unset($jointablecrit['TABLE']);
                 } else if (is_numeric($jointablekey) || $jointablekey == 'FKEY' || $jointablekey == 'ON') {
-                    throw new \RuntimeException('BAD JOIN');
+                    throw new \LogicException('BAD JOIN');
                 }
 
                 if ($jointablekey instanceof \QuerySubQuery) {
@@ -724,7 +725,7 @@ class DBmysqlIterator implements SeekableIterator, Countable
                 return $fkey . ' ' . key($condition) . ' ' . $this->analyseCrit(current($condition));
             }
         }
-        trigger_error("BAD FOREIGN KEY, should be [ table1 => key1, table2 => key2 ] or [ table1 => key1, table2 => key2, [criteria]]", E_USER_ERROR);
+        throw new \LogicException('BAD FOREIGN KEY, should be [ table1 => key1, table2 => key2 ] or [ table1 => key1, table2 => key2, [criteria]].');
     }
 
     /**
