@@ -35,7 +35,6 @@
 
 namespace Glpi\Dashboard;
 
-use Change;
 use CommonDBTM;
 use CommonDBVisible;
 use CommonITILActor;
@@ -45,20 +44,23 @@ use CommonTreeDropdown;
 use CommonDevice;
 use Config;
 use DBConnection;
+use Glpi\Dashboard\Filters\{
+    DatesFilter,
+    GroupTechFilter,
+    UserTechFilter,
+};
 use Group;
 use Group_Ticket;
-use ITILCategory;
-use Problem;
 use Profile_User;
 use QueryExpression;
 use QuerySubQuery;
-use Search;
 use Session;
 use Stat;
 use Ticket;
 use Ticket_User;
 use Toolbox;
 use User;
+use Search;
 
 /**
  * Provider class
@@ -135,16 +137,12 @@ class Provider
         $result   = $iterator->current();
         $nb_items = $result['cpt'];
 
-        $search_criteria = [
-            [
-                self::getSearchFiltersCriteria($i_table, $params['apply_filters'])
-            ]
-        ];
+        $search_criteria = self::getSearchFiltersCriteria($i_table, $params['apply_filters'], true)['criteria'] ?? [];
 
         $search_url = $item::getSearchURL();
         $url = $search_url . (str_contains($search_url, '?') ? '&' : '?') . Toolbox::append_params([
-            $search_criteria,
-            'reset' => 'reset',
+            'criteria' => $search_criteria,
+            'reset'    => 'reset',
         ]);
 
         return [
@@ -279,7 +277,8 @@ class Provider
             case 'late':
                 $params['icon']  = "far fa-clock";
                 $params['label']  = __("Late tickets");
-                $search_criteria = array_merge([$notold], [
+                $search_criteria = [
+                    $notold,
                     [
                         'link'       => 'AND',
                         'criteria'   => [
@@ -305,7 +304,7 @@ class Provider
                             ]
                         ]
                     ]
-                ]);
+                ];
                 $query_criteria['WHERE']["$table.status"] = Ticket::getNotSolvedStatusArray();
                 $query_criteria['WHERE'][] = [
                     'OR' => [
@@ -424,7 +423,12 @@ class Provider
                 break;
         }
 
-        $search_criteria['criteria'] = self::getSearchFiltersCriteria($table, $params['apply_filters']);
+        $filter_criteria = self::getSearchFiltersCriteria($table, $params['apply_filters'], count($search_criteria) === 0);
+
+        $search_criteria = array_merge(
+            $search_criteria,
+            $filter_criteria['criteria'] ?? [],
+        );
 
         $url = Ticket::getSearchURL() . "?" . Toolbox::append_params([
             'criteria' => $search_criteria,
@@ -518,7 +522,7 @@ class Provider
             ]
         ];
 
-        unset($params['apply_filters']['group_tech']);
+        unset($params['apply_filters'][GroupTechFilter::getId()]);
         $query_filter = self::getFiltersCriteria($table, $params['apply_filters']);
         unset($query_filter['LEFT JOIN']["$ticketUserTable as ul"]);
 
@@ -578,10 +582,10 @@ class Provider
             }
             $label = $username ?? $name;
             $data['labels'][] = $label;
-            array_unshift($data['series'][0]['data'], $allLate[$name]);
-            array_unshift($data['series'][1]['data'], $resolveLate[$name]);
-            array_unshift($data['series'][2]['data'], $ownLate[$name]);
-            array_unshift($data['series'][3]['data'], $onTime[$name]);
+            array_push($data['series'][0]['data'], $allLate[$name]);
+            array_push($data['series'][1]['data'], $resolveLate[$name]);
+            array_push($data['series'][2]['data'], $ownLate[$name]);
+            array_push($data['series'][3]['data'], $onTime[$name]);
         }
 
         if (count($data['series'][0]['data']) < 1) {
@@ -662,7 +666,7 @@ class Provider
             ]
         ];
 
-        unset($params['apply_filters']['user_tech']);
+        unset($params['apply_filters'][UserTechFilter::getId()]);
         $query_filter = self::getFiltersCriteria($table, $params['apply_filters']);
         unset($query_filter['LEFT JOIN']["$ticketGroupTable as gl"]);
 
@@ -722,10 +726,10 @@ class Provider
             }
             $label = $username ?? $name;
             $data['labels'][] = $label;
-            array_unshift($data['series'][0]['data'], $allLate[$name]);
-            array_unshift($data['series'][1]['data'], $resolveLate[$name]);
-            array_unshift($data['series'][2]['data'], $ownLate[$name]);
-            array_unshift($data['series'][3]['data'], $onTime[$name]);
+            array_push($data['series'][0]['data'], $allLate[$name]);
+            array_push($data['series'][1]['data'], $resolveLate[$name]);
+            array_push($data['series'][2]['data'], $ownLate[$name]);
+            array_push($data['series'][3]['data'], $onTime[$name]);
         }
 
         if (count($data['series'][0]['data']) < 1) {
@@ -841,28 +845,25 @@ class Provider
         );
         $iterator = $DB->request($criteria);
 
-        $search_criteria = [
-            'criteria' => [
-                [
-                    'field'      => $params['searchoption_id'],
-                    'searchtype' => 'equals',
-                    'value'      => 0
-                ],
-                self::getSearchFiltersCriteria($fk_table, $params['apply_filters'])
-            ],
-            'reset' => 'reset',
-        ];
+        $search_criteria = self::getSearchFiltersCriteria($fk_table, $params['apply_filters'])['criteria'] ?? [];
 
         $url = $item::getSearchURL();
-        $url .= (strpos($url, '?') !== false ? '&' : '?') . 'reset';
 
         $data = [];
         foreach ($iterator as $result) {
-            $search_criteria['criteria'][0]['value'] = $result['fk_id'] ?? 0;
+            $result_criteria = $search_criteria;
+            $result_criteria[] = [
+                'field'      => $params['searchoption_id'],
+                'searchtype' => 'equals',
+                'value'      => $result['fk_id'] ?? 0,
+            ];
             $data[] = [
                 'number' => $result['cpt'],
                 'label'  => $result['fk_name'] ?? __("without"),
-                'url'    => $url . '&' . Toolbox::append_params($search_criteria),
+                'url'    => $url . (str_contains($url, '?') ? '&' : '?') . Toolbox::append_params([
+                    'criteria' => $result_criteria,
+                    'reset' => 'reset',
+                ]),
             ];
         }
 
@@ -1043,96 +1044,110 @@ class Provider
         $end    = date("Y-m-d");
 
         if (
-            isset($params['apply_filters']['dates'])
-            && count($params['apply_filters']['dates']) == 2
+            isset($params['apply_filters'][DatesFilter::getId()])
+            && count($params['apply_filters'][DatesFilter::getId()]) == 2
         ) {
-            $begin = date("Y-m-d", strtotime($params['apply_filters']['dates'][0]));
-            $end   = date("Y-m-d", strtotime($params['apply_filters']['dates'][1]));
-            unset($params['apply_filters']['dates']);
+            $begin = date("Y-m-d", strtotime($params['apply_filters'][DatesFilter::getId()][0]));
+            $end   = date("Y-m-d", strtotime($params['apply_filters'][DatesFilter::getId()][1]));
+            unset($params['apply_filters'][DatesFilter::getId()]);
         }
 
         $t_table   = Ticket::getTable();
 
+        $base_search_criteria = self::getSearchFiltersCriteria($t_table, $params['apply_filters'])['criteria'] ?? [];
+
         $series = [
 
             'inter_total' => [
                 'name'   => _nx('ticket', 'Opened', 'Opened', Session::getPluralNumber()),
                 'search' => [
-                    'criteria' => [
+                    'criteria' => array_merge(
                         [
-                            'link'       => 'AND',
-                            'field'      => 15, // creation date
-                            'searchtype' => 'morethan',
-                            'value'      => null
-                        ], [
-                            'link'       => 'AND',
-                            'field'      => 15, // creation date
-                            'searchtype' => 'lessthan',
-                            'value'      => null
-                        ],self::getSearchFiltersCriteria($t_table, $params['apply_filters']),
-                    ],
+                            [
+                                'link'       => 'AND',
+                                'field'      => 15, // creation date
+                                'searchtype' => 'morethan',
+                                'value'      => null
+                            ], [
+                                'link'       => 'AND',
+                                'field'      => 15, // creation date
+                                'searchtype' => 'lessthan',
+                                'value'      => null
+                            ],
+                        ],
+                        $base_search_criteria
+                    ),
                     'reset' => 'reset'
                 ]
             ],
             'inter_solved' => [
                 'name'   => _nx('ticket', 'Solved', 'Solved', Session::getPluralNumber()),
                 'search' => [
-                    'criteria' => [
+                    'criteria' => array_merge(
                         [
-                            'link'       => 'AND',
-                            'field'      => 17, // solve date
-                            'searchtype' => 'morethan',
-                            'value'      => null
-                        ], [
-                            'link'       => 'AND',
-                            'field'      => 17, // solve date
-                            'searchtype' => 'lessthan',
-                            'value'      => null
-                        ],self::getSearchFiltersCriteria($t_table, $params['apply_filters']),
-                    ],
+                            [
+                                'link'       => 'AND',
+                                'field'      => 17, // solve date
+                                'searchtype' => 'morethan',
+                                'value'      => null
+                            ], [
+                                'link'       => 'AND',
+                                'field'      => 17, // solve date
+                                'searchtype' => 'lessthan',
+                                'value'      => null
+                            ],
+                        ],
+                        $base_search_criteria
+                    ),
                     'reset' => 'reset'
                 ]
             ],
             'inter_solved_late' => [
                 'name'   => __('Late'),
                 'search' => [
-                    'criteria' => [
+                    'criteria' => array_merge(
                         [
-                            'link'       => 'AND',
-                            'field'      => 17, // solve date
-                            'searchtype' => 'morethan',
-                            'value'      => null
-                        ], [
-                            'link'       => 'AND',
-                            'field'      => 17, // solve date
-                            'searchtype' => 'lessthan',
-                            'value'      => null
-                        ], [
-                            'link'       => 'AND',
-                            'field'      => 82, // time_to_resolve exceed solve date
-                            'searchtype' => 'equals',
-                            'value'      => 1
-                        ],self::getSearchFiltersCriteria($t_table, $params['apply_filters']),
-                    ],
+                            [
+                                'link'       => 'AND',
+                                'field'      => 17, // solve date
+                                'searchtype' => 'morethan',
+                                'value'      => null
+                            ], [
+                                'link'       => 'AND',
+                                'field'      => 17, // solve date
+                                'searchtype' => 'lessthan',
+                                'value'      => null
+                            ], [
+                                'link'       => 'AND',
+                                'field'      => 82, // time_to_resolve exceed solve date
+                                'searchtype' => 'equals',
+                                'value'      => 1
+                            ],
+                        ],
+                        $base_search_criteria
+                    ),
                     'reset' => 'reset'
                 ]
             ],
             'inter_closed' => [
                 'name'   => __('Closed'),
                 'search' => [
-                    'criteria' => [
+                    'criteria' => array_merge(
                         [
-                            'link'       => 'AND',
-                            'field'      => 16, // close date
-                            'searchtype' => 'morethan',
-                            'value'      => null
-                        ], [
-                            'link'       => 'AND',
-                            'field'      => 16, // close date
-                            'searchtype' => 'lessthan',
-                            'value'      => null
-                        ],self::getSearchFiltersCriteria($t_table, $params['apply_filters']),
-                    ],
+                            [
+                                'link'       => 'AND',
+                                'field'      => 16, // close date
+                                'searchtype' => 'morethan',
+                                'value'      => null
+                            ], [
+                                'link'       => 'AND',
+                                'field'      => 16, // close date
+                                'searchtype' => 'lessthan',
+                                'value'      => null
+                            ],
+                        ],
+                        $base_search_criteria
+                    ),
                     'reset' => 'reset'
                 ]
             ],
@@ -1263,26 +1278,28 @@ class Provider
 
         $iterator = $DB->request($criteria);
 
-        $s_criteria = [
-            'criteria' => [
+        $s_params = [
+            'criteria' => array_merge(
                 [
-                    'link'       => 'AND',
-                    'field'      => 12, // status
-                    'searchtype' => 'equals',
-                    'value'      => null
-                ], [
-                    'link'       => 'AND',
-                    'field'      => 15, // creation date
-                    'searchtype' => 'morethan',
-                    'value'      => null
-                ], [
-                    'link'       => 'AND',
-                    'field'      => 15, // creation date
-                    'searchtype' => 'lessthan',
-                    'value'      => null
+                    [
+                        'link'       => 'AND',
+                        'field'      => 12, // status
+                        'searchtype' => 'equals',
+                        'value'      => null
+                    ], [
+                        'link'       => 'AND',
+                        'field'      => 15, // creation date
+                        'searchtype' => 'morethan',
+                        'value'      => null
+                    ], [
+                        'link'       => 'AND',
+                        'field'      => 15, // creation date
+                        'searchtype' => 'lessthan',
+                        'value'      => null
+                    ],
                 ],
-                self::getSearchFiltersCriteria($t_table, $params['apply_filters'])
-            ],
+                self::getSearchFiltersCriteria($t_table, $params['apply_filters'])['criteria'] ?? []
+            ),
             'reset' => 'reset'
         ];
 
@@ -1292,8 +1309,8 @@ class Provider
         ];
         foreach ($iterator as $result) {
             list($start_day, $end_day) = self::formatMonthyearDates($result['period']);
-            $s_criteria['criteria'][1]['value'] = $start_day;
-            $s_criteria['criteria'][2]['value'] = $end_day;
+            $s_params['criteria'][1]['value'] = $start_day;
+            $s_params['criteria'][2]['value'] = $end_day;
 
             $data['labels'][] = $result['period'];
             $tmp = $result;
@@ -1302,12 +1319,12 @@ class Provider
             $i = 0;
             foreach ($tmp as $label2 => $value) {
                 $status_key = array_search($label2, $statuses);
-                $s_criteria['criteria'][0]['value'] = $status_key;
+                $s_params['criteria'][0]['value'] = $status_key;
 
                 $data['series'][$i]['name'] = $label2;
                 $data['series'][$i]['data'][] = [
                     'value' => (int) $value,
-                    'url'   => Ticket::getSearchURL() . "?" . Toolbox::append_params($s_criteria),
+                    'url'   => Ticket::getSearchURL() . "?" . Toolbox::append_params($s_params),
                 ];
                 $i++;
             }
@@ -1376,6 +1393,7 @@ class Provider
         }
 
         $type = 0;
+        $soption = 0;
         switch ($case) {
             case "user_requester":
                 $type     = CommonITILActor::REQUESTER;
@@ -1438,25 +1456,27 @@ class Provider
         );
         $iterator = $DBread->request($criteria);
 
-        $s_criteria = [
-            'criteria' => [
+        $s_params = [
+            'criteria' => array_merge(
                 [
-                    'link'       => 'AND',
-                    'field'      => $soption,
-                    'searchtype' => 'equals',
-                    'value'      => null
+                    [
+                        'link'       => 'AND',
+                        'field'      => $soption,
+                        'searchtype' => 'equals',
+                        'value'      => null
+                    ],
                 ],
-                self::getSearchFiltersCriteria($t_table, $params['apply_filters']),
-            ],
+                self::getSearchFiltersCriteria($t_table, $params['apply_filters'])['criteria'] ?? []
+            ),
             'reset' => 'reset'
         ];
         $data = [];
         foreach ($iterator as $result) {
-            $s_criteria['criteria'][0]['value'] = $result['actor_id'];
+            $s_params['criteria'][0]['value'] = $result['actor_id'];
             $data[] = [
                 'number' => $result['nb_tickets'],
                 'label'  => $result['first'] . " " . ($result['second'] ?? ""),
-                'url'    => Ticket::getSearchURL() . "?" . Toolbox::append_params($s_criteria),
+                'url'    => Ticket::getSearchURL() . "?" . Toolbox::append_params($s_params),
             ];
         }
         return [
@@ -1625,376 +1645,57 @@ class Provider
         return [$start_day, $end_day];
     }
 
-    private static function getSearchOptionID(string $table, string $name, string $tableToSearch): int
-    {
-        $data = Search::getOptions(getItemTypeForTable($table), true);
-        $sort = [];
-        foreach ($data as $ref => $opt) {
-            if (isset($opt['field'])) {
-                $sort[$ref] = $opt['linkfield'] . "-" . $opt['table'];
-            }
-        }
-        return array_search($name . "-" . $tableToSearch, $sort);
-    }
 
-    final public static function getSearchFiltersCriteria(string $table = "", array $apply_filters = [])
+
+    /**
+     * Get search criteria based on given filters.
+     *
+     * @param string $table                     Related itemtype table.
+     * @param array $apply_filters              Dashboard filters.
+     * @param bool $default_criteria_on_empty   Return default criteria if filters are not producing any criteria.
+     *
+     * @return array An empty array, or an array containing a `criteria` key that contains search criteria.
+     *
+     * @FIXME Remove `criteria` key encapsulation. It cannot be done in 10.0 as some plugins are relying on current signature.
+     */
+    final public static function getSearchFiltersCriteria(string $table = "", array $apply_filters = [], bool $default_criteria_on_empty = false)
     {
-        $DB = DBConnection::getReadConnection();
         $s_criteria = [];
+        $filters = Filter::getRegisteredFilterClasses();
 
-        if (
-            $DB->fieldExists($table, 'date')
-            && isset($apply_filters['dates'])
-            && count($apply_filters['dates']) == 2
-        ) {
-            $s_criteria['criteria'][] = self::getDatesSearchCriteria(self::getSearchOptionID($table, "date", $table), $apply_filters['dates'], 'begin');
-            $s_criteria['criteria'][] = self::getDatesSearchCriteria(self::getSearchOptionID($table, "date", $table), $apply_filters['dates'], 'end');
-        }
-
-       //exclude itilobject already processed with 'date'
-        if (
-            !in_array($table, [
-                Ticket::getTable(),
-                Change::getTable(),
-                Problem::getTable(),
-            ]) && $DB->fieldExists($table, 'date_creation')
-            && isset($apply_filters['dates'])
-            && count($apply_filters['dates']) == 2
-        ) {
-            $s_criteria['criteria'][] = self::getDatesSearchCriteria(self::getSearchOptionID($table, "date_creation", $table), $apply_filters['dates'], 'begin');
-            $s_criteria['criteria'][] = self::getDatesSearchCriteria(self::getSearchOptionID($table, "date_creation", $table), $apply_filters['dates'], 'end');
-        }
-
-        if (
-            $DB->fieldExists($table, 'date_mod')
-            && isset($apply_filters['dates_mod'])
-            && count($apply_filters['dates_mod']) == 2
-        ) {
-            $s_criteria['criteria'][] = self::getDatesSearchCriteria(self::getSearchOptionID($table, "date_mod", $table), $apply_filters['dates_mod'], 'begin');
-            $s_criteria['criteria'][] = self::getDatesSearchCriteria(self::getSearchOptionID($table, "date_mod", $table), $apply_filters['dates_mod'], 'end');
-        }
-
-        if (
-            $DB->fieldExists($table, 'itilcategories_id')
-            && isset($apply_filters['itilcategory'])
-            && (int) $apply_filters['itilcategory'] > 0
-        ) {
-            $s_criteria['criteria'][] = [
-                'link'       => 'AND',
-                'field'      => self::getSearchOptionID($table, 'itilcategories_id', 'glpi_itilcategories'), // itilcategory
-                'searchtype' => 'under',
-                'value'      => (int) $apply_filters['itilcategory']
-            ];
-        }
-
-        if (
-            $DB->fieldExists($table, 'requesttypes_id')
-            && isset($apply_filters['requesttype'])
-            && (int) $apply_filters['requesttype'] > 0
-        ) {
-            $s_criteria['criteria'][] = [
-                'link'       => 'AND',
-                'field'      => self::getSearchOptionID($table, 'requesttypes_id', 'glpi_requesttypes'), // request type
-                'searchtype' => 'equals',
-                'value'      => (int) $apply_filters['requesttype']
-            ];
-        }
-
-        if (
-            $DB->fieldExists($table, 'locations_id')
-            && isset($apply_filters['location'])
-            && (int) $apply_filters['location'] > 0
-        ) {
-            $s_criteria['criteria'][] = [
-                'link'       => 'AND',
-                'field'      => self::getSearchOptionID($table, 'locations_id', 'glpi_locations'), // location
-                'searchtype' => 'equals',
-                'value'      => (int) $apply_filters['location']
-            ];
-        }
-
-        if (
-            $DB->fieldExists($table, 'manufacturers_id')
-            && isset($apply_filters['manufacturer'])
-            && (int) $apply_filters['manufacturer'] > 0
-        ) {
-            $s_criteria['criteria'][] = [
-                'link'       => 'AND',
-                'field'      => self::getSearchOptionID($table, 'manufacturers_id', 'glpi_manufacturers'), // manufacturer
-                'searchtype' => 'equals',
-                'value'      => (int) $apply_filters['manufacturer']
-            ];
-        }
-
-        if (isset($apply_filters['group_tech'])) {
-            $groups_id = null;
-            if ((int) $apply_filters['group_tech'] > 0) {
-                $groups_id =  (int) $apply_filters['group_tech'];
-            } else if ($apply_filters['group_tech'] == 'mygroups') {
-                $groups_id =  'mygroups';
-            }
-
-            if ($groups_id != null) {
-                if ($DB->fieldExists($table, 'groups_id_tech')) {
-                    $s_criteria['criteria'][] = [
-                        'link'       => 'AND',
-                        'field'      => self::getSearchOptionID($table, 'groups_id_tech', 'glpi_groups'), // group tech
-                        'searchtype' => 'equals',
-                        'value'      => $groups_id
-                    ];
-                } else if (
-                    in_array($table, [
-                        Ticket::getTable(),
-                        Change::getTable(),
-                        Problem::getTable(),
-                    ])
-                ) {
-                    $s_criteria['criteria'][] = [
-                        'link'       => 'AND',
-                        'field'      => 8, // group tech
-                        'searchtype' => 'equals',
-                        'value'      => $groups_id
-                    ];
-                }
+        foreach ($filters as $filter) {
+            if (!$filter::canBeApplied($table) || !array_key_exists($filter::getId(), $apply_filters)) {
+                continue;
             }
+            $filter_criteria = $filter::getSearchCriteria($table, $apply_filters[$filter::getId()]);
+            array_push($s_criteria, ...$filter_criteria);
         }
 
-        if (
-            isset($apply_filters['user_tech'])
-            && (
-                (int) $apply_filters['user_tech'] > 0
-                || $apply_filters['user_tech'] === 'myself'
-            )
-        ) {
-            if ($DB->fieldExists($table, 'users_id_tech')) {
-                $s_criteria['criteria'][] = [
-                    'link'       => 'AND',
-                    'field'      => self::getSearchOptionID($table, 'users_id_tech', 'glpi_users'),// tech
-                    'searchtype' => 'equals',
-                    'value'      =>  $apply_filters['user_tech'] === 'myself' ? (int) Session::getLoginUserID() : (int) $apply_filters['user_tech']
-                ];
-            } elseif (
-                in_array($table, [
-                    Ticket::getTable(),
-                    Change::getTable(),
-                    Problem::getTable(),
-                ])
-            ) {
-                $s_criteria['criteria'][] = [
-                    'link'       => 'AND',
-                    'field'      => 5,// tech
-                    'searchtype' => 'equals',
-                    'value'      =>  is_numeric($apply_filters['user_tech']) ? (int) $apply_filters['user_tech'] : $apply_filters['user_tech']
-                ];
-            }
+        $itemtype = getItemTypeForTable($table);
+        if (is_a($itemtype, CommonDBTM::class, true) && $default_criteria_on_empty === true && count($s_criteria) === 0) {
+            $s_criteria = Search::getDefaultCriteria($itemtype);
         }
 
-        if (
-            $DB->fieldExists($table, 'states_id')
-            && isset($apply_filters['state'])
-            && (int) $apply_filters['state'] > 0
-        ) {
-            $s_criteria['criteria'][] = [
-                'link'       => 'AND',
-                'field'      => self::getSearchOptionID($table, 'states_id', 'glpi_states'), // state
-                'searchtype' => 'equals',
-                'value'      => (int) $apply_filters['state']
-            ];
-        }
-
-        if (
-            $DB->fieldExists($table, 'type')
-            && isset($apply_filters['tickettype'])
-            && (int) $apply_filters['tickettype'] > 0
-        ) {
-            $s_criteria['criteria'][] = [
-                'link'       => 'AND',
-                'field'      => self::getSearchOptionID($table, 'type', $table),
-                'searchtype' => 'equals',
-                'value'      => (int) $apply_filters['tickettype']
-            ];
-        }
-
-        return $s_criteria;
+        return ['criteria' => $s_criteria];
     }
 
     public static function getFiltersCriteria(string $table = "", array $apply_filters = [])
     {
-        $DB = DBConnection::getReadConnection();
-
         $where = [];
         $join  = [];
 
-        if (
-            ($DB->fieldExists($table, 'date'))
-            && isset($apply_filters['dates'])
-            && count($apply_filters['dates']) == 2
-        ) {
-            $where += self::getDatesCriteria("$table.date", $apply_filters['dates']);
-        }
+        $filters = Filter::getRegisteredFilterClasses();
 
-       //exclude itilobject already processed with 'date'
-        if (
-            (!in_array($table, [
-                Ticket::getTable(),
-                Change::getTable(),
-                Problem::getTable(),
-            ]) && $DB->fieldExists($table, 'date_creation'))
-            && isset($apply_filters['dates'])
-            && count($apply_filters['dates']) == 2
-        ) {
-            $where += self::getDatesCriteria("$table.date_creation", $apply_filters['dates']);
-        }
-
-        if (
-            $DB->fieldExists($table, 'date_mod')
-            && isset($apply_filters['dates_mod'])
-            && count($apply_filters['dates_mod']) == 2
-        ) {
-            $where += self::getDatesCriteria("$table.date_mod", $apply_filters['dates_mod']);
-        }
-
-        if (
-            $DB->fieldExists($table, 'itilcategories_id')
-            && isset($apply_filters['itilcategory'])
-            && (int) $apply_filters['itilcategory'] > 0
-        ) {
-            $where += [
-                "$table.itilcategories_id" => getSonsOf(ITILCategory::getTable(), (int) $apply_filters['itilcategory'])
-            ];
-        }
-
-        if (
-            $DB->fieldExists($table, 'requesttypes_id')
-            && isset($apply_filters['requesttype'])
-            && (int) $apply_filters['requesttype'] > 0
-        ) {
-            $where += [
-                "$table.requesttypes_id" => (int) $apply_filters['requesttype']
-            ];
-        }
-
-        if (
-            $DB->fieldExists($table, 'locations_id')
-            && isset($apply_filters['location'])
-            && (int) $apply_filters['location'] > 0
-        ) {
-            $where += [
-                "$table.locations_id" => (int) $apply_filters['location']
-            ];
-        }
-
-        if (
-            $DB->fieldExists($table, 'manufacturers_id')
-            && isset($apply_filters['manufacturer'])
-            && (int) $apply_filters['manufacturer'] > 0
-        ) {
-            $where += [
-                "$table.manufacturers_id" => (int) $apply_filters['manufacturer']
-            ];
-        }
-
-        if (
-            $DB->fieldExists($table, 'states_id')
-            && isset($apply_filters['state'])
-            && (int) $apply_filters['state'] > 0
-        ) {
-            $where += [
-                "$table.states_id" => (int) $apply_filters['state']
-            ];
-        }
-
-        if (
-            $DB->fieldExists($table, 'type')
-            && isset($apply_filters['tickettype'])
-            && (int) $apply_filters['tickettype'] > 0
-        ) {
-            $where += [
-                "$table.type" => (int) $apply_filters['tickettype']
-            ];
-        }
-
-        if (isset($apply_filters['group_tech'])) {
-            $groups_id = null;
-            if ((int) $apply_filters['group_tech'] > 0) {
-                $groups_id =  (int) $apply_filters['group_tech'];
-            } else if ($apply_filters['group_tech'] == 'mygroups') {
-                $groups_id =  $_SESSION['glpigroups'];
+        foreach ($filters as $filter) {
+            if (!$filter::canBeApplied($table) || !array_key_exists($filter::getId(), $apply_filters)) {
+                continue;
             }
-
-            if ($groups_id != null) {
-                if ($DB->fieldExists($table, 'groups_id_tech')) {
-                    $where += [
-                        "$table.groups_id_tech" => $groups_id
-                    ];
-                } else if (
-                    in_array($table, [
-                        Ticket::getTable(),
-                        Change::getTable(),
-                        Problem::getTable(),
-                    ])
-                ) {
-                    $itemtype  = getItemTypeForTable($table);
-                    $main_item = getItemForItemtype($itemtype);
-                    $grouplink = $main_item->grouplinkclass;
-                    $gl_table  = $grouplink::getTable();
-                    $fk        = $main_item->getForeignKeyField();
-
-                    $join += [
-                        "$gl_table as gl" => [
-                            'ON' => [
-                                'gl'   => $fk,
-                                $table => 'id',
-                            ]
-                        ]
-                    ];
-                    $where += [
-                        "gl.type"      => \CommonITILActor::ASSIGN,
-                        "gl.groups_id" => $groups_id
-                    ];
-                }
+            $filter_criteria = $filter::getCriteria($table, $apply_filters[$filter::getId()]);
+            if (isset($filter_criteria['WHERE'])) {
+                $where = array_merge($where, $filter_criteria['WHERE']);
             }
-        }
-
-        if (isset($apply_filters['user_tech'])) {
-            $users_id = null;
-            if ((int) $apply_filters['user_tech'] > 0) {
-                $users_id = (int) $apply_filters['user_tech'];
-            } else if ($apply_filters['user_tech'] === 'myself') {
-                $users_id = $_SESSION['glpiID'];
-            }
-
-            if ($users_id !== null) {
-                if ($DB->fieldExists($table, 'users_id_tech')) {
-                    $where += [
-                        "$table.users_id_tech" => $users_id,
-                    ];
-                } else if (
-                    in_array($table, [
-                        Ticket::getTable(),
-                        Change::getTable(),
-                        Problem::getTable(),
-                    ])
-                ) {
-                    $itemtype  = getItemTypeForTable($table);
-                    $main_item = getItemForItemtype($itemtype);
-                    $userlink  = $main_item->userlinkclass;
-                    $ul_table  = $userlink::getTable();
-                    $fk        = $main_item->getForeignKeyField();
-
-                    $join += [
-                        "$ul_table as ul" => [
-                            'ON' => [
-                                'ul'   => $fk,
-                                $table => 'id',
-                            ]
-                        ]
-                    ];
-                    $where += [
-                        "ul.type"     => \CommonITILActor::ASSIGN,
-                        "ul.users_id" => $users_id,
-                    ];
-                }
+            if (isset($filter_criteria['JOIN'])) {
+                $join = array_merge($join, $filter_criteria['JOIN']);
             }
         }
 
@@ -2008,37 +1709,4 @@ class Provider
 
         return $criteria;
     }
-
-    private static function getDatesCriteria(string $field = "", array $dates = []): array
-    {
-        $begin = strtotime($dates[0]);
-        $end   = strtotime($dates[1]);
-
-        return [
-            [$field => ['>=', date('Y-m-d', $begin)]],
-            [$field => ['<=', date('Y-m-d', $end)]],
-        ];
-    }
-
-    private static function getDatesSearchCriteria(int $searchoption_id, array $dates = [], $when = 'begin'): array
-    {
-
-        if ($when == "begin") {
-            $begin = strtotime($dates[0]);
-            return [
-                'link'       => 'AND',
-                'field'      => $searchoption_id, // creation date
-                'searchtype' => 'morethan',
-                'value'      => date('Y-m-d 00:00:00', $begin)
-            ];
-        } else {
-            $end   = strtotime($dates[1]);
-            return [
-                'link'       => 'AND',
-                'field'      => $searchoption_id, // creation date
-                'searchtype' => 'lessthan',
-                'value'      => date('Y-m-d 00:00:00', $end)
-            ];
-        }
-    }
 }
