@@ -188,6 +188,7 @@ final class DbUtils
      */
     public function getTableForItemType($itemtype)
     {
+        /** @var array $CFG_GLPI */
         global $CFG_GLPI;
 
        // Force singular for itemtype : States case
@@ -237,6 +238,7 @@ final class DbUtils
      */
     public function getItemTypeForTable($table)
     {
+        /** @var array $CFG_GLPI */
         global $CFG_GLPI;
 
         if (isset($CFG_GLPI['glpiitemtypetables'][$table])) {
@@ -246,12 +248,14 @@ final class DbUtils
             $table     = str_replace("glpi_", "", $table);
             $prefix    = "";
             $pref2     = NS_GLPI;
+            $is_plugin = false;
 
             $matches = [];
             if (preg_match('/^plugin_([a-z0-9]+)_/', $table, $matches)) {
                 $table  = preg_replace('/^plugin_[a-z0-9]+_/', '', $table);
                 $prefix = "Plugin" . Toolbox::ucfirst($matches[1]);
                 $pref2  = NS_PLUG . ucfirst($matches[1]) . '\\';
+                $is_plugin = true;
             }
 
             if (strstr($table, '_')) {
@@ -279,10 +283,40 @@ final class DbUtils
                     $itemtype = $base_itemtype;
                 }
             }
+
+            // Handle namespaces
             if ($itemtype === null) {
                 $namespaced_itemtype = $this->fixItemtypeCase($pref2 . str_replace('_', '\\', $table));
+
                 if (class_exists($namespaced_itemtype)) {
                     $itemtype = $namespaced_itemtype;
+                } else {
+                    // Handle namespace + db relation
+                    // On the previous step we converted all '_' into '\'
+                    // However some '_' must be kept in case of an item relation
+                    // For example, with the `glpi_namespace1_namespace2_items_filters` table
+                    // the expected itemtype is Glpi\Namespace1\Namespace2\Item_Filter
+                    // NOT Glpi\Namespace1\Namespace2\Item\Filter
+                    // To avoid this, we can revert the last '_' and check if the itemtype exists
+                    $check_alternative = $is_plugin
+                        ? substr_count($table, '_') > 1 // for plugin classes, always keep the first+second namespace levels (GlpiPlugin\\PluginName\\)
+                        : substr_count($table, '_') > 0 // for GLPI classes, always keep the first namespace level (Glpi\\)
+                    ;
+                    if ($check_alternative) {
+                        $last_backslash_position = strrpos($namespaced_itemtype, "\\");
+                        // Replace last '\' into '_'
+                        $alternative_namespaced_itemtype = substr_replace(
+                            $namespaced_itemtype,
+                            '_',
+                            $last_backslash_position,
+                            1
+                        );
+                        $alternative_namespaced_itemtype = $this->fixItemtypeCase($alternative_namespaced_itemtype);
+
+                        if (class_exists($alternative_namespaced_itemtype)) {
+                            $itemtype = $alternative_namespaced_itemtype;
+                        }
+                    }
                 }
             }
 
@@ -308,6 +342,7 @@ final class DbUtils
      */
     public function fixItemtypeCase(string $itemtype, $root_dir = GLPI_ROOT)
     {
+        /** @var \Psr\SimpleCache\CacheInterface $GLPI_CACHE */
         global $GLPI_CACHE;
 
         // If a class exists for this itemtype, just return the declared class name.
@@ -458,13 +493,14 @@ final class DbUtils
     /**
      * Count the number of elements in a table.
      *
-     * @param string|array $table     table name(s)
-     * @param array        $condition array of criteria
+     * @param string|array   $table     table name(s)
+     * @param ?string|?array $condition array of criteria
      *
      * @return integer Number of elements in table
      */
     public function countElementsInTable($table, $condition = [])
     {
+        /** @var \DBmysql $DB */
         global $DB;
 
         if (!is_array($table)) {
@@ -478,6 +514,7 @@ final class DbUtils
        }*/
 
         if (!is_array($condition)) {
+            Toolbox::Deprecated('Condition must be an array!');
             if (empty($condition)) {
                 $condition = [];
             }
@@ -491,9 +528,9 @@ final class DbUtils
     /**
      * Count the number of elements in a table.
      *
-     * @param string|array $table     table name(s)
-     * @param string       $field     field name
-     * @param array        $condition array of criteria
+     * @param string|array   $table     table name(s)
+     * @param string         $field     field name
+     * @param ?string|?array $condition array of criteria
      *
      * @return int nb of elements in table
      */
@@ -501,6 +538,7 @@ final class DbUtils
     {
 
         if (!is_array($condition)) {
+            Toolbox::Deprecated('Condition must be an array!');
             if (empty($condition)) {
                 $condition = [];
             }
@@ -563,15 +601,16 @@ final class DbUtils
      * Get data from a table in an array :
      * CAUTION TO USE ONLY FOR SMALL TABLES OR USING A STRICT CONDITION
      *
-     * @param string  $table    Table name
-     * @param array   $criteria Request criteria
-     * @param boolean $usecache Use cache (false by default)
-     * @param string  $order    Result order (default '')
+     * @param string         $table    Table name
+     * @param ?string|?array $criteria Request criteria
+     * @param boolean        $usecache Use cache (false by default)
+     * @param string         $order    Result order (default '')
      *
      * @return array containing all the datas
      */
     public function getAllDataFromTable($table, $criteria = [], $usecache = false, $order = '')
     {
+        /** @var \DBmysql $DB */
         global $DB;
 
         static $cache = [];
@@ -616,6 +655,7 @@ final class DbUtils
      */
     public function isIndex($table, $field)
     {
+        /** @var \DBmysql $DB */
         global $DB;
 
         if (!$DB->tableExists($table)) {
@@ -623,7 +663,7 @@ final class DbUtils
             return false;
         }
 
-        $result = $DB->query("SHOW INDEX FROM `$table`");
+        $result = $DB->doQuery("SHOW INDEX FROM `$table`");
 
         if ($result && $DB->numrows($result)) {
             while ($data = $DB->fetchAssoc($result)) {
@@ -645,6 +685,7 @@ final class DbUtils
      */
     public function isForeignKeyContraint($table, $keyname)
     {
+        /** @var \DBmysql $DB */
         global $DB;
 
         $query = [
@@ -686,6 +727,7 @@ final class DbUtils
         $is_recursive = false,
         $complete_request = false
     ) {
+        /** @var \DBmysql $DB */
         global $DB;
 
         $query = $separator . " ( ";
@@ -873,6 +915,10 @@ final class DbUtils
      */
     public function getSonsOf($table, $IDf)
     {
+        /**
+         * @var \DBmysql $DB
+         * @var \Psr\SimpleCache\CacheInterface $GLPI_CACHE
+         */
         global $DB, $GLPI_CACHE;
 
         $ckey = 'sons_cache_' . $table . '_' . $IDf;
@@ -899,7 +945,7 @@ final class DbUtils
                 $db_sons = $iterator->current()['sons_cache'];
                 $db_sons = $db_sons !== null ? trim($db_sons) : null;
                 if (!empty($db_sons)) {
-                    $sons = $this->importArrayFromDB($db_sons, true);
+                    $sons = $this->importArrayFromDB($db_sons);
                 }
             }
         }
@@ -981,6 +1027,10 @@ final class DbUtils
      */
     public function getAncestorsOf($table, $items_id)
     {
+        /**
+         * @var \DBmysql $DB
+         * @var \Psr\SimpleCache\CacheInterface $GLPI_CACHE
+         */
         global $DB, $GLPI_CACHE;
 
         if ($items_id === null) {
@@ -1022,7 +1072,7 @@ final class DbUtils
 
                   // Return datas from cache in DB
                     if (!empty($rancestors)) {
-                        $ancestors = array_replace($ancestors, $this->importArrayFromDB($rancestors, true));
+                        $ancestors = array_replace($ancestors, $this->importArrayFromDB($rancestors));
                     } else {
                         $loc_id_found = [];
                      // Recursive solution for table with-cache
@@ -1119,6 +1169,7 @@ final class DbUtils
      */
     public function getTreeLeafValueName($table, $ID, $withcomment = false, $translate = true)
     {
+        /** @var \DBmysql $DB */
         global $DB;
 
         $name    = "";
@@ -1221,6 +1272,7 @@ final class DbUtils
      */
     public function getTreeValueCompleteName($table, $ID, $withcomment = false, $translate = true, $tooltip = true, string $default = '&nbsp;')
     {
+        /** @var \DBmysql $DB */
         global $DB;
 
         $name    = "";
@@ -1372,6 +1424,7 @@ final class DbUtils
      */
     public function getTreeValueName($table, $ID, $wholename = "", $level = 0)
     {
+        /** @var \DBmysql $DB */
         global $DB;
 
         $parentIDfield = $this->getForeignKeyFieldForTable($table);
@@ -1410,6 +1463,7 @@ final class DbUtils
      */
     public function getTreeForItem($table, $IDf)
     {
+        /** @var \DBmysql $DB */
         global $DB;
 
         $parentIDfield = $this->getForeignKeyFieldForTable($table);
@@ -1521,6 +1575,7 @@ final class DbUtils
      **/
     public function regenerateTreeCompleteName($table)
     {
+        /** @var \DBmysql $DB */
         global $DB;
 
         $iterator = $DB->request([
@@ -1548,9 +1603,9 @@ final class DbUtils
      * Format a user name
      *
      * @param integer $ID           ID of the user.
-     * @param string  $login        login of the user
-     * @param string  $realname     realname of the user
-     * @param string  $firstname    firstname of the user
+     * @param string|null  $login        login of the user
+     * @param string|null  $realname     realname of the user
+     * @param string|null  $firstname    firstname of the user
      * @param integer $link         include link (only if $link==1) (default =0)
      * @param integer $cut          limit string length (0 = no limit) (default =0)
      * @param boolean $force_config force order and id_visible to use common config (false by default)
@@ -1559,6 +1614,7 @@ final class DbUtils
      */
     public function formatUserName($ID, $login, $realname, $firstname, $link = 1, $cut = 0, $force_config = false)
     {
+        /** @var array $CFG_GLPI */
         global $CFG_GLPI;
 
         $before = "";
@@ -1574,10 +1630,10 @@ final class DbUtils
             $id_visible = $_SESSION["glpiis_ids_visible"];
         }
 
-        if ($realname !== null && strlen($realname) > 0) {
+        if (strlen($realname ?? '') > 0) {
             $formatted = $realname;
 
-            if (strlen($firstname) > 0) {
+            if (strlen($firstname ?? '') > 0) {
                 if ($order == User::FIRSTNAME_BEFORE) {
                     $formatted = $firstname . " " . $formatted;
                 } else {
@@ -1592,12 +1648,12 @@ final class DbUtils
                 $formatted = Toolbox::substr($formatted, 0, $cut) . " ...";
             }
         } else {
-            $formatted = $login;
+            $formatted = $login ?? '';
         }
 
         if (
             $ID > 0
-            && ((strlen($formatted ?? '') == 0) || $id_visible)
+            && ((strlen($formatted) == 0) || $id_visible)
         ) {
             $formatted = sprintf(__('%1$s (%2$s)'), $formatted, $ID);
         }
@@ -1628,6 +1684,7 @@ final class DbUtils
      */
     public function getUserName($ID, $link = 0, $disable_anon = false)
     {
+        /** @var \DBmysql $DB */
         global $DB;
 
         $user = "";
@@ -1729,7 +1786,11 @@ final class DbUtils
      */
     public function autoName($objectName, $field, $isTemplate, $itemtype, $entities_id = -1)
     {
-        global $DB, $CFG_GLPI;
+        /**
+         * @var array $CFG_GLPI
+         * @var \DBmysql $DB
+         */
+        global $CFG_GLPI, $DB;
 
         if (!$isTemplate) {
             return $objectName;
@@ -1894,6 +1955,7 @@ final class DbUtils
      */
     public function closeDBConnections()
     {
+        /** @var \DBmysql $DB */
         global $DB;
 
        // Case of not init $DB object
@@ -1913,6 +1975,7 @@ final class DbUtils
      */
     public function getDateCriteria($field, $begin, $end)
     {
+        /** @var \DBmysql $DB */
         global $DB;
 
         $date_pattern = '/^\d{4}-\d{2}-\d{2}( \d{2}:\d{2}:\d{2})?$/'; // `YYYY-mm-dd` optionaly followed by ` HH:ii:ss`
