@@ -42,6 +42,7 @@ use Glpi\Toolbox\Sanitizer;
 class Document extends CommonDBTM
 {
     use Glpi\Features\TreeBrowse;
+    use Glpi\Features\ParentStatus;
 
    // From CommonDBTM
     public $dohistory                   = true;
@@ -70,6 +71,7 @@ class Document extends CommonDBTM
      **/
     public static function canApplyOn($item)
     {
+        /** @var array $CFG_GLPI */
         global $CFG_GLPI;
 
        // All devices can have documents!
@@ -102,6 +104,7 @@ class Document extends CommonDBTM
      **/
     public static function getItemtypesThatCanHave()
     {
+        /** @var array $CFG_GLPI */
         global $CFG_GLPI;
 
         return array_merge(
@@ -222,6 +225,7 @@ class Document extends CommonDBTM
 
     public function prepareInputForAdd($input)
     {
+        /** @var array $CFG_GLPI */
         global $CFG_GLPI;
 
        // security (don't accept filename from $_REQUEST)
@@ -355,6 +359,12 @@ class Document extends CommonDBTM
                 'items_id'     => $this->input["items_id"]
             ]);
 
+            if (is_a($this->input["itemtype"], CommonITILObject::class, true)) {
+                $itilobject = new $this->input["itemtype"]();
+                $itilobject->getFromDB($this->input["items_id"]);
+                $this->updateParentStatus($itilobject, $this->input);
+            }
+
             Event::log(
                 $this->fields['id'],
                 "documents",
@@ -524,6 +534,7 @@ class Document extends CommonDBTM
      **/
     public static function getMaxUploadSize()
     {
+        /** @var array $CFG_GLPI */
         global $CFG_GLPI;
 
        //TRANS: %s is a size
@@ -555,7 +566,11 @@ class Document extends CommonDBTM
      **/
     public function getDownloadLink($linked_item = null, $len = 20)
     {
-        global $DB, $CFG_GLPI;
+        /**
+         * @var array $CFG_GLPI
+         * @var \DBmysql $DB
+         */
+        global $CFG_GLPI, $DB;
 
         $link_params = '';
         if (is_string($linked_item)) {
@@ -640,6 +655,7 @@ class Document extends CommonDBTM
     public function getFromDBbyContent($entity, $path)
     {
 
+        /** @var \DBmysql $DB */
         global $DB;
 
         if (empty($path)) {
@@ -776,6 +792,7 @@ class Document extends CommonDBTM
     private function canViewFileFromReminder()
     {
 
+        /** @var \DBmysql $DB */
         global $DB;
 
         if (!Session::getLoginUserID()) {
@@ -819,6 +836,10 @@ class Document extends CommonDBTM
     private function canViewFileFromKnowbaseItem()
     {
 
+        /**
+         * @var array $CFG_GLPI
+         * @var \DBmysql $DB
+         */
         global $CFG_GLPI, $DB;
 
        // Knowbase items can be viewed by non connected user in case of public FAQ
@@ -876,6 +897,7 @@ class Document extends CommonDBTM
     private function canViewFileFromItilObject($itemtype, $items_id)
     {
 
+        /** @var \DBmysql $DB */
         global $DB;
 
         if (!Session::getLoginUserID()) {
@@ -915,6 +937,7 @@ class Document extends CommonDBTM
      */
     private function canViewFileFromItem($itemtype, $items_id): bool
     {
+        /** @var \DBmysql $DB */
         global $DB;
 
         $item = new $itemtype();
@@ -1151,6 +1174,12 @@ class Document extends CommonDBTM
      **/
     public function moveUploadedDocument(array &$input, $filename)
     {
+        if (str_contains($filename, '/') || str_contains($filename, '\\')) {
+            // Filename is not supposed to contains directory separators.
+            trigger_error(sprintf('Moving file `%s` is forbidden for security reasons.', $filename), E_USER_WARNING);
+            return false;
+        }
+
         $prefix = '';
         if (isset($input['_prefix_filename'])) {
             $prefix = array_shift($input['_prefix_filename']);
@@ -1263,6 +1292,12 @@ class Document extends CommonDBTM
      **/
     public static function moveDocument(array &$input, $filename)
     {
+        if (str_contains($filename, '/') || str_contains($filename, '\\')) {
+            // Filename is not supposed to contains directory separators.
+            trigger_error(sprintf('Moving file `%s` is forbidden for security reasons.', $filename), E_USER_WARNING);
+            return false;
+        }
+
         $prefix = '';
         if (isset($input['_prefix_filename'])) {
             $prefix = array_shift($input['_prefix_filename']);
@@ -1337,24 +1372,13 @@ class Document extends CommonDBTM
        // Local file : try to detect mime type
         $input['mime'] = Toolbox::getMime($fullpath);
 
-        if (
-            is_writable(GLPI_TMP_DIR)
-            && is_writable($fullpath)
-        ) { // Move if allowed
-            if (self::renameForce($fullpath, GLPI_DOC_DIR . "/" . $new_path)) {
-                Session::addMessageAfterRedirect(__('Document move succeeded.'));
-            } else {
-                Session::addMessageAfterRedirect(__('File move failed.'), false, ERROR);
-                return false;
-            }
-        } else { // Copy (will overwrite dest file is present)
-            if (copy($fullpath, GLPI_DOC_DIR . "/" . $new_path)) {
-                Session::addMessageAfterRedirect(__('Document copy succeeded.'));
-            } else {
-                Session::addMessageAfterRedirect(__('File move failed'), false, ERROR);
-                @unlink($fullpath);
-                return false;
-            }
+        // Copy (will overwrite dest file if present)
+        if (copy($fullpath, GLPI_DOC_DIR . "/" . $new_path)) {
+            Session::addMessageAfterRedirect(__('Document copy succeeded.'));
+        } else {
+            Session::addMessageAfterRedirect(__('File move failed'), false, ERROR);
+            @unlink($fullpath);
+            return false;
         }
 
        // For display
@@ -1373,7 +1397,7 @@ class Document extends CommonDBTM
      * @param &$input    array of datas need for add/update (will be completed)
      * @param $FILEDESC        FILE descriptor
      *
-     * @return true on success
+     * @return boolean
      **/
     public static function uploadDocument(array &$input, $FILEDESC)
     {
@@ -1579,6 +1603,7 @@ class Document extends CommonDBTM
      **/
     public static function isValidDoc($filename)
     {
+        /** @var \DBmysql $DB */
         global $DB;
 
         $splitter = explode(".", $filename);
@@ -1632,7 +1657,11 @@ class Document extends CommonDBTM
      **/
     public static function dropdown($options = [])
     {
-        global $DB, $CFG_GLPI;
+        /**
+         * @var array $CFG_GLPI
+         * @var \DBmysql $DB
+         */
+        global $CFG_GLPI, $DB;
 
         $p['name']    = 'documents_id';
         $p['entity']  = '';
@@ -1719,7 +1748,7 @@ class Document extends CommonDBTM
     public static function getMassiveActionsForItemtype(
         array &$actions,
         $itemtype,
-        $is_deleted = 0,
+        $is_deleted = false,
         CommonDBTM $checkitem = null
     ) {
         $action_prefix = 'Document_Item' . MassiveAction::CLASS_ACTION_SEPARATOR;
@@ -1878,6 +1907,7 @@ class Document extends CommonDBTM
      **/
     public static function cronCleanOrphans(CronTask $task)
     {
+        /** @var \DBmysql $DB */
         global $DB;
 
         $dtable = static::getTable();
