@@ -72,6 +72,7 @@ class Domain extends CommonDBTM
 
     public function cleanDBonPurge()
     {
+        /** @var \DBmysql $DB */
         global $DB;
 
         $ditem = new Domain_Item();
@@ -201,7 +202,7 @@ class Domain extends CommonDBTM
         ];
 
         $tab[] = [
-            'id'                 => '30',
+            'id'                 => '1400',
             'table'              => $this->getTable(),
             'field'              => 'id',
             'name'               => __('ID'),
@@ -347,6 +348,7 @@ class Domain extends CommonDBTM
      * */
     public static function dropdownDomains($options = [])
     {
+        /** @var \DBmysql $DB */
         global $DB;
 
         $p = [
@@ -547,6 +549,7 @@ class Domain extends CommonDBTM
      */
     public static function expiredDomainsCriteria($entities_id): array
     {
+        /** @var \DBmysql $DB */
         global $DB;
 
         $delay = Entity::getUsedConfig('send_domains_alert_expired_delay', $entities_id);
@@ -571,6 +574,7 @@ class Domain extends CommonDBTM
      */
     public static function closeExpiriesDomainsCriteria($entities_id): array
     {
+        /** @var \DBmysql $DB */
         global $DB;
 
         $delay = Entity::getUsedConfig('send_domains_alert_close_expiries_delay', $entities_id);
@@ -596,7 +600,11 @@ class Domain extends CommonDBTM
      */
     public static function cronDomainsAlert($task = null)
     {
-        global $DB, $CFG_GLPI;
+        /**
+         * @var array $CFG_GLPI
+         * @var \DBmysql $DB
+         */
+        global $CFG_GLPI, $DB;
 
         if (!$CFG_GLPI["use_notifications"]) {
             return 0; // Nothing to do
@@ -706,6 +714,7 @@ class Domain extends CommonDBTM
      * */
     public static function getTypes($all = false)
     {
+        /** @var array $CFG_GLPI */
         global $CFG_GLPI;
 
         $types = $CFG_GLPI['domain_types'];
@@ -747,6 +756,7 @@ class Domain extends CommonDBTM
 
     public static function getUsed(array $used, $domaintype)
     {
+        /** @var \DBmysql $DB */
         global $DB;
 
         $iterator = $DB->request([
@@ -819,7 +829,7 @@ class Domain extends CommonDBTM
         return "fas fa-globe-americas";
     }
 
-    public function post_updateItem($history = 1)
+    public function post_updateItem($history = true)
     {
         $this->cleanAlerts([Alert::END, Alert::NOTICE]);
         parent::post_updateItem($history);
