@@ -33,6 +33,8 @@
  * ---------------------------------------------------------------------
  */
 
+use Glpi\RichText\RichText;
+
 /**
  * DropdownTranslation Class
  *
@@ -172,7 +174,7 @@ class DropdownTranslation extends CommonDBChild
     }
 
 
-    public function post_updateItem($history = 1)
+    public function post_updateItem($history = true)
     {
 
         if (!isset($this->input['_no_completename'])) {
@@ -229,6 +231,7 @@ class DropdownTranslation extends CommonDBChild
      **/
     public static function getNumberOfTranslationsForItem($item)
     {
+        /** @var \DBmysql $DB */
         global $DB;
 
         return countElementsInTable(
@@ -274,86 +277,94 @@ class DropdownTranslation extends CommonDBChild
      **/
     public function generateCompletename($input, $add = true)
     {
+        /** @var \DBmysql $DB */
         global $DB;
-       // Force completename translated : used for the first translation
-        $_SESSION['glpi_dropdowntranslations'][$input['itemtype']]['completename'] = 'completename';
 
-       //If there's already a completename for this language, get it's ID, otherwise 0
+        if (!is_a($input['itemtype'], CommonTreeDropdown::class, true)) {
+            return; // `completename` is used only for tree dropdowns
+        }
+        $itemtype = $input['itemtype'];
+
+        //If there's already a completename for this language, get it's ID, otherwise 0
         $completenames_id = self::getTranslationID(
             $input['items_id'],
-            $input['itemtype'],
+            $itemtype,
             'completename',
             $input['language']
         );
-        $item = new $input['itemtype']();
-       //Completename is used only for tree dropdowns !
-        if (
-            $item instanceof CommonTreeDropdown
-            && isset($input['language'])
-        ) {
-            $item->getFromDB($input['items_id']);
-            $foreignKey = $item->getForeignKeyField();
+        $item = new $itemtype();
+        $item->getFromDB($input['items_id']);
+        $foreignKey = $item->getForeignKeyField();
 
-           //Regenerate completename : look for item's ancestors
-            $completename = "";
+        $completename_parts  = [];
+        $completename = "";
 
-           //Get ancestors as an array
-
-            if ($item->fields[$foreignKey] != 0) {
-                $completename = self::getTranslatedValue(
-                    $item->fields[$foreignKey],
-                    $input['itemtype'],
-                    'completename',
-                    $input['language']
-                );
-            }
-
-            if ($completename != '') {
-                $completename .= " > ";
-            }
-            $completename .= self::getTranslatedValue(
-                $item->getID(),
-                $input['itemtype'],
-                'name',
+        if ($item->fields[$foreignKey] != 0) {
+            // Get translated complename of parent item
+            $tranlated_parent_completename = self::getTranslatedValue(
+                $item->fields[$foreignKey],
+                $itemtype,
+                'completename',
                 $input['language']
             );
+            if ($tranlated_parent_completename !== '') {
+                $completename_parts[] = $tranlated_parent_completename;
+            } elseif ($parent = $itemtype::getById($item->fields[$foreignKey])) {
+                // Fallback to untranslated completename of parent item
+                $completename_parts[] = $parent->fields['completename'];
+            }
+        }
 
-           //Add or update completename for this language
-            $translation              = new self();
-            $tmp                      = [];
-            $tmp['items_id']          = $input['items_id'];
-            $tmp['itemtype']          = $input['itemtype'];
-            $tmp['field']             = 'completename';
-            $tmp['value']             = addslashes($completename);
-            $tmp['language']          = $input['language'];
-            $tmp['_no_completename']  = true;
-            if ($completenames_id) {
-                $tmp['id']    = $completenames_id;
-                if ($completename === $item->fields['completename']) {
-                    $translation->delete(['id' => $completenames_id]);
-                } else {
-                    $translation->update($tmp);
-                }
+        // Append translated name of item
+        $tranlated_name = self::getTranslatedValue(
+            $item->getID(),
+            $itemtype,
+            'name',
+            $input['language']
+        );
+        if ($tranlated_name !== '') {
+            $completename_parts[] = $tranlated_name;
+        } else {
+            $completename_parts[] = $item->fields['name'];
+        }
+
+        $completename = implode(' > ', $completename_parts);
+
+        // Add or update completename for this language
+        $translation              = new self();
+        $tmp                      = [];
+        $tmp['items_id']          = $input['items_id'];
+        $tmp['itemtype']          = $input['itemtype'];
+        $tmp['field']             = 'completename';
+        $tmp['value']             = addslashes($completename);
+        $tmp['language']          = $input['language'];
+        $tmp['_no_completename']  = true;
+        if ($completenames_id) {
+            $tmp['id']    = $completenames_id;
+            if ($completename === $item->fields['completename']) {
+                $translation->delete(['id' => $completenames_id]);
             } else {
-                if ($completename != $item->fields['completename']) {
-                     $translation->add($tmp);
-                }
+                $translation->update($tmp);
             }
-
-            $iterator = $DB->request([
-                'SELECT' => ['id'],
-                'FROM'   => $item->getTable(),
-                'WHERE'  => [
-                    $foreignKey => $item->getID()
-                ]
-            ]);
-
-            foreach ($iterator as $tmp) {
-                $input2 = $input;
-                $input2['items_id'] = $tmp['id'];
-                $this->generateCompletename($input2, $add);
+        } else {
+            if ($completename != $item->fields['completename']) {
+                 $translation->add($tmp);
             }
         }
+
+        $iterator = $DB->request([
+            'SELECT' => ['id'],
+            'FROM'   => $item->getTable(),
+            'WHERE'  => [
+                $foreignKey => $item->getID()
+            ]
+        ]);
+
+        foreach ($iterator as $tmp) {
+            $input2 = $input;
+            $input2['items_id'] = $tmp['id'];
+            $this->generateCompletename($input2, $add);
+        }
     }
 
 
@@ -366,7 +377,11 @@ class DropdownTranslation extends CommonDBChild
      **/
     public static function showTranslations(CommonDropdown $item)
     {
-        global $DB, $CFG_GLPI;
+        /**
+         * @var array $CFG_GLPI
+         * @var \DBmysql $DB
+         */
+        global $CFG_GLPI, $DB;
 
         $rand    = mt_rand();
         $canedit = $item->can($item->getID(), UPDATE);
@@ -456,7 +471,14 @@ class DropdownTranslation extends CommonDBChild
                 echo "</td><td $onhover>";
                 $searchOption = $item->getSearchOptionByField('field', $data['field']);
                 echo $searchOption['name'] . "</td>";
-                echo "<td $onhover>" . $data['value'] . "</td>";
+                echo "<td $onhover>";
+                $matching_field = $item->getAdditionalField($data['field']);
+                if (($matching_field['type'] ?? null) === 'tinymce') {
+                    echo '<div class="rich_text_container">' . RichText::getSafeHtml($data['value']) . '</div>';
+                } else {
+                    echo $data['value'];
+                }
+                echo "</td>";
                 echo "</tr>";
             }
             echo "</table>";
@@ -487,6 +509,7 @@ class DropdownTranslation extends CommonDBChild
             return false;
         }
 
+        /** @var array $CFG_GLPI */
         global $CFG_GLPI;
 
         $item = $options['parent'];
@@ -538,12 +561,47 @@ class DropdownTranslation extends CommonDBChild
             echo $searchOption['name'];
         } else {
             echo "<span id='span_fields' name='span_fields'>";
-            self::dropdownFields($item, $_SESSION['glpilanguage']);
+            $rand = self::dropdownFields($item, $_SESSION['glpilanguage']);
             echo "</span>";
+            $params = [
+                'field'    => '__VALUE__',
+                'itemtype' => get_class($item),
+                'items_id' => $item->getID(),
+            ];
+            Ajax::updateItemOnSelectEvent(
+                "dropdown_field$rand",
+                "span_value",
+                $CFG_GLPI["root_doc"] . "/ajax/updateTranslationValue.php",
+                $params
+            );
+            echo Html::scriptBlock(<<<JAVASCRIPT
+                $(
+                    function() {
+                        $("#dropdown_field$rand").trigger("change");
+                    }
+                );
+JAVASCRIPT
+            );
         }
         echo "</td>";
         echo "<td>" . __('Value') . "</td>";
-        echo "<td><input type='text' name='value' value=\"" . $this->fields['value'] . "\" size='50'>";
+        echo "<td>";
+        echo "<span id='span_value'>";
+        if ($ID > 0) {
+            $matching_field = $item->getAdditionalField($this->fields['field']);
+            if (($matching_field['type'] ?? null) === 'tinymce') {
+                Html::textarea([
+                    'name'              => 'value',
+                    'value'             => RichText::getSafeHtml($this->fields["value"], true),
+                    'enable_richtext'   => true,
+                    'enable_images'     => false,
+                    'enable_fileupload' => false,
+                ]);
+            } else {
+                echo "<input type='text' name='value' value=\"" . $this->fields['value'] . "\" size='50'>";
+            }
+        }
+        echo "</span>";
         echo "</td>";
         echo "</tr>\n";
         $this->showFormButtons($options);
@@ -562,6 +620,7 @@ class DropdownTranslation extends CommonDBChild
      **/
     public static function dropdownFields(CommonDBTM $item, $language = '', $value = '')
     {
+        /** @var \DBmysql $DB */
         global $DB;
 
         $options = [];
@@ -615,18 +674,22 @@ class DropdownTranslation extends CommonDBChild
      **/
     public static function getTranslatedValue($ID, $itemtype, $field = 'name', $language = '', $value = '')
     {
+        /** @var \DBmysql $DB */
         global $DB;
 
         if ($language == '') {
             $language = $_SESSION['glpilanguage'];
         }
 
+        $translated_fields = $language === $_SESSION['glpilanguage'] && isset($_SESSION['glpi_dropdowntranslations'])
+            ? $_SESSION['glpi_dropdowntranslations']
+            : DropdownTranslation::getAvailableTranslations($language);
+
        //If dropdown translation is globally off, or if this itemtype cannot be translated,
        //then original value should be returned
-        $item = new $itemtype();
         if (
             !$ID
-            || !Session::haveTranslations($itemtype, $field)
+            || !isset($translated_fields[$itemtype][$field])
         ) {
             return $value;
         }
@@ -678,6 +741,7 @@ class DropdownTranslation extends CommonDBChild
      **/
     public static function getTranslationID($ID, $itemtype, $field, $language)
     {
+        /** @var \DBmysql $DB */
         global $DB;
 
         $iterator = $DB->request([
@@ -723,6 +787,7 @@ class DropdownTranslation extends CommonDBChild
      **/
     public static function isDropdownTranslationActive()
     {
+        /** @var array $CFG_GLPI */
         global $CFG_GLPI;
 
         return $CFG_GLPI['translate_dropdowns'];
@@ -740,6 +805,7 @@ class DropdownTranslation extends CommonDBChild
      **/
     public static function getTranslationByName($itemtype, $field, $value)
     {
+        /** @var \DBmysql $DB */
         global $DB;
 
         $iterator = $DB->request([
@@ -773,6 +839,7 @@ class DropdownTranslation extends CommonDBChild
      **/
     public static function getTranslationsForAnItem($itemtype, $items_id, $field)
     {
+        /** @var \DBmysql $DB */
         global $DB;
 
         $iterator = $DB->request([
@@ -828,6 +895,7 @@ class DropdownTranslation extends CommonDBChild
      **/
     public static function getAvailableTranslations($language)
     {
+        /** @var \DBmysql $DB */
         global $DB;
 
         $tab = [];
