@@ -170,6 +170,7 @@ class GLPINetwork extends CommonGLPI
      */
     public static function getRegistrationKey(): string
     {
+        /** @var array $CFG_GLPI */
         global $CFG_GLPI;
         return (new GLPIKey())->decrypt($CFG_GLPI['glpinetwork_registration_key'] ?? '');
     }
@@ -187,6 +188,7 @@ class GLPINetwork extends CommonGLPI
      */
     public static function getRegistrationInformations(bool $force_refresh = false)
     {
+        /** @var \Psr\SimpleCache\CacheInterface $GLPI_CACHE */
         global $GLPI_CACHE;
 
         $registration_key = self::getRegistrationKey();
@@ -226,6 +228,7 @@ class GLPINetwork extends CommonGLPI
         );
 
         $valid_json = false;
+        $registration_data = null;
         if ($error_message === null) {
             if (\Toolbox::isJSON($registration_response)) {
                 $valid_json = true;
@@ -279,13 +282,17 @@ class GLPINetwork extends CommonGLPI
 
     public static function showInstallMessage()
     {
-        return nl2br(sprintf(
-            __("You need help to integrate GLPI in your IT, have a bug fixed or benefit from pre-configured rules or dictionaries?\n\n" .
-            "We provide the %s space for you.\n" .
-            "GLPI-Network is a commercial service that includes a subscription for tier 3 support, ensuring the correction of bugs encountered with a commitment time.\n\n" .
-            "In this same space, you will be able to <b>contact an official partner</b> to help you with your GLPI integration."),
-            "<a href='" . GLPI_NETWORK_SERVICES . "' target='_blank'>" . GLPI_NETWORK_SERVICES . "</a>"
-        ));
+        return nl2br(
+            sprintf(
+                __(
+                    "You need help to integrate GLPI in your IT, have a bug fixed or benefit from pre-configured rules or dictionaries?\n\n"
+                    . "We provide the %s space for you.\n"
+                    . "GLPI-Network is a commercial service that includes a subscription for tier 3 support, ensuring the correction of bugs encountered with a commitment time.\n\n"
+                    . "In this same space, you will be able to contact an official partner to help you with your GLPI integration."
+                ),
+                "<a href='" . GLPI_NETWORK_SERVICES . "' target='_blank'>" . GLPI_NETWORK_SERVICES . "</a>"
+            )
+        );
     }
 
     public static function getSupportPromoteMessage()
@@ -318,6 +325,7 @@ class GLPINetwork extends CommonGLPI
 
     public static function getOffers(bool $force_refresh = false): array
     {
+        /** @var \Psr\SimpleCache\CacheInterface $GLPI_CACHE */
         global $GLPI_CACHE;
 
         $lang = preg_replace('/^([a-z]+)_.+$/', '$1', $_SESSION["glpilanguage"]);
