@@ -78,6 +78,7 @@ class Group_User extends CommonDBRelation
      **/
     public static function getUserGroups($users_id, $condition = [])
     {
+        /** @var \DBmysql $DB */
         global $DB;
 
         $groups = [];
@@ -124,6 +125,7 @@ class Group_User extends CommonDBRelation
      **/
     public static function getGroupUsers($groups_id, $condition = [])
     {
+        /** @var \DBmysql $DB */
         global $DB;
 
         $users = [];
@@ -165,6 +167,7 @@ class Group_User extends CommonDBRelation
      **/
     public static function showForUser(User $user)
     {
+        /** @var array $CFG_GLPI */
         global $CFG_GLPI;
 
         $ID = $user->fields['id'];
@@ -379,6 +382,7 @@ class Group_User extends CommonDBRelation
         $tree = 0,
         bool $check_entities = true
     ) {
+        /** @var \DBmysql $DB */
         global $DB;
 
         // Entity restriction for this group, according to user allowed entities
@@ -472,6 +476,7 @@ class Group_User extends CommonDBRelation
      **/
     public static function showForGroup(Group $group)
     {
+        /** @var array $CFG_GLPI */
         global $CFG_GLPI;
 
         $ID = $group->getID();
@@ -855,8 +860,11 @@ class Group_User extends CommonDBRelation
 
     public function post_addItem()
     {
+        /** @var \DBmysql $DB */
         global $DB;
 
+        parent::post_addItem();
+
        // add new user to plannings
         $groups_id  = $this->fields['groups_id'];
         $planning_k = 'group_' . $groups_id . '_users';
@@ -914,8 +922,11 @@ class Group_User extends CommonDBRelation
 
     public function post_purgeItem()
     {
+        /** @var \DBmysql $DB */
         global $DB;
 
+        parent::post_purgeItem();
+
        // remove user from plannings
         $groups_id  = $this->fields['groups_id'];
         $planning_k = 'group_' . $groups_id . '_users';
