@@ -132,7 +132,7 @@ class Holiday extends CommonDropdown
         return $input;
     }
 
-    public function post_updateItem($history = 1)
+    public function post_updateItem($history = true)
     {
 
         $this->invalidateCalendarHolidayCache();
