@@ -181,7 +181,7 @@ class IPAddress extends CommonDBChild
     }
 
 
-    public function post_updateItem($history = 1)
+    public function post_updateItem($history = true)
     {
 
         if (
@@ -218,6 +218,7 @@ class IPAddress extends CommonDBChild
 
     public static function showForItem(CommonGLPI $item, $withtemplate = 0)
     {
+        /** @var array $CFG_GLPI */
         global $CFG_GLPI;
 
         if ($item->getType() == 'IPNetwork') {
@@ -327,6 +328,7 @@ class IPAddress extends CommonDBChild
      **/
     public static function countForItem(CommonDBTM $item)
     {
+        /** @var \DBmysql $DB */
         global $DB;
 
         switch ($item->getType()) {
@@ -445,7 +447,7 @@ class IPAddress extends CommonDBChild
      *
      * If the field name is empty, then, the field is not set
      *
-     * @return true is succeffully defined
+     * @return boolean successfully defined
      **/
     public function setAddressFromArray(array $array, $versionField, $textualField, $binaryField)
     {
@@ -555,7 +557,7 @@ class IPAddress extends CommonDBChild
      *
      * @param integer[] $address (bytes[4]) the address to check
      *
-     * @return true if the address is IPv4 mapped to IPv6
+     * @return boolean
      **/
     public static function isIPv4MappedToIPv6Address($address)
     {
@@ -592,10 +594,11 @@ class IPAddress extends CommonDBChild
      * @param string  $itemtype  type of the item this address has to be attached (default '')
      * @param integer $items_id  id of the item this address has to be attached (default -1)
      *
-     * @return true if the address is valid.
+     * @return boolean address is valid
      **/
     public function setAddressFromString($address, $itemtype = "", $items_id = -1)
     {
+        /** @var \DBmysql $DB */
         global $DB;
 
         $this->disableAddress();
@@ -776,10 +779,11 @@ class IPAddress extends CommonDBChild
      * @param string    $itemtype  type of the item this address has to be attached (default '')
      * @param integer   $items_id  id of the item this address has to be attached (default -1)
      *
-     * @return true if the address is valid.
+     * @return boolean address is valid
      **/
     public function setAddressFromBinary($address, $itemtype = "", $items_id = -1)
     {
+        /** @var \DBmysql $DB */
         global $DB;
 
         $this->disableAddress();
@@ -884,7 +888,7 @@ class IPAddress extends CommonDBChild
 
         $prefix = "";
 
-       //If it a special format, add prefix previsouly removed (to manage IPV4 part)
+       //If it is a special format, add prefix previously removed (to manage IPV4 part)
         if ($this->isDottedQuoadFormat) {
             $prefix = "::ffff:";
         }
@@ -900,7 +904,7 @@ class IPAddress extends CommonDBChild
      * @param integer[] $address   (in and out) the address to increment or decrement
      * @param integer   $value     the value to add or remove. Must be betwwen -0xffffffff and +0xffffffff
      *
-     * @return true if the increment is valid
+     * @return boolean true if the increment is valid
      **/
     public static function addValueToAddress(&$address, $value)
     {
@@ -963,6 +967,7 @@ class IPAddress extends CommonDBChild
      **/
     public static function getItemsByIPAddress($IPaddress)
     {
+        /** @var \DBmysql $DB */
         global $DB;
 
        // We must resolv binary address :
@@ -1141,7 +1146,11 @@ class IPAddress extends CommonDBChild
         HTMLTableCell $father = null,
         array $options = []
     ) {
-        global $DB, $CFG_GLPI;
+        /**
+         * @var array $CFG_GLPI
+         * @var \DBmysql $DB
+         */
+        global $CFG_GLPI, $DB;
 
         if (
             ($item !== null)
