@@ -425,12 +425,12 @@ abstract class InventoryAsset
 
     protected function handleInput(\stdClass $value, ?CommonDBTM $item = null): array
     {
-        $input = [];
+        $input = ['_auto' => 1];
         $locks = [];
 
         if ($item !== null) {
             $lockeds = new \Lockedfield();
-            $locks = $lockeds->getLockedNames($item->getType(), $item->fields['id'] ?? 0);
+            $locks = $lockeds->getLockedNames($item->getType(), $item->isNewItem() ? 0 : $item->fields['id']);
         }
 
         foreach ($value as $key => $val) {
@@ -450,4 +450,19 @@ abstract class InventoryAsset
     }
 
     abstract public function getItemtype(): string;
+
+    final protected function cleanName(string $string): string
+    {
+        return trim(
+            preg_replace(
+                '/[\x{200B}-\x{200D}\x{FEFF}]/u', //remove invisible characters
+                '',
+                preg_replace(
+                    '/\s+/u', //replace with single standard whitespace
+                    ' ',
+                    $string
+                )
+            )
+        );
+    }
 }
