@@ -48,6 +48,7 @@ use Glpi\Toolbox\Sanitizer;
 use NetworkEquipment;
 use Printer;
 use RefusedEquipment;
+use RuleImportAsset;
 use RuleImportAssetCollection;
 use RuleImportEntityCollection;
 use RuleLocationCollection;
@@ -179,7 +180,9 @@ abstract class MainAsset extends InventoryAsset
             'winprodkey'     => 'license_number',
             'workgroup'      => 'domains_id',
             'lastloggeduser' => 'users_id',
-            'description'    => 'comment'
+            'description'    => 'comment',
+            'wincompany'     => 'company',
+            'winowner'       => 'owner',
         ];
 
         foreach ($hw_mapping as $origin => $dest) {
@@ -240,6 +243,7 @@ abstract class MainAsset extends InventoryAsset
      */
     protected function prepareForUsers($val)
     {
+        /** @var \DBmysql $DB */
         global $DB;
 
         if ($this->isPartial()) {
@@ -404,7 +408,7 @@ abstract class MainAsset extends InventoryAsset
      */
     public function prepareAllRulesInput(\stdClass $val): array
     {
-        $input = [];
+        $input = ['_auto' => 1];
 
         if (isset($this->getAgent()->fields['tag'])) {
             $input['tag'] = $this->getAgent()->fields['tag'];
@@ -488,6 +492,10 @@ abstract class MainAsset extends InventoryAsset
 
         $input['itemtype'] = $this->item->getType();
 
+        if (property_exists($val, 'comment')) {
+            $input['oscomment'] = $val->comment;
+        }
+
         // * entity rules
         $input['entities_id'] = $this->entities_id;
 
@@ -581,8 +589,10 @@ abstract class MainAsset extends InventoryAsset
                     //Only main item is stored as refused, not all APs
                     unset($this->data[$key]);
                 } else {
-                    $input['rules_id'] = $datarules['rules_id'];
-                    $this->addRefused($input);
+                    if ($datarules['action'] != RuleImportAsset::LINK_RESULT_DENIED) {
+                        $input['rules_id'] = $datarules['rules_id'];
+                        $this->addRefused($input);
+                    }
                 }
             }
         }
@@ -647,6 +657,10 @@ abstract class MainAsset extends InventoryAsset
      */
     public function rulepassed($items_id, $itemtype, $rules_id, $ports_id = 0)
     {
+        /**
+         * @var array $CFG_GLPI
+         * @var \DBmysql $DB
+         */
         global $CFG_GLPI, $DB;
 
         $key = $this->current_key;
@@ -700,8 +714,40 @@ abstract class MainAsset extends InventoryAsset
                 throw new \Exception('Unable to create item.');
             }
             $this->setNew();
+
+            //update val according to commonDBTM process (rule)
+            foreach ($this->item->fields as $onadd_key => $onadd_value) {
+                // handle after
+                // we need to manage states_id on both cases (add / update)
+                // because states_id can be configured globally by inventory configuration
+                if ($onadd_key == 'states_id') {
+                    continue;
+                }
+
+                // set value computed on add by GLPI (and rules) to $val
+                // to prevent data loss during updates
+                // only for known keys (from $val)
+                if (property_exists($val, $onadd_key)) {
+                    $val->$onadd_key = $onadd_value;
+                    //update known_list
+                    $known_key = md5($onadd_key . $val->$onadd_key);
+                    $this->known_links[$known_key] = $onadd_value;
+                    $this->raw_links[$known_key] = $onadd_value;
+                }
+            }
         }
 
+        // special case for states_id (no need for entites_id because RuleAsset has no action for entities_id)
+        // when default states is set (> 0) from inventory configuration
+        // force it to be set on the item
+        if ($default_states_id && $default_states_id != '-1') {
+            $val->states_id = $default_states_id;
+        } else {
+            $val->states_id =  $this->item->fields['states_id'];
+        }
+        $known_key = md5('states_id' . $val->states_id);
+        $this->known_links[$known_key] = $val->states_id;
+        $this->raw_links[$known_key] = $val->states_id;
         $val->id = $this->item->fields['id'];
 
         if ($entities_id == -1) {
@@ -753,7 +799,7 @@ abstract class MainAsset extends InventoryAsset
                     'is_dynamic' => 1,
                     ['NOT' => ['domains_id' => $domain->getID()]]
                 ],
-                0,
+                1,
                 0
             );
         }
@@ -796,7 +842,7 @@ abstract class MainAsset extends InventoryAsset
         ]);
 
         if ($this->is_discovery === true && !$this->isNew()) {
-            //if NetworkEquipement
+            //if NetworkEquipment
             //Or printer that has not changed its IP
             //do not update to prevents discoveries to remove all ports, IPs and so on found with network inventory
             if (
@@ -815,6 +861,18 @@ abstract class MainAsset extends InventoryAsset
                     'snmpcredentials_id'    => $input['snmpcredentials_id'],
                     'is_dynamic'            => true
                 ]));
+                //add rule matched log
+                $rulesmatched = new RuleMatchedLog();
+                $inputrulelog = [
+                    'date'      => date('Y-m-d H:i:s'),
+                    'rules_id'  => $rules_id,
+                    'items_id'  => $items_id,
+                    'itemtype'  => $itemtype,
+                    'agents_id' => $this->agent->fields['id'],
+                    'method'    => Request::NETDISCOVERY_TASK
+                ];
+                $rulesmatched->add($inputrulelog, [], false);
+                $rulesmatched->cleanOlddata($items_id, $itemtype);
                 return;
             }
         }
@@ -846,6 +904,12 @@ abstract class MainAsset extends InventoryAsset
         }
 
         $input = $this->handleInput($val, $this->item);
+
+        if ($this->isNew()) {
+            // ONADD were already exececuted, and we want to skip rules that are only ONUPDATE
+            $input['_skip_rules'] = true;
+        }
+
         $this->item->update(Sanitizer::sanitize($input));
 
         if (!($this->item instanceof RefusedEquipment)) {
@@ -998,7 +1062,7 @@ abstract class MainAsset extends InventoryAsset
     /**
      * Set partial inventory
      *
-     * @return Inventory
+     * @return self
      */
     protected function setPartial(): self
     {
