@@ -238,6 +238,7 @@ class Inventory
      */
     public function doInventory($test_rules = false)
     {
+        /** @var \DBmysql $DB */
         global $DB;
 
         //check
@@ -288,7 +289,8 @@ class Inventory
             ) {
                 //if inventory is not partial, we consider following properties are empty if not present; so they'll be removed
                 $empty_props = [
-                    'virtualmachines'
+                    'virtualmachines',
+                    'remote_mgmt'
                 ];
             }
 
@@ -410,9 +412,9 @@ class Inventory
 
 
     /**
-     * Get rawdata
+     * Get raw data
      *
-     * @return array
+     * @return object|null
      */
     public function getRawData(): ?object
     {
@@ -823,7 +825,7 @@ class Inventory
         return $this->metadata;
     }
 
-    public function getMainAsset(): InventoryAsset
+    public function getMainAsset(): MainAsset
     {
         return $this->mainasset;
     }
@@ -888,6 +890,7 @@ class Inventory
      **/
     public static function cronCleanorphans($task)
     {
+        /** @var \DBmysql $DB */
         global $DB;
 
         $cron_status = 0;
