@@ -71,7 +71,7 @@ class Item_Rack extends CommonDBRelation
 
     public static function displayTabContentForItem(CommonGLPI $item, $tabnum = 1, $withtemplate = 0)
     {
-        self::showItems($item, $withtemplate);
+        self::showItems($item);
         return true;
     }
 
@@ -85,6 +85,39 @@ class Item_Rack extends CommonDBRelation
         return $forbidden;
     }
 
+    public static function processMassiveActionsForOneItemtype(
+        MassiveAction $ma,
+        CommonDBTM $item,
+        array $ids
+    ) {
+        switch ($ma->getAction()) {
+            case 'delete':
+                $input = $ma->getInput();
+                $item_rack = new Item_Rack();
+                foreach ($ids as $id) {
+                    if ($item->can($id, UPDATE, $input)) {
+                        $relation_criteria = [
+                            'itemtype' => $item->getType(),
+                            'items_id' => $item->getID()
+                        ];
+                        if (countElementsInTable(Item_Rack::getTable(), $relation_criteria) > 0) {
+                            if ($item_rack->deleteByCriteria($relation_criteria)) {
+                                $ma->itemDone($item->getType(), $id, MassiveAction::ACTION_OK);
+                            } else {
+                                $ma->itemDone($item->getType(), $id, MassiveAction::ACTION_KO);
+                                $ma->addMessage($item->getErrorMessage(ERROR_ON_ACTION));
+                            }
+                        }
+                    } else {
+                        $ma->itemDone($item->getType(), $id, MassiveAction::ACTION_NORIGHT);
+                        $ma->addMessage($item->getErrorMessage(ERROR_RIGHT));
+                    }
+                }
+                return;
+        }
+        parent::processMassiveActionsForOneItemtype($ma, $item, $ids);
+    }
+
     /**
      * Print racks items
      * @param  Rack   $rack the current rack instance
@@ -92,7 +125,11 @@ class Item_Rack extends CommonDBRelation
      */
     public static function showItems(Rack $rack)
     {
-        global $DB, $CFG_GLPI;
+        /**
+         * @var array $CFG_GLPI
+         * @var \DBmysql $DB
+         */
+        global $CFG_GLPI, $DB;
 
         $ID = $rack->getID();
         $rand = mt_rand();
@@ -411,6 +448,7 @@ JAVASCRIPT;
      */
     public static function showStats(Rack $rack)
     {
+        /** @var \DBmysql $DB */
         global $DB;
 
         $items = $DB->request([
@@ -500,7 +538,11 @@ JAVASCRIPT;
 
     public function showForm($ID, array $options = [])
     {
-        global $DB, $CFG_GLPI;
+        /**
+         * @var array $CFG_GLPI
+         * @var \DBmysql $DB
+         */
+        global $CFG_GLPI, $DB;
 
         $colspan = 4;
 
@@ -857,7 +899,7 @@ JAVASCRIPT;
          </div>";
         }
 
-        return false;
+        return '';
     }
 
 
@@ -904,7 +946,7 @@ JAVASCRIPT;
      *
      * @param array $input Input data
      *
-     * @return array
+     * @return false|array
      */
     private function prepareInput($input)
     {
