@@ -144,6 +144,7 @@ class Item_SoftwareLicense extends CommonDBRelation
                 return true;
 
             case 'add_item':
+                /** @var array $CFG_GLPI */
                 global $CFG_GLPI;
                 echo "<table class='tab_cadre_fixe'>";
                 echo "<tr class='tab_bg_2 center'>";
@@ -289,6 +290,7 @@ class Item_SoftwareLicense extends CommonDBRelation
      **/
     public static function countForLicense($softwarelicenses_id, $entity = '', $itemtype = null)
     {
+        /** @var \DBmysql $DB */
         global $DB;
 
         $iterator = $DB->request([
@@ -357,6 +359,7 @@ class Item_SoftwareLicense extends CommonDBRelation
      **/
     public static function countForSoftware($softwares_id)
     {
+        /** @var \DBmysql $DB */
         global $DB;
 
         $license_table = SoftwareLicense::getTable();
@@ -435,6 +438,7 @@ class Item_SoftwareLicense extends CommonDBRelation
      **/
     public static function showForLicenseByEntity(SoftwareLicense $license)
     {
+        /** @var \DBmysql $DB */
         global $DB;
 
         $softwarelicense_id = $license->getField('id');
@@ -514,7 +518,11 @@ class Item_SoftwareLicense extends CommonDBRelation
      **/
     public static function showForLicense(SoftwareLicense $license)
     {
-        global $DB, $CFG_GLPI;
+        /**
+         * @var array $CFG_GLPI
+         * @var \DBmysql $DB
+         */
+        global $CFG_GLPI, $DB;
 
         $searchID = $license->getField('id');
 
@@ -757,8 +765,8 @@ JAVASCRIPT;
                     $DB->quoteValue('') . " AS " . $DB->quoteName('state')
                 );
             }
-            $group_fkey  = State::getForeignKeyField();
-            $group_table = State::getTable();
+            $group_fkey  = Group::getForeignKeyField();
+            $group_table = Group::getTable();
             if ($DB->fieldExists($itemtable, $group_fkey)) {
                 $query['SELECT'][] = sprintf('%s.name AS groupe', $group_table);
                 $query['LEFT JOIN'][$group_table] = [
@@ -954,6 +962,7 @@ JAVASCRIPT;
      **/
     public static function getLicenseForInstallation($itemtype, $items_id, $softwareversions_id)
     {
+        /** @var \DBmysql $DB */
         global $DB;
 
         $lic = [];
@@ -1050,6 +1059,7 @@ JAVASCRIPT;
      **/
     public static function countLicenses($softwares_id)
     {
+        /** @var \DBmysql $DB */
         global $DB;
 
         $result = $DB->request([
