@@ -186,6 +186,7 @@ class Item_Ticket extends CommonItilObject_Item
      **/
     public static function itemAddForm(Ticket $ticket, $options = [])
     {
+        /** @var array $CFG_GLPI */
         global $CFG_GLPI;
 
         $params = [
@@ -382,13 +383,13 @@ class Item_Ticket extends CommonItilObject_Item
 
         $types_iterator = self::getDistinctTypes($instID);
         $number = count($types_iterator);
-
+        $ticket_closed = in_array($ticket->fields['status'], array_merge(
+            $ticket->getClosedStatusArray(),
+            $ticket->getSolvedStatusArray()
+        ));
         if (
             $canedit
-            && !in_array($ticket->fields['status'], array_merge(
-                $ticket->getClosedStatusArray(),
-                $ticket->getSolvedStatusArray()
-            ))
+            && !$ticket_closed
         ) {
             echo "<div class='firstbloc'>";
             echo "<form name='ticketitem_form$rand' id='ticketitem_form$rand' method='post'
@@ -426,9 +427,8 @@ class Item_Ticket extends CommonItilObject_Item
             Html::closeForm();
             echo "</div>";
         }
-
         echo "<div class='spaced'>";
-        if ($canedit && $number) {
+        if ($canedit && $number && !$ticket_closed) {
             Html::openMassiveActionsForm('mass' . __CLASS__ . $rand);
             $massiveactionparams = ['container' => 'mass' . __CLASS__ . $rand];
             Html::showMassiveActions($massiveactionparams);
@@ -438,7 +438,7 @@ class Item_Ticket extends CommonItilObject_Item
         $header_top    = '';
         $header_bottom = '';
         $header_end    = '';
-        if ($canedit && $number) {
+        if ($canedit && $number && !$ticket_closed) {
             $header_top    .= "<th width='10'>" . Html::getCheckAllAsCheckbox('mass' . __CLASS__ . $rand);
             $header_top    .= "</th>";
             $header_bottom .= "<th width='10'>" . Html::getCheckAllAsCheckbox('mass' . __CLASS__ . $rand);
@@ -483,7 +483,7 @@ class Item_Ticket extends CommonItilObject_Item
                     }
 
                     echo "<tr class='tab_bg_1'>";
-                    if ($canedit) {
+                    if ($canedit && !$ticket_closed) {
                         echo "<td width='10'>";
                         Html::showMassiveActionCheckBox(__CLASS__, $data["linkid"]);
                         echo "</td>";
@@ -520,7 +520,7 @@ class Item_Ticket extends CommonItilObject_Item
         }
 
         echo "</table>";
-        if ($canedit && $number) {
+        if ($canedit && $number && !$ticket_closed) {
             $massiveactionparams['ontop'] = false;
             Html::showMassiveActions($massiveactionparams);
             Html::closeForm();
@@ -583,7 +583,11 @@ class Item_Ticket extends CommonItilObject_Item
      **/
     public static function dropdownMyDevices($userID = 0, $entity_restrict = -1, $itemtype = 0, $items_id = 0, $options = [])
     {
-        global $DB, $CFG_GLPI;
+        /**
+         * @var array $CFG_GLPI
+         * @var \DBmysql $DB
+         */
+        global $CFG_GLPI, $DB;
 
         $params = ['tickets_id' => 0,
             'used'       => [],
@@ -928,6 +932,7 @@ class Item_Ticket extends CommonItilObject_Item
      **/
     public static function dropdown($options = [])
     {
+        /** @var \DBmysql $DB */
         global $DB;
 
        // Default values
@@ -1012,6 +1017,7 @@ class Item_Ticket extends CommonItilObject_Item
      **/
     public static function showFormMassiveAction($ma)
     {
+        /** @var array $CFG_GLPI */
         global $CFG_GLPI;
 
         switch ($ma->getAction()) {
