@@ -87,7 +87,11 @@ class KnowbaseItem_Revision extends CommonDBTM
      **/
     public static function showForItem(CommonDBTM $item, $withtemplate = 0)
     {
-        global $DB, $CFG_GLPI;
+        /**
+         * @var array $CFG_GLPI
+         * @var \DBmysql $DB
+         */
+        global $CFG_GLPI, $DB;
 
         $item_id = $item->getID();
         $item_type = $item::getType();
@@ -97,19 +101,20 @@ class KnowbaseItem_Revision extends CommonDBTM
             $start = 0;
         }
 
-       // Total Number of revisions
+        $kb_item_id = 0;
+        $language   = '';
         if ($item->getType() == KnowbaseItem::getType()) {
-            $where = [
-                'knowbaseitems_id' => $item->getID(),
-                'language'         => ''
-            ];
+            $kb_item_id = $item->getID();
         } else {
-            $where = [
-                'knowbaseitems_id' => $item->fields['knowbaseitems_id'],
-                'language'         => $item->fields['language']
-            ];
+            $kb_item_id = $item->fields['knowbaseitems_id'];
+            $language   = $item->fields['language'];
         }
+        $where = [
+            'knowbaseitems_id' => $kb_item_id,
+            'language'         => $language,
+        ];
 
+        // Total Number of revisions
         $number = countElementsInTable(
             'glpi_knowbaseitems_revisions',
             $where
@@ -242,7 +247,7 @@ class KnowbaseItem_Revision extends CommonDBTM
                   data: {
                      oldid :  _oldid,
                      diffid: _diffid,
-                     kbid  : '{$revision['knowbaseitems_id']}'
+                     kbid  : '{$kb_item_id}'
                   }
                }).done(function(data) {
                   if (_diffid == 0) {
@@ -356,6 +361,7 @@ class KnowbaseItem_Revision extends CommonDBTM
      */
     private function getNewRevision()
     {
+        /** @var \DBmysql $DB */
         global $DB;
 
         $result = $DB->request([
