@@ -203,7 +203,8 @@ abstract class LevelAgreement extends CommonDBChild
         echo "<tr class='tab_bg_1'><td>" . __('Maximum time') . "</td>";
         echo "<td>";
         Dropdown::showNumber("number_time", ['value' => $this->fields["number_time"],
-            'min'   => 0
+            'min'   => 0,
+            'max'   => 1000
         ]);
         $possible_values = self::getDefinitionTimeValues();
         $rand = Dropdown::showFromArray(
@@ -330,6 +331,7 @@ abstract class LevelAgreement extends CommonDBChild
      */
     public static function showForSLM(SLM $slm)
     {
+        /** @var array $CFG_GLPI */
         global $CFG_GLPI;
 
         if (!$slm->can($slm->fields['id'], READ)) {
@@ -467,6 +469,7 @@ abstract class LevelAgreement extends CommonDBChild
      */
     public function showRulesList()
     {
+        /** @var \DBmysql $DB */
         global $DB;
 
         $fk      = static::getFieldNames($this->fields['type'])[1];
@@ -600,6 +603,7 @@ abstract class LevelAgreement extends CommonDBChild
      */
     public function getDataForTicket($tickets_id, $type)
     {
+        /** @var \DBmysql $DB */
         global $DB;
 
         list($dateField, $field) = static::getFieldNames($type);
@@ -856,6 +860,19 @@ abstract class LevelAgreement extends CommonDBChild
         return null;
     }
 
+    /**
+     * Should calculation on this LevelAgreement target date be done using
+     * the "work_in_day" parameter set to true ?
+     *
+     * @return bool
+     */
+    public function shouldUseWorkInDayMode(): bool
+    {
+        return
+            $this->fields['definition_time'] == 'day'
+            || $this->fields['definition_time'] == 'month'
+        ;
+    }
 
     /**
      * Get execution date of a level
@@ -875,22 +892,39 @@ abstract class LevelAgreement extends CommonDBChild
 
             if ($level->getFromDB($levels_id)) { // level exists
                 if ($level->fields[$fk] == $this->fields['id']) { // correct level
-                    $work_in_days = ($this->fields['definition_time'] == 'day' || $this->fields['definition_time'] == 'month');
                     $delay        = $this->getTime();
 
-                   // Based on a calendar
+                    // Based on a calendar
                     if ($this->fields['calendars_id'] > 0) {
                         $cal = new Calendar();
                         if ($cal->getFromDB($this->fields['calendars_id']) && $cal->hasAWorkingDay()) {
-                            return $cal->computeEndDate(
+                            // Take SLA into account
+                            $date_with_sla = $cal->computeEndDate(
                                 $start_date,
                                 $delay,
-                                $level->fields['execution_time'] + $additional_delay,
-                                $work_in_days
+                                0,
+                                $this->shouldUseWorkInDayMode(),
+                                $this->fields['end_of_working_day']
                             );
+
+                            // Take waiting duration time into account
+                            $date_with_waiting_time = $cal->computeEndDate(
+                                $date_with_sla,
+                                $additional_delay,
+                            );
+
+                            // Take current SLA escalation level into account
+                            $date_with_sla_and_escalation_level = $cal->computeEndDate(
+                                $date_with_waiting_time,
+                                $level->fields['execution_time'],
+                                0,
+                                $level->shouldUseWorkInDayMode(),
+                            );
+
+                            return $date_with_sla_and_escalation_level;
                         }
                     }
-                   // No calendar defined or invalid calendar
+                    // No calendar defined or invalid calendar
                     $delay    += $additional_delay + $level->fields['execution_time'];
                     $starttime = strtotime($start_date);
                     $endtime   = $starttime + $delay;
@@ -1068,6 +1102,7 @@ abstract class LevelAgreement extends CommonDBChild
      **/
     public static function deleteLevelsToDo(Ticket $ticket)
     {
+        /** @var \DBmysql $DB */
         global $DB;
 
         $ticketfield = static::$prefix . "levels_id_ttr";
@@ -1089,6 +1124,7 @@ abstract class LevelAgreement extends CommonDBChild
 
     public function cleanDBonPurge()
     {
+        /** @var \DBmysql $DB */
         global $DB;
 
        // Clean levels
@@ -1114,4 +1150,62 @@ abstract class LevelAgreement extends CommonDBChild
 
         Rule::cleanForItemAction($this);
     }
+
+    /**
+     * Getter for the protected $levelclass static property
+     *
+     * @return string
+     */
+    public function getLevelClass(): string
+    {
+        return static::$levelclass;
+    }
+
+    /**
+     * Getter for the protected $levelticketclass static property
+     *
+     * @return string
+     */
+    public function getLevelTicketClass(): string
+    {
+        return static::$levelticketclass;
+    }
+
+    /**
+     * Remove level of previously assigned level agreements for a given ticket
+     *
+     * @param int $tickets_id
+     *
+     * @return void
+     */
+    public function clearInvalidLevels(int $tickets_id): void
+    {
+        // CLear levels of others LA of the same type
+        // e.g. if a new LA TTR was assigned, clear levels from others (= previous) LA TTR
+        $level_ticket_class = $this->getLevelTicketClass();
+        $level_class = $this->getLevelClass();
+        $levels = (new $level_ticket_class())->find([
+            'tickets_id' => $tickets_id,
+            [$level_class::getForeignKeyField() => ['!=', $this->getID()]],
+            [
+                $level_class::getForeignKeyField() => new QuerySubQuery([
+                    'SELECT' => 'id',
+                    'FROM' => $level_class::getTable(),
+                    'WHERE' => [
+                        static::getForeignKeyField() => new QuerySubQuery([
+                            'SELECT' => 'id',
+                            'FROM' => static::getTable(),
+                            'WHERE' => ['type' => $this->fields['type']],
+                        ])
+                    ]
+                ]),
+            ]
+        ]);
+
+        // Delete invalid levels
+        foreach ($levels as $level) {
+            $em = new $level_ticket_class();
+            $em->delete(['id' => $level['id']]);
+        }
+    }
 }
