@@ -7,7 +7,7 @@
  *
  * http://glpi-project.org
  *
- * @copyright 2015-2022 Teclib' and contributors.
+ * @copyright 2015-2023 Teclib' and contributors.
  * @copyright 2003-2014 by the INDEPNET Development Team.
  * @licence   https://www.gnu.org/licenses/gpl-3.0.html
  *
@@ -33,6 +33,7 @@
  * ---------------------------------------------------------------------
  */
 
+use Glpi\Toolbox\Sanitizer;
 use Glpi\Toolbox\URL;
 
 /** Link Class
@@ -268,10 +269,18 @@ class Link extends CommonDBTM
      * @param bool          $safe_url   indicates whether URL should be sanitized or not
      *
      * @return array of link contents (may have several when item have several IP / MAC cases)
+     *
+     * @FIXME Uncomment $safe_url parameter declaration in GLPI 10.1.
      */
-    public static function generateLinkContents($link, CommonDBTM $item, bool $safe_url = true)
+    public static function generateLinkContents($link, CommonDBTM $item/*, bool $safe_url = true*/)
     {
-        global $DB, $CFG_GLPI;
+        $safe_url = func_num_args() === 3 ? func_get_arg(2) : true;
+
+        /**
+         * @var array $CFG_GLPI
+         * @var \DBmysql $DB
+         */
+        global $CFG_GLPI, $DB;
 
        // Replace [FIELD:<field name>]
         $matches = [];
@@ -581,6 +590,7 @@ class Link extends CommonDBTM
      **/
     public static function showForItem(CommonDBTM $item, $withtemplate = 0)
     {
+        /** @var \DBmysql $DB */
         global $DB;
 
         if (!self::canView()) {
@@ -631,6 +641,7 @@ class Link extends CommonDBTM
      **/
     public static function getAllLinksFor($item, $params = [])
     {
+        /** @var array $CFG_GLPI */
         global $CFG_GLPI;
 
         $computedlinks = [];
@@ -655,13 +666,14 @@ class Link extends CommonDBTM
         $file  = trim($params['data']);
 
         if (empty($file)) {
-           // Generate links
-            $links = $item->generateLinkContents($params['link'], $item, true);
+            // Generate links
+            $link_pattern = Sanitizer::unsanitize($params['link']); // generate links from raw pattern
+            $links = $item->generateLinkContents($link_pattern, $item, true);
             $i     = 1;
             foreach ($links as $key => $val) {
+                $val     = htmlspecialchars($val); // encode special chars as value was generated from a raw pattern
                 $name    = (isset($names[$key]) ? $names[$key] : reset($names));
-                $url     = $val;
-                $newlink = "<a href='$url'";
+                $newlink = '<a href="' . $val . '"';
                 if ($params['open_window']) {
                     $newlink .= " target='_blank'";
                 }
@@ -687,9 +699,9 @@ class Link extends CommonDBTM
                     $file = reset($files);
                 }
                 $url             = $CFG_GLPI["root_doc"] . "/front/link.send.php?lID=" . $params['id'] .
-                                 "&amp;itemtype=" . $item->getType() .
-                                 "&amp;id=" . $item->getID() . "&amp;rank=$key";
-                $newlink         = "<a href='$url' target='_blank'>";
+                                 "&itemtype=" . $item->getType() .
+                                 "&id=" . $item->getID() . "&rank=$key";
+                $newlink         = '<a href="' . htmlspecialchars($url) . '" target="_blank">';
                 $newlink        .= "<i class='fa-lg fa-fw fas fa-link'></i>&nbsp;";
                 $linkname        = sprintf(__('%1$s #%2$s'), $name, $i);
                 $newlink        .= sprintf(__('%1$s: %2$s'), $linkname, $val);
@@ -747,6 +759,7 @@ class Link extends CommonDBTM
 
     public static function getLinksDataForItem(CommonDBTM $item)
     {
+        /** @var \DBmysql $DB */
         global $DB;
 
         $restrict = self::getEntityRestrictForItem($item);
