@@ -87,6 +87,9 @@ class Log extends CommonDBTM
 
     public function getTabNameForItem(CommonGLPI $item, $withtemplate = 0)
     {
+        if (!self::canView()) {
+            return '';
+        }
 
         $nb = 0;
         if ($_SESSION['glpishow_count_on_tabs']) {
@@ -154,7 +157,7 @@ class Log extends CommonDBTM
                         && ($val2['rightname'] == $item->fields['name'])
                     ) {
                         $id_search_option = $key2;
-                        $changes          =  [$id_search_option, addslashes($oldval ?? ''), $values[$key]];
+                        $changes          =  [$id_search_option, addslashes($oldval ?? ''), $values[$key] ?? ''];
                     }
                 } else if (
                     ($val2['linkfield'] == $key && $real_type === $item->getType())
@@ -169,7 +172,7 @@ class Log extends CommonDBTM
                             $oldval = CommonTreeDropdown::sanitizeSeparatorInCompletename($oldval);
                             $values[$key] = CommonTreeDropdown::sanitizeSeparatorInCompletename($values[$key]);
                         }
-                        $changes = [$id_search_option, addslashes($oldval ?? ''), $values[$key]];
+                        $changes = [$id_search_option, addslashes($oldval ?? ''), $values[$key] ?? ''];
                     } else {
                        // other cases; link field -> get data from dropdown
                         if ($val2["table"] != 'glpi_auth_tables') {
@@ -217,6 +220,7 @@ class Log extends CommonDBTM
      **/
     public static function history($items_id, $itemtype, $changes, $itemtype_link = '', $linked_action = '0')
     {
+        /** @var \DBmysql $DB */
         global $DB;
 
         $date_mod = $_SESSION["glpi_currenttime"];
@@ -295,8 +299,13 @@ class Log extends CommonDBTM
      **/
     public static function showForItem(CommonDBTM $item, $withtemplate = 0)
     {
+        /** @var array $CFG_GLPI */
         global $CFG_GLPI;
 
+        if (!self::canView()) {
+            return;
+        }
+
         $itemtype = $item->getType();
         $items_id = $item->getField('id');
 
@@ -527,6 +536,7 @@ class Log extends CommonDBTM
                             if ($data['id_search_option']) { // Recent record - see CommonITILObject::getSearchOptionsActors()
                                 $as = $SEARCHOPTION[$data['id_search_option']]['name'];
                             } else { // Old record
+                                $is = $isr = $isa = $iso = false;
                                 switch ($data['itemtype_link']) {
                                     case 'Group':
                                         $is = 'isGroup';
@@ -539,10 +549,6 @@ class Log extends CommonDBTM
                                     case 'Supplier':
                                         $is = 'isSupplier';
                                         break;
-
-                                    default:
-                                        $is = $isr = $isa = $iso = false;
-                                        break;
                                 }
                                 if ($is) {
                                     $iditem = intval(substr($data['new_value'], strrpos($data['new_value'], '(') + 1)); // This is terrible idea
@@ -578,7 +584,7 @@ class Log extends CommonDBTM
                         $tmp['field']   = NOT_AVAILABLE;
                         if ($linktype_field = explode('#', $data["itemtype_link"])) {
                             $linktype     = $linktype_field[0];
-                            $tmp['field'] = $linktype::getTypeName();
+                            $tmp['field'] = is_a($linktype, CommonGLPI::class, true) ? $linktype::getTypeName() : $linktype;
                         }
                         $tmp['change'] = sprintf(
                             __('%1$s: %2$s'),
@@ -782,6 +788,7 @@ class Log extends CommonDBTM
      **/
     public static function getDistinctUserNamesValuesInItemLog(CommonDBTM $item)
     {
+        /** @var \DBmysql $DB */
         global $DB;
 
         $itemtype = $item->getType();
@@ -823,6 +830,7 @@ class Log extends CommonDBTM
      **/
     public static function getDistinctAffectedFieldValuesInItemLog(CommonDBTM $item)
     {
+        /** @var \DBmysql $DB */
         global $DB;
 
         $itemtype = $item->getType();
@@ -996,6 +1004,7 @@ class Log extends CommonDBTM
      **/
     public static function getDistinctLinkedActionValuesInItemLog(CommonDBTM $item)
     {
+        /** @var \DBmysql $DB */
         global $DB;
 
         $itemtype = $item->getType();
@@ -1185,6 +1194,7 @@ class Log extends CommonDBTM
      **/
     public static function convertFiltersValuesToSqlCriteria(array $filters)
     {
+        /** @var \DBmysql $DB */
         global $DB;
 
         $sql_filters = [];
@@ -1281,6 +1291,7 @@ class Log extends CommonDBTM
 
     public static function handleQueue(): void
     {
+        /** @var \DBmysql $DB */
         global $DB;
 
         $queue = static::$queue;
