@@ -81,7 +81,7 @@ class Migration
     protected $output_handler;
 
     /**
-     * @param integer $ver Version number
+     * @param string $ver Version number
      **/
     public function __construct($ver)
     {
@@ -89,6 +89,7 @@ class Migration
         $this->deb = time();
         $this->version = $ver;
 
+        /** @var \Glpi\Console\Application $application */
         global $application;
         if ($application instanceof Application) {
            // $application global variable will be available if Migration is called from a CLI console command
@@ -101,7 +102,7 @@ class Migration
      *
      * @since 0.84
      *
-     * @param integer $ver Version number
+     * @param string $ver Version number
      *
      * @return void
      **/
@@ -197,7 +198,7 @@ class Migration
        // Do not log if more than 3 log error
         if (
             $this->log_errors < 3
-            && !Toolbox::logInFile($log_file_name, $message . ' @ ', true)
+            && !Toolbox::logInFile($log_file_name, $message . ' @\n', true)
         ) {
             $this->log_errors++;
         }
@@ -273,7 +274,7 @@ class Migration
                     } else if (in_array($default_value, ['0', '1'])) {
                         $format .= " DEFAULT '$default_value'";
                     } else {
-                        trigger_error(__('default_value must be 0 or 1'), E_USER_ERROR);
+                        throw new \LogicException('Default value must be 0 or 1.');
                     }
                 }
                 break;
@@ -311,7 +312,7 @@ class Migration
                     } else if (is_numeric($default_value)) {
                         $format .= " DEFAULT '$default_value'";
                     } else {
-                        trigger_error(__('default_value must be numeric'), E_USER_ERROR);
+                        throw new \LogicException('Default value must be numeric.');
                     }
                 }
                 break;
@@ -405,6 +406,7 @@ class Migration
      **/
     public function addField($table, $field, $type, $options = [])
     {
+        /** @var \DBmysql $DB */
         global $DB;
 
         $params['update']    = '';
@@ -448,7 +450,7 @@ class Migration
                     $query = "UPDATE `$table`
                         SET `$field` = " . $params['update'] . " " .
                         $params['condition'] . "";
-                    $DB->queryOrDie($query, $this->version . " set $field in $table");
+                    $DB->doQueryOrDie($query, $this->version . " set $field in $table");
                 }
                 return true;
             }
@@ -476,6 +478,7 @@ class Migration
      **/
     public function changeField($table, $oldfield, $newfield, $type, $options = [])
     {
+        /** @var \DBmysql $DB */
         global $DB;
 
         $params['value']     = null;
@@ -514,7 +517,7 @@ class Migration
                 ($oldfield != $newfield)
                 && $DB->fieldExists($table, $newfield)
             ) {
-                $this->change[$table][] = "DROP `$newfield` ";
+                $this->change[$table][] = $DB->buildDrop($newfield, 'FIELD');
             }
 
             if ($format) {
@@ -538,16 +541,17 @@ class Migration
      **/
     public function dropField($table, $field)
     {
+        /** @var \DBmysql $DB */
         global $DB;
 
         if ($DB->fieldExists($table, $field, false)) {
-            $this->change[$table][] = "DROP `$field`";
+            $this->change[$table][] = $DB->buildDrop($field, 'FIELD');
         }
     }
 
 
     /**
-     * Drop immediatly a table if it exists
+     * Drop immediately a table if it exists
      *
      * @param string $table Table name
      *
@@ -555,10 +559,11 @@ class Migration
      **/
     public function dropTable($table)
     {
+        /** @var \DBmysql $DB */
         global $DB;
 
         if ($DB->tableExists($table)) {
-            $DB->query("DROP TABLE `$table`");
+            $DB->dropTable($table);
         }
     }
 
@@ -620,9 +625,10 @@ class Migration
      **/
     public function dropKey($table, $indexname)
     {
-
+        /** @var \DBmysql $DB */
+        global $DB;
         if (isIndex($table, $indexname)) {
-            $this->change[$table][] = "DROP INDEX `$indexname`";
+            $this->change[$table][] = $DB->buildDrop($indexname, 'INDEX');
         }
     }
 
@@ -637,9 +643,10 @@ class Migration
      **/
     public function dropForeignKeyContraint($table, $keyname)
     {
-
+        /** @var \DBmysql $DB */
+        global $DB;
         if (isForeignKeyContraint($table, $keyname)) {
-            $this->change[$table][] = "DROP FOREIGN KEY `$keyname`";
+            $this->change[$table][] = $DB->buildDrop($keyname, 'FOREIGN KEY');
         }
     }
 
@@ -654,11 +661,12 @@ class Migration
      **/
     public function renameTable($oldtable, $newtable)
     {
+        /** @var \DBmysql $DB */
         global $DB;
 
         if (!$DB->tableExists("$newtable") && $DB->tableExists("$oldtable")) {
             $query = "RENAME TABLE `$oldtable` TO `$newtable`";
-            $DB->queryOrDie($query, $this->version . " rename $oldtable");
+            $DB->doQueryOrDie($query, $this->version . " rename $oldtable");
 
            // Clear possibly forced value of table name.
            // Actually the only forced value in core is for config table.
@@ -717,6 +725,7 @@ class Migration
      **/
     public function copyTable($oldtable, $newtable, bool $insert = true)
     {
+        /** @var \DBmysql $DB */
         global $DB;
 
         if (
@@ -728,12 +737,12 @@ class Migration
            // $DB->query($query);
 
             $query = "CREATE TABLE `$newtable` LIKE `$oldtable`";
-            $DB->queryOrDie($query, $this->version . " create $newtable");
+            $DB->doQueryOrDie($query, $this->version . " create $newtable");
 
             if ($insert) {
                //needs DB::insert to support subqueries to get migrated
                 $query = "INSERT INTO `$newtable` (SELECT * FROM `$oldtable`)";
-                $DB->queryOrDie($query, $this->version . " copy from $oldtable to $newtable");
+                $DB->doQueryOrDie($query, $this->version . " copy from $oldtable to $newtable");
             }
         }
     }
@@ -751,6 +760,7 @@ class Migration
      **/
     public function insertInTable($table, array $input)
     {
+        /** @var \DBmysql $DB */
         global $DB;
 
         if (
@@ -782,12 +792,13 @@ class Migration
      **/
     public function migrationOneTable($table)
     {
+        /** @var \DBmysql $DB */
         global $DB;
 
         if (isset($this->change[$table])) {
             $query = "ALTER TABLE `$table` " . implode(" ,\n", $this->change[$table]) . " ";
             $this->displayMessage(sprintf(__('Change of the database layout - %s'), $table));
-            $DB->queryOrDie($query, $this->version . " multiple alter in $table");
+            $DB->doQueryOrDie($query, $this->version . " multiple alter in $table");
             unset($this->change[$table]);
         }
 
@@ -795,7 +806,7 @@ class Migration
             $this->displayMessage(sprintf(__('Adding fulltext indices - %s'), $table));
             foreach ($this->fulltexts[$table] as $idx) {
                 $query = "ALTER TABLE `$table` " . $idx;
-                $DB->queryOrDie($query, $this->version . " $idx");
+                $DB->doQueryOrDie($query, $this->version . " $idx");
             }
             unset($this->fulltexts[$table]);
         }
@@ -804,7 +815,7 @@ class Migration
             $this->displayMessage(sprintf(__('Adding unicity indices - %s'), $table));
             foreach ($this->uniques[$table] as $idx) {
                 $query = "ALTER TABLE `$table` " . $idx;
-                $DB->queryOrDie($query, $this->version . " $idx");
+                $DB->doQueryOrDie($query, $this->version . " $idx");
             }
             unset($this->uniques[$table]);
         }
@@ -818,10 +829,11 @@ class Migration
      **/
     public function executeMigration()
     {
+        /** @var \DBmysql $DB */
         global $DB;
 
         foreach ($this->queries[self::PRE_QUERY] as $query) {
-            $DB->queryOrDie($query['query'], $query['message']);
+            $DB->doQueryOrDie($query['query'], $query['message']);
         }
         $this->queries[self::PRE_QUERY] = [];
 
@@ -835,7 +847,7 @@ class Migration
         }
 
         foreach ($this->queries[self::POST_QUERY] as $query) {
-            $DB->queryOrDie($query['query'], $query['message']);
+            $DB->doQueryOrDie($query['query'], $query['message']);
         }
         $this->queries[self::POST_QUERY] = [];
 
@@ -860,6 +872,7 @@ class Migration
      **/
     public function createRule(array $rule, array $criteria, array $actions)
     {
+        /** @var \DBmysql $DB */
         global $DB;
 
        // Avoid duplicate - Need to be improved using a rule uuid of other
@@ -919,6 +932,7 @@ class Migration
      **/
     public function updateDisplayPrefs($toadd = [], $todel = [], bool $only_default = false)
     {
+        /** @var \DBmysql $DB */
         global $DB;
 
         //TRANS: %s is the table or item to migrate
@@ -1059,6 +1073,7 @@ class Migration
      */
     public function backupTables($tables)
     {
+        /** @var \DBmysql $DB */
         global $DB;
 
         $backup_tables = false;
@@ -1086,8 +1101,8 @@ class Migration
      *
      * @since 9.2
      *
-     * @param string|array $values  Value(s) to add
-     * @param string       $context Context to add on (optional)
+     * @param array  $values  Value(s) to add
+     * @param string $context Context to add on (optional)
      *
      * @return Migration
      */
@@ -1110,6 +1125,7 @@ class Migration
      */
     private function storeConfig()
     {
+        /** @var \DBmysql $DB */
         global $DB;
 
         foreach ($this->configs as $context => $config) {
@@ -1153,6 +1169,7 @@ class Migration
      */
     public function addRight($name, $rights = ALLSTANDARDRIGHT, $requiredrights = ['config' => READ | UPDATE])
     {
+        /** @var \DBmysql $DB */
         global $DB;
 
        // Get all profiles where new rights has not been added yet
@@ -1237,6 +1254,7 @@ class Migration
      */
     public function addRightByInterface($name, $right, $interface = 'central')
     {
+        /** @var \DBmysql $DB */
         global $DB;
 
         $prof_iterator = $DB->request([
@@ -1304,6 +1322,7 @@ class Migration
      */
     public function updateRight($name, $rights, $requiredrights = ['config' => READ | UPDATE])
     {
+        /** @var \DBmysql $DB */
         global $DB;
 
        // Get all profiles with required rights
@@ -1490,6 +1509,7 @@ class Migration
      */
     public function renameItemtype($old_itemtype, $new_itemtype, $update_structure = true)
     {
+        /** @var \DBmysql $DB */
         global $DB;
 
         if ($old_itemtype == $new_itemtype) {
@@ -1649,6 +1669,7 @@ class Migration
      */
     private function migrateSearchOptions()
     {
+        /** @var \DBmysql $DB */
         global $DB;
 
         if (empty($this->search_opts)) {
@@ -1771,6 +1792,7 @@ class Migration
         string $class_1,
         string $class_2
     ) {
+        /** @var \DBmysql $DB */
         global $DB;
         if ($DB->tableExists($table)) {
             return;
@@ -1783,7 +1805,7 @@ class Migration
         $default_collation = DBConnection::getDefaultCollation();
         $default_key_sign = DBConnection::getDefaultPrimaryKeySignOption();
 
-        $DB->queryOrDie("
+        $DB->doQueryOrDie("
             CREATE TABLE `$table` (
                 `id` int {$default_key_sign} NOT NULL AUTO_INCREMENT,
                 `$fk_1` int {$default_key_sign} NOT NULL DEFAULT '0',
