@@ -115,7 +115,7 @@ class NetworkPortInstantiation extends CommonDBChild
         $this->manageSocket();
     }
 
-    public function post_updateItem($history = 1)
+    public function post_updateItem($history = true)
     {
         $this->manageSocket();
     }
@@ -337,6 +337,7 @@ class NetworkPortInstantiation extends CommonDBChild
         HTMLTableCell $father = null,
         array $options = []
     ) {
+        /** @var \DBmysql $DB */
         global $DB;
 
         $display_options = $options['display_options'];
@@ -432,6 +433,7 @@ class NetworkPortInstantiation extends CommonDBChild
      **/
     public static function getItemsByMac($mac, $wildcard_search = false)
     {
+        /** @var \DBmysql $DB */
         global $DB;
 
         $mac = strtolower($mac);
@@ -543,6 +545,10 @@ class NetworkPortInstantiation extends CommonDBChild
      **/
     public function showNetworkCardField(NetworkPort $netport, $options = [], $recursiveItems = [])
     {
+        /**
+         * @var array $CFG_GLPI
+         * @var \DBmysql $DB
+         */
         global $CFG_GLPI, $DB;
 
         echo "<td>" . DeviceNetworkCard::getTypeName(1) . "</td>\n";
@@ -744,6 +750,7 @@ class NetworkPortInstantiation extends CommonDBChild
      **/
     public function showNetworkPortSelector($recursiveItems, $origin)
     {
+        /** @var \DBmysql $DB */
         global $DB;
 
         if (count($recursiveItems) == 0) {
@@ -991,6 +998,7 @@ class NetworkPortInstantiation extends CommonDBChild
      **/
     public static function dropdownConnect($ID, $options = [])
     {
+        /** @var array $CFG_GLPI */
         global $CFG_GLPI;
 
         $p['name']        = 'networkports_id';
