@@ -7,7 +7,7 @@
  *
  * http://glpi-project.org
  *
- * @copyright 2015-2022 Teclib' and contributors.
+ * @copyright 2015-2023 Teclib' and contributors.
  * @copyright 2003-2014 by the INDEPNET Development Team.
  * @licence   https://www.gnu.org/licenses/gpl-3.0.html
  *
@@ -131,6 +131,7 @@ class NetworkPort_NetworkPort extends CommonDBRelation
     public function connectToHub($ports_id, $hubs_id)
     {
 
+        /** @var \DBmysql $DB */
         global $DB;
 
         $netport = new NetworkPort();
@@ -182,11 +183,12 @@ class NetworkPort_NetworkPort extends CommonDBRelation
      */
     public function disconnectFrom($ports_id)
     {
-        $opposite_id = $this->getOppositeContact($ports_id);
-        if ($opposite_id && $this->getFromDBForNetworkPort($opposite_id) || $this->getFromDBForNetworkPort($ports_id)) {
-            return $this->delete($this->fields);
-        }
-        return true; // Nothing to disconnect
+        return $this->deleteByCriteria([
+            'OR'  => [
+                'networkports_id_1'  => $ports_id,
+                'networkports_id_2'  => $ports_id,
+            ]
+        ]);
     }
 
     /**
