@@ -205,6 +205,7 @@ class Notification extends CommonDBTM
 
     public function showForm($ID, array $options = [])
     {
+        /** @var array $CFG_GLPI */
         global $CFG_GLPI;
 
         $this->initForm($ID, $options);
@@ -318,6 +319,7 @@ class Notification extends CommonDBTM
     public static function getSpecificValueToSelect($field, $name = '', $values = '', array $options = [])
     {
 
+        /** @var array $CFG_GLPI */
         global $CFG_GLPI;
 
         if (!is_array($values)) {
@@ -632,6 +634,7 @@ class Notification extends CommonDBTM
      **/
     public static function getMailingSignature($entity)
     {
+        /** @var array $CFG_GLPI */
         global $CFG_GLPI;
 
         $signature = trim(Entity::getUsedConfig('mailing_signature', $entity, '', ''));
@@ -648,11 +651,15 @@ class Notification extends CommonDBTM
      * @param string $itemtype Item type
      * @param int    $entity   Restrict to entity
      *
-     * @return ResultSet
+     * @return DBmysqlIterator
      **/
     public static function getNotificationsByEventAndType($event, $itemtype, $entity)
     {
-        global $DB, $CFG_GLPI;
+        /**
+         * @var array $CFG_GLPI
+         * @var \DBmysql $DB
+         */
+        global $CFG_GLPI, $DB;
 
         $criteria = [
             'SELECT'    => [
