@@ -106,6 +106,7 @@ class NotificationTemplate extends CommonDBTM
 
     public function showForm($ID, array $options = [])
     {
+        /** @var array $CFG_GLPI */
         global $CFG_GLPI;
 
         if (!Config::canUpdate()) {
@@ -237,7 +238,7 @@ class NotificationTemplate extends CommonDBTM
      * @param $event
      * @param $options      array
      *
-     * @return id of the template in templates_by_languages / false if computation failed
+     * @return false|integer id of the template in templates_by_languages / false if computation failed
      **/
     public function getTemplateByLanguage(
         NotificationTarget $target,
@@ -426,6 +427,29 @@ class NotificationTemplate extends CommonDBTM
         $string = self::processIf($string, $cleandata);
         $string = strtr($string, $cleandata);
 
+        $string = self::convertRelativeGlpiLinksToAbsolute($string);
+
+        return $string;
+    }
+
+    /**
+     * Convert relative links to GLPI nto absolute links.
+     *
+     * @param string $string
+     * @return string
+     */
+    private static function convertRelativeGlpiLinksToAbsolute(string $string): string
+    {
+        /** @var array $CFG_GLPI */
+        global $CFG_GLPI;
+
+        // Convert domain relative links to absolute links
+        $string = preg_replace(
+            '/((?:href)=[\'"])(\/(?:[^\/][^\'"]*)?)([\'"])/',
+            '$1' . $CFG_GLPI['url_base'] . '$2$3',
+            $string
+        );
+
         return $string;
     }
 
@@ -560,6 +584,7 @@ class NotificationTemplate extends CommonDBTM
      **/
     public function getByLanguage($language)
     {
+        /** @var \DBmysql $DB */
         global $DB;
 
         $iterator = $DB->request([
