@@ -97,6 +97,7 @@ class ObjectLock extends CommonDBTM
      **/
     public static function getLockableObjects()
     {
+        /** @var array $CFG_GLPI */
         global $CFG_GLPI;
 
         $ret = [];
@@ -140,6 +141,7 @@ class ObjectLock extends CommonDBTM
      */
     private function getScriptToUnlock()
     {
+        /** @var array $CFG_GLPI */
         global $CFG_GLPI;
 
         $ret = Html::scriptBlock("
@@ -221,6 +223,7 @@ class ObjectLock extends CommonDBTM
      **/
     private function setLockedByMessage()
     {
+        /** @var array $CFG_GLPI */
         global $CFG_GLPI;
 
        // should get locking user info
@@ -335,6 +338,7 @@ class ObjectLock extends CommonDBTM
      **/
     private function lockObject()
     {
+        /** @var array $CFG_GLPI */
         global $CFG_GLPI;
 
         $ret = false;
@@ -413,6 +417,7 @@ class ObjectLock extends CommonDBTM
      **/
     private function getLockedObjectInfo()
     {
+        /** @var array $CFG_GLPI */
         global $CFG_GLPI;
 
         $ret = false;
@@ -455,7 +460,8 @@ class ObjectLock extends CommonDBTM
      **/
     public static function setReadOnlyProfile()
     {
-        global $CFG_GLPI, $_SESSION;
+        /** @var array $CFG_GLPI */
+        global $CFG_GLPI;
 
        // to prevent double set ReadOnlyProfile
         if (!isset($_SESSION['glpilocksavedprofile'])) {
@@ -492,8 +498,6 @@ class ObjectLock extends CommonDBTM
      **/
     public static function revertProfile()
     {
-        global $_SESSION;
-
         if (isset($_SESSION['glpilocksavedprofile'])) {
             $_SESSION['glpiactiveprofile'] = $_SESSION['glpilocksavedprofile'];
             unset($_SESSION['glpilocksavedprofile']);
@@ -510,6 +514,7 @@ class ObjectLock extends CommonDBTM
      **/
     public static function manageObjectLock($itemtype, &$options)
     {
+        /** @var array $CFG_GLPI */
         global $CFG_GLPI;
 
         if (isset($options['id']) && ($options['id'] > 0)) {
@@ -578,6 +583,7 @@ class ObjectLock extends CommonDBTM
 
     public static function rawSearchOptionsToAdd($itemtype)
     {
+        /** @var array $CFG_GLPI */
         global $CFG_GLPI;
         $tab = [];
 
@@ -631,6 +637,7 @@ class ObjectLock extends CommonDBTM
      **/
     public static function getRightsToAdd($itemtype, $interface = 'central')
     {
+        /** @var array $CFG_GLPI */
         global $CFG_GLPI;
 
         $ret = [];
