@@ -81,6 +81,7 @@ class OlaLevel extends LevelAgreementLevel
      **/
     public function showForOLA(OLA $ola)
     {
+        /** @var \DBmysql $DB */
         global $DB;
 
         $ID = $ola->getField('id');
@@ -112,7 +113,8 @@ class OlaLevel extends LevelAgreementLevel
             self::dropdownExecutionTime(
                 'execution_time',
                 ['max_time' => $delay,
-                    'used'     => self::getAlreadyUsedExecutionTime($ola->fields['id'])
+                    'used'     => self::getAlreadyUsedExecutionTime($ola->fields['id']),
+                    'type'     => $ola->fields['type'],
                 ]
             );
 
@@ -262,6 +264,7 @@ class OlaLevel extends LevelAgreementLevel
             'execution_time',
             ['max_time'  => $delay,
                 'used'      => self::getAlreadyUsedExecutionTime($ola->fields['id']),
+                'type'      => $ola->fields['type'],
                 'value'     => $this->fields['execution_time']
             ]
         );
@@ -281,14 +284,15 @@ class OlaLevel extends LevelAgreementLevel
     /**
      * Get first level for a OLA
      *
-     * @param $olas_id   integer  id of the OLA
+     * @param integer $olas_id id of the OLA
      *
      * @since 9.1 (before getFirst OlaLevel)
      *
-     * @return id of the ola level : 0 if not exists
+     * @return integer id of the ola level : 0 if not exists
      **/
     public static function getFirstOlaLevel($olas_id)
     {
+        /** @var \DBmysql $DB */
         global $DB;
 
         $iterator = $DB->request([
@@ -313,13 +317,14 @@ class OlaLevel extends LevelAgreementLevel
     /**
      * Get next level for a OLA
      *
-     * @param $olas_id         integer id of the OLA
-     * @param $olalevels_id    integer id of the current OLA level
+     * @param integer $olas_id      id of the OLA
+     * @param integer $olalevels_id id of the current OLA level
      *
-     * @return id of the ola level : 0 if not exists
+     * @return integer id of the ola level : 0 if not exists
      **/
     public static function getNextOlaLevel($olas_id, $olalevels_id)
     {
+        /** @var \DBmysql $DB */
         global $DB;
 
         $iterator = $DB->request([
