@@ -140,6 +140,7 @@ class PlanningExternalEvent extends CommonDBTM implements CalDAVCompatibleItemIn
 
     public function showForm($ID, array $options = [])
     {
+        /** @var array $CFG_GLPI */
         global $CFG_GLPI;
 
         $canedit    = $this->can($ID, UPDATE);
@@ -157,7 +158,7 @@ class PlanningExternalEvent extends CommonDBTM implements CalDAVCompatibleItemIn
         $this->showFormHeader($options);
 
         $is_ajax  = isset($options['from_planning_edit_ajax']) && $options['from_planning_edit_ajax'];
-        $is_rrule = strlen($this->fields['rrule']) > 0;
+        $is_rrule = strlen($this->fields['rrule'] ?? '') > 0;
 
        // set event for another user
         if (
@@ -202,9 +203,7 @@ class PlanningExternalEvent extends CommonDBTM implements CalDAVCompatibleItemIn
                   }
                   $("#dropdown_background{$rand}").trigger("setValue", data.background);
                   if (data.text.length > 0) {
-                     if (contenttinymce = tinymce.get("text{$rand}")) {
-                        contenttinymce.setContent(data.text);
-                     }
+                     setRichTextEditorContent("text{$rand}", data.text);
                   }
 
                   // set planification fields
@@ -416,6 +415,7 @@ JAVASCRIPT;
     private static function getItemsAsVCalendars(array $criteria)
     {
 
+        /** @var \DBmysql $DB */
         global $DB;
 
         $query = [
