@@ -69,6 +69,7 @@ class PlanningRecall extends CommonDBChild
 
     public static function isAvailable()
     {
+        /** @var array $CFG_GLPI */
         global $CFG_GLPI;
 
        // Cache in session
@@ -85,8 +86,7 @@ class PlanningRecall extends CommonDBChild
                     if (
                         Session::haveRightsOr(
                             "planning",
-                            [Planning::READMY, Planning::READGROUP],
-                            Planning::READALL
+                            [Planning::READMY, Planning::READGROUP, Planning::READALL]
                         )
                     ) {
                         $_SESSION['glpiplanningreminder_isavailable'] = 1;
@@ -122,7 +122,7 @@ class PlanningRecall extends CommonDBChild
     /**
      * @see CommonDBTM::post_updateItem()
      **/
-    public function post_updateItem($history = 1)
+    public function post_updateItem($history = true)
     {
 
         $alert = new Alert();
@@ -222,6 +222,7 @@ class PlanningRecall extends CommonDBChild
      **/
     public static function managePlanningUpdates($itemtype, $items_id, $begin)
     {
+        /** @var \DBmysql $DB */
         global $DB;
 
         if (isset($_SESSION['glpiplanningreminder_isavailable'])) {
@@ -389,7 +390,11 @@ class PlanningRecall extends CommonDBChild
      **/
     public static function cronPlanningRecall($task = null)
     {
-        global $DB, $CFG_GLPI;
+        /**
+         * @var array $CFG_GLPI
+         * @var \DBmysql $DB
+         */
+        global $CFG_GLPI, $DB;
 
         if (!$CFG_GLPI["use_notifications"]) {
             return 0;
