@@ -234,6 +234,7 @@ class ProjectCost extends CommonDBChild
      **/
     public function getLastCostForProject($projects_id)
     {
+        /** @var \DBmysql $DB */
         global $DB;
 
         $iterator = $DB->request([
@@ -317,7 +318,11 @@ class ProjectCost extends CommonDBChild
      **/
     public static function showForProject(Project $project, $withtemplate = 0)
     {
-        global $DB, $CFG_GLPI;
+        /**
+         * @var array $CFG_GLPI
+         * @var \DBmysql $DB
+         */
+        global $CFG_GLPI, $DB;
 
         $ID = $project->fields['id'];
 
