@@ -117,6 +117,7 @@ class ProjectTask_Ticket extends CommonDBRelation
      **/
     public static function getTicketsTotalActionTime($projecttasks_id)
     {
+        /** @var \DBmysql $DB */
         global $DB;
 
         $iterator = $DB->request([
@@ -247,7 +248,11 @@ class ProjectTask_Ticket extends CommonDBRelation
      **/
     public static function showForTicket(Ticket $ticket)
     {
-        global $DB, $CFG_GLPI;
+        /**
+         * @var array $CFG_GLPI
+         * @var \DBmysql $DB
+         */
+        global $CFG_GLPI, $DB;
 
         $ID = $ticket->getField('id');
         if (!$ticket->can($ID, READ)) {
