@@ -209,6 +209,7 @@ class RSSFeed extends CommonDBVisible implements ExtraVisibilityCriteria
     public static function addVisibilityJoins($forceall = false)
     {
        //not deprecated because used in Search
+        /** @var \DBmysql $DB */
         global $DB;
 
        //get and clean criteria
@@ -920,6 +921,7 @@ class RSSFeed extends CommonDBVisible implements ExtraVisibilityCriteria
      **/
     public static function getRSSFeed($url, $cache_duration = DAY_TIMESTAMP)
     {
+        /** @var \Psr\SimpleCache\CacheInterface $GLPI_CACHE */
         global $GLPI_CACHE;
 
         if (Sanitizer::isHtmlEncoded($url)) {
@@ -974,14 +976,18 @@ class RSSFeed extends CommonDBVisible implements ExtraVisibilityCriteria
     /**
      * Show list for central view
      *
-     * @param $personal boolean   display rssfeeds created by me ?
-     * @param $personal $display  if false, return html
+     * @param boolean $personal display rssfeeds created by me?
+     * @param boolean $display  if false, return html
      *
-     * @return void
+     * @return false|void|string
      **/
     public static function showListForCentral(bool $personal = true, bool $display = true)
     {
-        global $DB, $CFG_GLPI;
+        /**
+         * @var array $CFG_GLPI
+         * @var \DBmysql $DB
+         */
+        global $CFG_GLPI, $DB;
 
         $users_id             = Session::getLoginUserID();
 
