@@ -66,7 +66,11 @@ class Report extends CommonGLPI
      **/
     public static function title()
     {
-        global $PLUGIN_HOOKS, $CFG_GLPI;
+        /**
+         * @var array $CFG_GLPI
+         * @var array $PLUGIN_HOOKS
+         */
+        global $CFG_GLPI, $PLUGIN_HOOKS;
 
        // Report generation
        // Default Report included
@@ -183,7 +187,11 @@ class Report extends CommonGLPI
      **/
     public static function showDefaultReport()
     {
-        global $DB, $CFG_GLPI;
+        /**
+         * @var array $CFG_GLPI
+         * @var \DBmysql $DB
+         */
+        global $CFG_GLPI, $DB;
 
        // Title
         echo "<span class='big b'>GLPI " . Report::getTypeName(Session::getPluralNumber()) . "</span><br><br>";
@@ -357,6 +365,7 @@ class Report extends CommonGLPI
         array $order = [],
         $extra = ''
     ) {
+        /** @var \DBmysql $DB */
         global $DB;
 
        // This SQL request matches the NetworkPort, then its NetworkName and IPAddreses. It also
