@@ -197,13 +197,20 @@ final class UserMention
             $dom = new DOMDocument();
             libxml_use_internal_errors(true);
             $dom->loadHTML($content);
-            $content_as_xml = simplexml_import_dom($dom);
+            // TODO In GLPI 10.1, find a way to remove usage of this `@` operator
+            // that was added to prevent Error E_WARNING simplexml_import_dom(): Invalid Nodetype to import
+            // with bad HTML content.
+            $content_as_xml = @simplexml_import_dom($dom);
         } catch (\Throwable $e) {
            // Sanitize process does not handle correctly `<` and `>` chars that are not surrounding html tags.
            // This generates invalid HTML that cannot be loaded by `SimpleXMLElement`.
             return [];
         }
 
+        if ($content_as_xml === null) {
+            return [];
+        }
+
         $mention_elements = $content_as_xml->xpath('//*[@data-user-mention="true"]');
         foreach ($mention_elements as $mention_element) {
             $ids[] = (int)$mention_element->attributes()->{'data-user-id'};
