@@ -48,7 +48,7 @@ class RuleCollection extends CommonDBTM
     public $orderby                               = "ranking";
    /// Processing several rules : use result of the previous one to computer the current one
     public $use_output_rule_process_as_next_input = false;
-   /// Rule collection can be replay (for dictionnary)
+   /// Rule collection can be replay (for dictionary)
     public $can_replay_rules                      = false;
    /// List of rules of the rule collection
     public $RuleList                              = null;
@@ -106,6 +106,7 @@ class RuleCollection extends CommonDBTM
         $condition = 0,
         $children = 0
     ) {
+        /** @var \DBmysql $DB */
         global $DB;
 
         $restrict = $this->getRuleListCriteria([
@@ -208,7 +209,7 @@ class RuleCollection extends CommonDBTM
     /**
      * Get Collection Part : retrieve descriptions of a range of rules
      *
-     * @param $options array of options may be :
+     * @param array $options array of options may be :
      *         - start : first rule (in the result set - default 0)
      *         - limit : max number of rules to retrieve (default 0)
      *         - recursive : boolean get recursive rules
@@ -216,6 +217,7 @@ class RuleCollection extends CommonDBTM
      **/
     public function getCollectionPart($options = [])
     {
+        /** @var \DBmysql $DB */
         global $DB;
 
         $p['start']     = 0;
@@ -252,14 +254,15 @@ class RuleCollection extends CommonDBTM
 
 
     /**
-     * Get Collection Datas : retrieve descriptions and rules
+     * Get Collection Data: retrieve descriptions and rules
      *
-     * @param $retrieve_criteria  Retrieve the criterias of the rules ? (default 0)
-     * @param $retrieve_action    Retrieve the action of the rules ? (default 0)
-     * @param $condition          Retrieve with a specific condition
+     * @param boolean $retrieve_criteria  Retrieve the criteria of the rules ? (default 0)
+     * @param boolean $retrieve_action    Retrieve the action of the rules ? (default 0)
+     * @param integer $condition          Retrieve with a specific condition
      **/
     public function getCollectionDatas($retrieve_criteria = 0, $retrieve_action = 0, $condition = 0)
     {
+        /** @var \DBmysql $DB */
         global $DB;
 
         if ($this->RuleList === null) {
@@ -333,9 +336,9 @@ class RuleCollection extends CommonDBTM
      * Is a confirmation needed before replay on DB ?
      * If needed need to send 'replay_confirm' in POST
      *
-     * @param $target filename : where to go when done
+     * @param string $target filename : where to go when done
      *
-     * @return  true if confirmtion is needed, else false
+     * @return boolean true if confirmation is needed, else false
      **/
     public function warningBeforeReplayRulesOnExistingDB($target)
     {
@@ -346,10 +349,10 @@ class RuleCollection extends CommonDBTM
     /**
      * Replay Collection on DB
      *
-     * @param $offset             first row to work on (default 0)
-     * @param $maxtime   float    max system time to stop working (default 0)
-     * @param $items     array    containg items to replay. If empty -> all
-     * @param $params    array    additional parameters if needed
+     * @param integer $offset  first row to work on (default 0)
+     * @param float   $maxtime max system time to stop working (default 0)
+     * @param array   $items   array containing items to replay. If empty -> all
+     * @param array   $params  array additional parameters if needed
      *
      * @return int|false -1 if all rows done, else offset for next run, or false on error
      **/
@@ -362,7 +365,7 @@ class RuleCollection extends CommonDBTM
     /**
      * Get title used in list of rules
      *
-     * @return Title of the rule collection
+     * @return string Title of the rule collection
      **/
     public function getTitle()
     {
@@ -372,6 +375,8 @@ class RuleCollection extends CommonDBTM
 
     /**
      * Indicates if the rule can be affected to an entity or if it's global
+     *
+     * @return boolean
      **/
     public function isRuleEntityAssigned()
     {
@@ -383,6 +388,8 @@ class RuleCollection extends CommonDBTM
 
     /**
      * Indicates if the rule can be affected to an entity or if it's global
+     *
+     * @return boolean
      **/
     public function isRuleRecursive()
     {
@@ -393,6 +400,8 @@ class RuleCollection extends CommonDBTM
 
     /**
      * Indicates if the rule use conditions
+     *
+     * @return boolean
      **/
     public function isRuleUseConditions()
     {
@@ -402,14 +411,16 @@ class RuleCollection extends CommonDBTM
     }
 
     /**
-     * Indicates if the rule use conditions
+     * Get default rule conditions
+     *
+     * @return integer
      **/
     public function getDefaultRuleConditionForList()
     {
 
         $rule = $this->getRuleClass();
         $cond = $rule->getConditionsArray();
-       // Get max value
+        // Get max value
         if (count($cond)) {
             return max(array_keys($cond));
         }
@@ -421,7 +432,7 @@ class RuleCollection extends CommonDBTM
 
         echo "<table class='tab_cadre_fixe'><tr><th>";
 
-       //Display information about the how the rules engine process the rules
+       //Display information about how the rules engine process the rules
         if ($this->stop_on_first_match) {
            //The engine stop on the first matched rule
             echo "<span class='center b'>" . __('The engine stops on the first checked rule.') .
@@ -452,13 +463,14 @@ class RuleCollection extends CommonDBTM
     /**
      * Show the list of rules
      *
-     * @param $target
-     * @param $options   array
+     * @param string $target
+     * @param array $options
      *
      * @return void
      **/
     public function showListRules($target, $options = [])
     {
+        /** @var array $CFG_GLPI */
         global $CFG_GLPI;
 
         $p['inherited'] = 1;
@@ -705,7 +717,7 @@ JAVASCRIPT;
     /**
      * Show the list of rules
      *
-     * @param $target
+     * @param string $target
      *
      * @return void
      **/
@@ -717,12 +729,15 @@ JAVASCRIPT;
     /**
      * Modify rule's ranking and automatically reorder all rules
      *
-     * @param $ID     the rule ID whose ranking must be modified
-     * @param $action up or down
-     * @param $condition action on a specific condition
+     * @param integer $ID        rule ID whose ranking must be modified
+     * @param string  $action    up or down
+     * @param integer $condition action on a specific condition
+     *
+     * @return boolean
      **/
     public function changeRuleOrder($ID, $action, $condition = 0)
     {
+        /** @var \DBmysql $DB */
         global $DB;
 
         $criteria = [
@@ -840,12 +855,13 @@ JAVASCRIPT;
     /**
      * Update Rule Order when deleting a rule
      *
-     * @param $ranking rank of the deleted rule
+     * @param integer $ranking rank of the deleted rule
      *
-     * @return true if all ok
+     * @return boolean
      **/
     public function deleteRuleOrder($ranking)
     {
+        /** @var \DBmysql $DB */
         global $DB;
 
         $result = $DB->update(
@@ -873,6 +889,7 @@ JAVASCRIPT;
      **/
     public function moveRule($ID, $ref_ID, $type = self::MOVE_AFTER)
     {
+        /** @var \DBmysql $DB */
         global $DB;
 
         $ruleDescription = new Rule();
@@ -965,6 +982,7 @@ JAVASCRIPT;
      **/
     public static function titleBackup()
     {
+        /** @var array $CFG_GLPI */
         global $CFG_GLPI;
 
         $base_url = "{$CFG_GLPI["root_doc"]}/front/rule.backup.php";
@@ -1137,9 +1155,9 @@ JAVASCRIPT;
      *
      * @since 0.85
      *
-     * @param $available_criteria    available criterai for this rule
-     * @param $condition             the rulecriteria condition
-     * @param $criterion             the criterion
+     * @param array   $available_criteria available criteria for this rule
+     * @param integer $condition          the rulecriteria condition
+     * @param stirng  $criterion          the criterion
      *
      * @return true if a criterion is a dropdown, false otherwise
      **/
@@ -1164,10 +1182,11 @@ JAVASCRIPT;
      *
      * @since 0.85
      *
-     * @return true if all ok
+     * @return boolean
      **/
     public static function previewImportRules()
     {
+        /** @var \DBmysql $DB */
         global $DB;
 
         if (!isset($_FILES["xml_file"]) || ($_FILES["xml_file"]["size"] == 0)) {
@@ -1224,6 +1243,11 @@ JAVASCRIPT;
                 }
 
                 foreach ($rule['rulecriteria'] as $k_crit => $criteria) {
+                    // Fix patterns decoded as empty arrays to prevent empty IN clauses in SQL generation.
+                    if (is_array($criteria['pattern']) && empty($criteria['pattern'])) {
+                        $criteria['pattern'] = '';
+                    }
+
                     $available_criteria = $tmprule->getCriterias();
                     $crit               = $criteria['criteria'];
                    //check FK (just in case of "is", "is_not" and "under" criteria)
@@ -1261,6 +1285,10 @@ JAVASCRIPT;
                 }
 
                 foreach ($rule['ruleaction'] as $k_action => $action) {
+                    // Fix values decoded as empty arrays to prevent empty IN clauses in SQL generation.
+                    if (is_array($action['value']) && empty($action['value'])) {
+                        $action['value'] = '';
+                    }
                     $available_actions = $tmprule->getActions();
                     $act               = $action['field'];
 
@@ -1271,9 +1299,9 @@ JAVASCRIPT;
                     ) {
                        //pass root entity and empty array (N/A value)
                         if (
-                            ($action['field'] == "entities_id")
+                            (in_array($action['value'], ['entities_id', 'new_entities_id'], true))
                             && (($action['value'] == 0)
-                            || ($action['value'] == []))
+                            || ($action['value'] == ''))
                         ) {
                             continue;
                         }
@@ -1448,10 +1476,11 @@ JAVASCRIPT;
      *
      * @since 0.85
      *
-     * @return true if all ok
+     * @return boolean
      **/
     public static function processImportRules()
     {
+        /** @var \DBmysql $DB */
         global $DB;
         $ruleCriteria = new RuleCriteria();
         $ruleAction   = new RuleAction();
@@ -1587,14 +1616,14 @@ JAVASCRIPT;
     /**
      * Process all the rules collection
      *
-     * @param input            array the input data used to check criterias (need to be clean slashes)
-     * @param output           array the initial ouput array used to be manipulate by actions (need to be clean slashes)
-     * @param params           array parameters for all internal functions (need to be clean slashes)
-     * @param options          array options :
-     *                            - condition : specific condition to limit rule list
-     *                            - only_criteria : only react on specific criteria
+     * @param array $input    Input data used to check criterias (need to be clean slashes)
+     * @param array $output   Initial ouput array used to be manipulate by actions (need to be clean slashes)
+     * @param array $params   Parameters for all internal functions (need to be clean slashes)
+     * @param array $options  Options :
+     *                         - condition : specific condition to limit rule list
+     *                         - only_criteria : only react on specific criteria
      *
-     * @return the output array updated by actions (addslashes datas)
+     * @return array the output array updated by actions (addslashes datas)
      **/
     public function processAllRules($input = [], $output = [], $params = [], $options = [])
     {
@@ -1608,23 +1637,32 @@ JAVASCRIPT;
             }
         }
 
-       // Get Collection datas
+        // Get Collection datas
         $this->getCollectionDatas(1, 1, $p['condition']);
         $input                      = $this->prepareInputDataForProcessWithPlugins($input, $params);
         $output["_no_rule_matches"] = true;
-       //Store rule type being processed (for plugins)
+
+        //Store rule type being processed (for plugins)
         $params['rule_itemtype']    = $this->getRuleClassName();
 
         if (count($this->RuleList->list)) {
             /** @var Rule $rule */
             foreach ($this->RuleList->list as $rule) {
+                if ($p['condition'] && !($rule->fields['condition'] & $p['condition'])) {
+                    // Rule is loaded in the cache but is not relevant for the current condition
+                    continue;
+                }
+
                //If the rule is active, process it
 
                 if ($rule->fields["is_active"]) {
                     $output["_rule_process"] = false;
                     $rule->process($input, $output, $params, $p);
 
-                    if ((isset($output['_stop_rules_processing']) && (int) $output['_stop_rules_processing'] === 1) || ($output["_rule_process"] && $this->stop_on_first_match)) {
+                    if (
+                        (isset($output['_stop_rules_processing']) && (int) $output['_stop_rules_processing'] === 1)
+                        || ($output["_rule_process"] && $this->stop_on_first_match)
+                    ) {
                         unset($output["_stop_rules_processing"], $output["_rule_process"]);
                         $output["_ruleid"] = $rule->fields["id"];
                         return Toolbox::addslashes_deep($output);
@@ -1645,9 +1683,11 @@ JAVASCRIPT;
     /**
      * Show form displaying results for rule collection preview
      *
-     * @param $target          where to go
-     * @param $values    array of data
-     * @param $condition       condition to limit rules (default 0)
+     * @param string  $target    where to go
+     * @param array   $values    array of data
+     * @param integer $condition condition to limit rules (default 0)
+     *
+     * @return array
      **/
     public function showRulesEnginePreviewCriteriasForm($target, array $values, $condition = 0)
     {
@@ -1711,12 +1751,12 @@ JAVASCRIPT;
     /**
      * Test all the rules collection
      *
-     * @param input      array the input data used to check criterias
-     * @param output     array the initial ouput array used to be manipulate by actions
-     * @param params     array parameters for all internal functions
-     * @param $condition       condition to limit rules (DEFAULT 0)
+     * @param array   $input     array the input data used to check criterias
+     * @param array   $output    array the initial output array used to be manipulated by actions
+     * @param array   $params    array parameters for all internal functions
+     * @param integer $condition condition to limit rules (DEFAULT 0)
      *
-     * @return the output array updated by actions
+     * @return array the output array updated by actions
      **/
     public function testAllRules($input = [], $output = [], $params = [], $condition = 0)
     {
@@ -1761,12 +1801,12 @@ JAVASCRIPT;
 
 
     /**
-     * Prepare input datas for the rules collection
+     * Prepare input data for the rules collection
      *
-     * @param $input  the input data used to check criterias
-     * @param $params parameters
+     * @param array $input  the input data used to check criteria
+     * @param array $params parameters
      *
-     * @return the updated input datas
+     * @return array the updated input data
      **/
     public function prepareInputDataForProcess($input, $params)
     {
@@ -1779,13 +1819,14 @@ JAVASCRIPT;
      *
      * @since 0.84
      *
-     * @param $input  the input data used to check criterias
-     * @param $params parameters
+     * @param array $input  the input data used to check criterias
+     * @param array $params parameters
      *
-     * @return the updated input datas
+     * @return array the updated input datas
      **/
     public function prepareInputDataForProcessWithPlugins($input, $params)
     {
+        /** @var array $PLUGIN_HOOKS */
         global $PLUGIN_HOOKS;
 
         $input = $this->prepareInputDataForProcess($input, $params);
@@ -1817,14 +1858,15 @@ JAVASCRIPT;
 
 
     /**
-     * Prepare input datas for the rules collection
+     * Prepare input data for the rules collection
      *
-     * @param $condition condition to limit rules (DEFAULT 0)
+     * @param integer $condition condition to limit rules (DEFAULT 0)
      *
-     * @return the updated input datas
+     * @return array the updated input data
      **/
     public function prepareInputDataForTestProcess($condition = 0)
     {
+        /** @var \DBmysql $DB */
         global $DB;
 
         $limit = [];
@@ -1861,9 +1903,11 @@ JAVASCRIPT;
     /**
      * Show form displaying results for rule engine preview
      *
-     * @param $target          where to go
-     * @param $input     array of data
-     * @param $condition       condition to limit rules (DEFAULT 0)
+     * @param string  $target    where to go
+     * @param array   $input     array of data
+     * @param integer $condition condition to limit rules (DEFAULT 0)
+     *
+     * @return void
      **/
     public function showRulesEnginePreviewResultsForm($target, array $input, $condition = 0)
     {
@@ -1918,11 +1962,11 @@ JAVASCRIPT;
 
 
     /**
-     * Unset criterias from the rule's ouput results (begins by _)
+     * Unset criteria from the rule's ouput results (begins by _)
      *
-     * @param $output    array clean output array to clean
+     * @param array $output array clean output array to clean
      *
-     * @return cleaned array
+     * @return array cleaned array
      **/
     public function cleanTestOutputCriterias(array $output)
     {
@@ -1943,9 +1987,9 @@ JAVASCRIPT;
     /**
      * Show test results for a rule
      *
-     * @param $rule                     rule object
-     * @param $output          array    output data array
-     * @param $global_result   boolean  global result
+     * @param Rule    $rule          rule object
+     * @param array   $output        output data array
+     * @param boolean $global_result global result
      *
      * @return void
      **/
@@ -1975,10 +2019,13 @@ JAVASCRIPT;
 
 
     /**
-     * @param $output
+     * @param array $output
+     *
+     * @return array
      **/
     public function preProcessPreviewResults($output)
     {
+        /** @var array $PLUGIN_HOOKS */
         global $PLUGIN_HOOKS;
 
         if (isset($PLUGIN_HOOKS['use_rules'])) {
@@ -2020,14 +2067,15 @@ JAVASCRIPT;
     /**
      * Get rulecollection classname by giving his itemtype
      *
-     * @param $itemtype                 itemtype
-     * @param $check_dictionnary_type   check if the itemtype is a dictionnary or not
+     * @param string  $itemtype               itemtype
+     * @param boolean $check_dictionnary_type check if the itemtype is a dictionary or not
      *                                  (false by default)
      *
      * @return RuleCollection|null
      */
     public static function getClassByType($itemtype, $check_dictionnary_type = false)
     {
+        /** @var array $CFG_GLPI */
         global $CFG_GLPI;
 
         if ($plug = isPluginItemType($itemtype)) {
@@ -2066,9 +2114,12 @@ JAVASCRIPT;
 
     /**
      * Get all the fields needed to perform the rule
+     *
+     * @return array
      **/
     public function getFieldsToLookFor()
     {
+        /** @var \DBmysql $DB */
         global $DB;
 
         $params = [];
@@ -2102,6 +2153,8 @@ JAVASCRIPT;
      * For tabs management : force isNewItem
      *
      * @since 0.83
+     *
+     * @return boolean
      **/
     public function isNewItem()
     {
@@ -2109,9 +2162,6 @@ JAVASCRIPT;
     }
 
 
-    /**
-     * @see CommonGLPI::defineTabs()
-     **/
     public function defineTabs($options = [])
     {
 
@@ -2131,9 +2181,6 @@ JAVASCRIPT;
         return _n('Rule', 'Rules', Session::getPluralNumber());
     }
 
-    /**
-     * @see CommonGLPI::getTabNameForItem()
-     **/
     public function getTabNameForItem(CommonGLPI $item, $withtemplate = 0)
     {
 
@@ -2208,6 +2255,7 @@ JAVASCRIPT;
      */
     public static function getRules(): array
     {
+        /** @var array $CFG_GLPI */
         global $CFG_GLPI;
 
         $rules = [];
@@ -2257,7 +2305,7 @@ JAVASCRIPT;
 
 
     /**
-     * Get list of dictionnaries
+     * Get list of dictionaries
      *
      * @return array
      */
