@@ -46,9 +46,6 @@ class RuleCriteria extends CommonDBChild
 
 
 
-    /**
-     * @since 0.84
-     **/
     public function getForbiddenStandardMassiveAction()
     {
 
@@ -59,7 +56,9 @@ class RuleCriteria extends CommonDBChild
 
 
     /**
-     * @param $rule_type (default 'Rule)
+     * @param string $rule_type (default 'Rule)
+     *
+     * @return void
      **/
     public function __construct($rule_type = 'Rule')
     {
@@ -67,11 +66,6 @@ class RuleCriteria extends CommonDBChild
     }
 
 
-    /**
-     * @since 0.84.3
-     *
-     * @see CommonDBTM::post_getFromDB()
-     */
     public function post_getFromDB()
     {
 
@@ -88,9 +82,9 @@ class RuleCriteria extends CommonDBChild
     /**
      * Get title used in rule
      *
-     * @param $nb  integer  for singular or plural (default 0)
+     * @param integer $nb for singular or plural (default 0)
      *
-     * @return Title of the rule
+     * @return string Title of the rule
      **/
     public static function getTypeName($nb = 0)
     {
@@ -108,11 +102,6 @@ class RuleCriteria extends CommonDBChild
         return '';
     }
 
-    /**
-     * @since 0.84
-     *
-     * @see CommonDBChild::post_addItem()
-     **/
     public function post_addItem()
     {
 
@@ -128,11 +117,6 @@ class RuleCriteria extends CommonDBChild
     }
 
 
-    /**
-     * @since 0.84
-     *
-     * @see CommonDBTM::post_purgeItem()
-     **/
     public function post_purgeItem()
     {
 
@@ -148,9 +132,6 @@ class RuleCriteria extends CommonDBChild
     }
 
 
-    /**
-     * @since 0.84
-     **/
     public function prepareInputForAdd($input)
     {
 
@@ -199,13 +180,6 @@ class RuleCriteria extends CommonDBChild
     }
 
 
-    /**
-     * @since 0.84
-     *
-     * @param $field
-     * @param $values
-     * @param $options   array
-     **/
     public static function getSpecificValueToDisplay($field, $values, array $options = [])
     {
 
@@ -265,14 +239,6 @@ class RuleCriteria extends CommonDBChild
     }
 
 
-    /**
-     * @since 0.84
-     *
-     * @param $field
-     * @param $name               (default '')
-     * @param $values             (default '')
-     * @param $options      array
-     **/
     public static function getSpecificValueToSelect($field, $name = '', $values = '', array $options = [])
     {
         if (!is_array($values)) {
@@ -340,14 +306,15 @@ class RuleCriteria extends CommonDBChild
 
 
     /**
-     * Get all criterias for a given rule
+     * Get all criteria for a given rule
      *
-     * @param $rules_id the rule ID
+     * @param integer $rules_id the rule ID
      *
-     * @return an array of RuleCriteria objects
+     * @return array of RuleCriteria objects
      **/
     public function getRuleCriterias($rules_id)
     {
+        /** @var \DBmysql $DB */
         global $DB;
 
         $rules_list = [];
@@ -367,12 +334,12 @@ class RuleCriteria extends CommonDBChild
     /**
      * Try to match a defined rule
      *
-     * @param &$criterion         RuleCriteria object
-     * @param $field              the field to match
-     * @param &$criterias_results
-     * @param &$regex_result
+     * @param RuleCriteria &$criterion         RuleCriteria object
+     * @param string       $field              the field to match
+     * @param array        &$criterias_results
+     * @param array        &$regex_result
      *
-     * @return true if the field match the rule, false if it doesn't match
+     * @return boolean
      **/
     public static function match(RuleCriteria &$criterion, $field, &$criterias_results, &$regex_result)
     {
@@ -381,6 +348,11 @@ class RuleCriteria extends CommonDBChild
         $pattern   = $criterion->fields['pattern'];
         $criteria  = $criterion->fields['criteria'];
 
+        // Permit use of `<`, `&` and `>` and prevent issues with quotes.
+        $raw_pattern = $pattern;
+        $pattern     = Sanitizer::unsanitize($pattern);
+        $field       = Sanitizer::unsanitize($field);
+
        //If pattern is wildcard, don't check the rule and return true
        //or if the condition is "already present in GLPI" : will be processed later
         if (
@@ -404,7 +376,7 @@ class RuleCriteria extends CommonDBChild
                    // Special case (used only by UNIQUE_PROFILE, for now)
                    // $pattern is an ID
                     if (in_array($pattern, $field)) {
-                        $criterias_results[$criteria] = $pattern;
+                        $criterias_results[$criteria] = $raw_pattern;
                         return true;
                     }
                 } else {
@@ -412,7 +384,7 @@ class RuleCriteria extends CommonDBChild
                     $field                        = Toolbox::strtolower($field);
                     $pattern                      = Toolbox::strtolower($pattern);
                     if ($field == $pattern) {
-                        $criterias_results[$criteria] = $pattern;
+                        $criterias_results[$criteria] = $raw_pattern;
                         return true;
                     }
                 }
@@ -423,14 +395,14 @@ class RuleCriteria extends CommonDBChild
                 $field   = Toolbox::strtolower($field);
                 $pattern = Toolbox::strtolower($pattern);
                 if ($field != $pattern) {
-                    $criterias_results[$criteria] = $pattern;
+                    $criterias_results[$criteria] = $raw_pattern;
                     return true;
                 }
                 return false;
 
             case Rule::PATTERN_UNDER:
                 $table  = getTableNameForForeignKeyField($criteria);
-                $values = getSonsOf($table, $pattern);
+                $values = Sanitizer::unsanitize(getSonsOf($table, $pattern));
                 if (isset($values[$field])) {
                     return true;
                 }
@@ -438,7 +410,7 @@ class RuleCriteria extends CommonDBChild
 
             case Rule::PATTERN_NOT_UNDER:
                 $table  = getTableNameForForeignKeyField($criteria);
-                $values = getSonsOf($table, $pattern);
+                $values = Sanitizer::unsanitize(getSonsOf($table, $pattern));
                 if (isset($values[$field])) {
                     return false;
                 }
@@ -450,7 +422,7 @@ class RuleCriteria extends CommonDBChild
                 }
 
                 if (str_ends_with(mb_strtolower($field), mb_strtolower($pattern))) {
-                    $criterias_results[$criteria] = $pattern;
+                    $criterias_results[$criteria] = $raw_pattern;
                     return true;
                 }
                 return false;
@@ -461,7 +433,7 @@ class RuleCriteria extends CommonDBChild
                 }
                 $value = mb_stripos($field, $pattern, 0, 'UTF-8');
                 if (($value !== false) && ($value == 0)) {
-                    $criterias_results[$criteria] = $pattern;
+                    $criterias_results[$criteria] = $raw_pattern;
                     return true;
                 }
                 return false;
@@ -472,7 +444,7 @@ class RuleCriteria extends CommonDBChild
                 }
                 $value = mb_stripos($field, $pattern, 0, 'UTF-8');
                 if (($value !== false) && ($value >= 0)) {
-                    $criterias_results[$criteria] = $pattern;
+                    $criterias_results[$criteria] = $raw_pattern;
                     return true;
                 }
                 return false;
@@ -483,16 +455,14 @@ class RuleCriteria extends CommonDBChild
                 }
                 $value = mb_stripos($field ?? '', $pattern, 0, 'UTF-8');
                 if ($value === false) {
-                    $criterias_results[$criteria] = $pattern;
+                    $criterias_results[$criteria] = $raw_pattern;
                     return true;
                 }
                 return false;
 
             case Rule::REGEX_MATCH:
                 $results = [];
-                // Permit use < and >
-                $pattern = Sanitizer::unsanitize($pattern);
-                $match_result = @preg_match_all($pattern . "i", $field, $results);
+                $match_result = @preg_match_all($pattern . "si", $field, $results);
                 if ($match_result === false) {
                     trigger_error(
                         sprintf('Invalid regular expression `%s`.', $pattern),
@@ -509,22 +479,20 @@ class RuleCriteria extends CommonDBChild
                         }
                     }
                     $regex_result[]               = $res;
-                    $criterias_results[$criteria] = $pattern;
+                    $criterias_results[$criteria] = $raw_pattern;
                     return true;
                 }
                 return false;
 
             case Rule::REGEX_NOT_MATCH:
-               // Permit use < and >
-                $pattern = Sanitizer::unsanitize($pattern);
-                $match_result = @preg_match($pattern . "i", $field);
+                $match_result = @preg_match($pattern . "si", $field);
                 if ($match_result === false) {
                     trigger_error(
                         sprintf('Invalid regular expression `%s`.', $pattern),
                         E_USER_WARNING
                     );
                 } elseif ($match_result === 0) {
-                    $criterias_results[$criteria] = $pattern;
+                    $criterias_results[$criteria] = $raw_pattern;
                     return true;
                 }
                 return false;
@@ -570,11 +538,11 @@ class RuleCriteria extends CommonDBChild
     /**
      * Return the condition label by giving his ID
      *
-     * @param $ID        condition's ID
-     * @param $itemtype  itemtype
-     * @param $criterion (default '')
+     * @param integer $ID        condition's ID
+     * @param string  $itemtype  itemtype
+     * @param string  $criterion (default '')
      *
-     * @return condition's label
+     * @return string condition's label
      **/
     public static function getConditionByID($ID, $itemtype, $criterion = '')
     {
@@ -588,8 +556,8 @@ class RuleCriteria extends CommonDBChild
 
 
     /**
-     * @param $itemtype  itemtype
-     * @param $criterion (default '')
+     * @param string $itemtype  itemtype
+     * @param string $criterion (default '')
      *
      * @return array of criteria
      **/
@@ -643,10 +611,10 @@ class RuleCriteria extends CommonDBChild
 
 
     /**
-     * Display a dropdown with all the criterias
+     * Display a dropdown with all the criteria
      *
-     * @param $itemtype
-     * @param $params    array
+     * @param string $itemtype
+     * @param array  $params
      **/
     public static function dropdownConditions($itemtype, $params = [])
     {
@@ -677,12 +645,15 @@ class RuleCriteria extends CommonDBChild
      *
      * @since 0.85
      *
-     * @param $ID      integer  Id of the criteria
-     * @param $options array    of possible options:
+     * @param integer $ID      Id of the criteria
+     * @param array   $options possible options:
      *     - rule Object : the rule
+     *
+     * @return boolean
      **/
     public function showForm($ID, array $options = [])
     {
+        /** @var array $CFG_GLPI */
         global $CFG_GLPI;
 
        // Yllen: you always have parent for criteria
