@@ -35,9 +35,6 @@
 
 class RuleDictionnaryComputerTypeCollection extends RuleDictionnaryDropdownCollection
 {
-   // From RuleCollection
-   //public $rule_class_name = 'RuleDictionnaryComputerType';
-
     public $item_table  = "glpi_computertypes";
     public $menu_option = "type.computer";
 
@@ -46,6 +43,6 @@ class RuleDictionnaryComputerTypeCollection extends RuleDictionnaryDropdownColle
      **/
     public function getTitle()
     {
-        return __('Dictionnary of computer types');
+        return __('Dictionary of computer types');
     }
 }
