@@ -49,7 +49,7 @@ class RuleDictionnaryPrinterCollection extends RuleCollection
      **/
     public function getTitle()
     {
-        return __('Dictionnary of printers');
+        return __('Dictionary of printers');
     }
 
 
@@ -71,6 +71,7 @@ class RuleDictionnaryPrinterCollection extends RuleCollection
 
     public function replayRulesOnExistingDB($offset = 0, $maxtime = 0, $items = [], $params = [])
     {
+        /** @var \DBmysql $DB */
         global $DB;
 
         if (isCommandLine()) {
@@ -129,7 +130,7 @@ class RuleDictionnaryPrinterCollection extends RuleCollection
                 }
             }
 
-           //Replay printer dictionnary rules
+           //Replay printer dictionary rules
             $res_rule = $this->processAllRules($input, [], []);
 
             foreach (['manufacturer', 'is_global', 'name'] as $attr) {
@@ -156,7 +157,7 @@ class RuleDictionnaryPrinterCollection extends RuleCollection
                     foreach ($print_iterator as $result) {
                         $IDs[] = $result["id"];
                     }
-                     //Replay dictionnary on all the printers
+                     //Replay dictionary on all the printers
                      $this->replayDictionnaryOnPrintersByID($IDs, $res_rule);
                 }
             }
@@ -203,7 +204,7 @@ class RuleDictionnaryPrinterCollection extends RuleCollection
 
 
     /**
-     * Replay dictionnary on several printers
+     * Replay dictionary on several printers
      *
      * @param $IDs       array of printers IDs to replay
      * @param $res_rule  array of rule results
@@ -212,6 +213,7 @@ class RuleDictionnaryPrinterCollection extends RuleCollection
      **/
     public function replayDictionnaryOnPrintersByID(array $IDs, $res_rule = [])
     {
+        /** @var \DBmysql $DB */
         global $DB;
 
         $new_printers  = [];
@@ -264,7 +266,7 @@ class RuleDictionnaryPrinterCollection extends RuleCollection
 
 
     /**
-     * Replay dictionnary on one printer
+     * Replay dictionary on one printer
      *
      * @param &$new_printers   array containing new printers already computed
      * @param $res_rule        array of rule results
