@@ -34,6 +34,8 @@
  * ---------------------------------------------------------------------
  */
 
+use Glpi\Toolbox\Sanitizer;
+
 class RuleImportAsset extends Rule
 {
     const RULE_ACTION_LINK_OR_IMPORT    = 0;
@@ -446,7 +448,12 @@ class RuleImportAsset extends Rule
 
     public function findWithGlobalCriteria($input)
     {
-        global $DB, $PLUGIN_HOOKS, $CFG_GLPI;
+        /**
+         * @var array $CFG_GLPI
+         * @var \DBmysql $DB
+         * @var array $PLUGIN_HOOKS
+         */
+        global $CFG_GLPI, $DB, $PLUGIN_HOOKS;
 
         $this->complex_criteria = [];
         $this->restrict_entity = false;
@@ -513,7 +520,7 @@ class RuleImportAsset extends Rule
                 $this->handleOneJoinPerCriteria($item, $it_criteria);
             }
 
-            $this->handleFieldsCriteria($item, $it_criteria, $input);
+            $this->handleFieldsCriteria($item, $it_criteria, Sanitizer::sanitize($input));
 
             if (isset($PLUGIN_HOOKS['use_rules'])) {
                 foreach ($PLUGIN_HOOKS['use_rules'] as $plugin => $val) {
@@ -922,11 +929,16 @@ class RuleImportAsset extends Rule
 
         if (count($this->actions)) {
             foreach ($this->actions as $action) {
-                if ($action->fields['field'] == '_ignore_import' || $action->fields["value"] == self::RULE_ACTION_DENIED) {
+                if ($action->fields["value"] == self::RULE_ACTION_DENIED) {
                     $output['action'] = self::LINK_RESULT_DENIED;
                     return $output;
                 }
 
+                if ($action->fields['field'] == '_ignore_import') {
+                    $output['action'] = self::LINK_RESULT_CREATE;
+                    return $output;
+                }
+
                 if ($action->fields['field'] != '_inventory' && $action->fields['field'] != '_fusion') {
                     if (count($this->criterias)) {
                         foreach ($this->criterias as $criterion) {
@@ -1047,6 +1059,7 @@ class RuleImportAsset extends Rule
      */
     public static function getItemTypesForRules()
     {
+        /** @var array $CFG_GLPI */
         global $CFG_GLPI;
 
         $types = [];
@@ -1093,6 +1106,7 @@ class RuleImportAsset extends Rule
      */
     public function getGlobalCriteria(): array
     {
+        /** @var array $PLUGIN_HOOKS */
         global $PLUGIN_HOOKS;
 
         $criteria = array_merge([
