@@ -148,10 +148,14 @@ class RuleImportEntity extends Rule
      **/
     public function displayAdditionalRuleCondition($condition, $criteria, $name, $value, $test = false)
     {
-        global $PLUGIN_HOOKS, $CFG_GLPI;
+        /**
+         * @var array $CFG_GLPI
+         * @var array $PLUGIN_HOOKS
+         */
+        global $CFG_GLPI, $PLUGIN_HOOKS;
 
         if ($criteria['field'] == '_source') {
-            $tab = ['GLPI' => __('GLPI')];
+            $tab = ['GLPI' => __('GLPI'), 'NATIVE_INVENTORY' => AutoUpdateSystem::getLabelFor(AutoUpdateSystem::NATIVE_INVENTORY)];
             foreach ($PLUGIN_HOOKS['import_item'] as $plug => $types) {
                 if (!Plugin::isPluginActive($plug)) {
                     continue;
@@ -192,13 +196,15 @@ class RuleImportEntity extends Rule
 
         $crit = $this->getCriteria($ID);
         if (count($crit) && $crit['field'] == '_source') {
-            if ($pattern != 'GLPI') {
+            if ($pattern == 'GLPI') {
+                $name = $pattern;
+            } elseif ($pattern == 'NATIVE_INVENTORY') {
+                $name = AutoUpdateSystem::getLabelFor(AutoUpdateSystem::NATIVE_INVENTORY);
+            } else {
                 $name = Plugin::getInfo($pattern, 'name');
                 if (empty($name)) {
                     return false;
                 }
-            } else {
-                $name = $pattern;
             }
             return $name;
         }
@@ -260,12 +266,12 @@ class RuleImportEntity extends Rule
                 'type' => 'yesno'
             ],
             'groups_id_tech' => [
-                'name' => __('Group in charge of the hardware'),
+                'name' => __('Group in charge'),
                 'type' => 'dropdown',
                 'table' => Group::getTable()
             ],
             'users_id_tech' => [
-                'name' => __('Technician in charge of the hardware'),
+                'name' => __('Technician in charge'),
                 'type' => 'dropdown_users'
             ]
         ];
