@@ -123,8 +123,9 @@ class SLM extends CommonDBTM
         return $input;
     }
 
-    public function post_updateItem($history = 1)
+    public function post_updateItem($history = true)
     {
+        /** @var \DBmysql $DB */
         global $DB;
 
         if (in_array('use_ticket_calendar', $this->updates) || in_array('calendars_id', $this->updates)) {
