@@ -86,6 +86,7 @@ class Session
      **/
     public static function init(Auth $auth)
     {
+        /** @var array $CFG_GLPI */
         global $CFG_GLPI;
 
         if ($auth->auth_succeded) {
@@ -348,9 +349,10 @@ class Session
      **/
     public static function initNavigateListItems($itemtype, $title = "", $url = null)
     {
+        /** @var int $AJAX_INCLUDE */
         global $AJAX_INCLUDE;
 
-        if (isset($AJAX_INCLUDE) && ($url === null)) {
+        if ($AJAX_INCLUDE && ($url === null)) {
             return;
         }
         if (empty($title)) {
@@ -562,6 +564,7 @@ class Session
      **/
     public static function initEntityProfiles($userID)
     {
+        /** @var \DBmysql $DB */
         global $DB;
 
         $_SESSION['glpiprofiles'] = [];
@@ -644,6 +647,7 @@ class Session
      **/
     public static function loadGroups()
     {
+        /** @var \DBmysql $DB */
         global $DB;
 
         $_SESSION["glpigroups"] = [];
@@ -688,6 +692,10 @@ class Session
      **/
     public static function loadLanguage($forcelang = '', $with_plugins = true)
     {
+        /**
+         * @var array $CFG_GLPI
+         * @var \Laminas\I18n\Translator\TranslatorInterface $TRANSLATE
+         */
         global $CFG_GLPI, $TRANSLATE;
 
         if (!isset($_SESSION["glpilanguage"])) {
@@ -783,6 +791,7 @@ class Session
      */
     public static function getPreferredLanguage(): string
     {
+        /** @var array $CFG_GLPI */
         global $CFG_GLPI;
 
        // Extract accepted languages from headers
@@ -821,6 +830,7 @@ class Session
      */
     public static function getPluralNumber()
     {
+        /** @var int $DEFAULT_PLURAL_NUMBER */
         global $DEFAULT_PLURAL_NUMBER;
 
         if (isset($_SESSION['glpipluralnumber'])) {
@@ -917,6 +927,7 @@ class Session
      **/
     public static function checkValidSessionId()
     {
+        /** @var \DBmysql $DB */
         global $DB;
 
         if (
@@ -994,6 +1005,7 @@ class Session
      **/
     public static function checkFaqAccess()
     {
+        /** @var array $CFG_GLPI */
         global $CFG_GLPI;
 
         if (!$CFG_GLPI["use_public_faq"]) {
@@ -1288,6 +1300,7 @@ class Session
      **/
     public static function haveRight($module, $right)
     {
+        /** @var \DBmysql $DB */
         global $DB;
 
         if (Session::isInventory()) {
@@ -1490,6 +1503,7 @@ class Session
      **/
     public static function getNewCSRFToken(bool $standalone = false)
     {
+        /** @var string $CURRENTCSRFTOKEN */
         global $CURRENTCSRFTOKEN;
 
         $token = $standalone ? '' : $CURRENTCSRFTOKEN;
@@ -1606,7 +1620,7 @@ class Session
         ) {
             $requested_url = (isset($_SERVER['REQUEST_URI']) ? $_SERVER['REQUEST_URI'] : 'Unknown');
             $user_id = self::getLoginUserID() ?? 'Anonymous';
-            Toolbox::logInFile('access-errors', "CSRF check failed for User ID: $user_id at $requested_url");
+            Toolbox::logInFile('access-errors', "CSRF check failed for User ID: $user_id at $requested_url\n");
             // Output JSON if requested by client
             if (strpos($_SERVER['HTTP_ACCEPT'] ?? '', 'application/json') !== false) {
                 http_response_code(403);
@@ -2011,4 +2025,15 @@ class Session
     {
         return $_SESSION['glpilanguage'] ?? null;
     }
+
+    /**
+     * Helper function to get the date stored in $_SESSION['glpi_currenttime']
+     *
+     * @return null|string
+     */
+    public static function getCurrentTime(): ?string
+    {
+        // TODO (10.1 refactoring): replace references to $_SESSION['glpi_currenttime'] by a call to this function
+        return $_SESSION['glpi_currenttime'] ?? null;
+    }
 }
