@@ -103,6 +103,7 @@ class Socket extends CommonDBChild
     public static function showNetworkPortForm($itemtype, $items_id, $networkports_id = 0, $options = [])
     {
 
+        /** @var array $CFG_GLPI */
         global $CFG_GLPI;
 
         //if form is called from an item, retrieve itemtype and items
@@ -137,7 +138,7 @@ class Socket extends CommonDBChild
             $rand_items_id =  $itemtype::dropdown(['name'                  => 'items_id',
                 'value'                 => $items_id,
                 'display_emptychoice'   => true,
-                'display_dc_position'   => true,
+                'display_dc_position'   => in_array($itemtype, $CFG_GLPI['rackable_types']),
                 'rand' => $rand_items_id
             ]);
         }
@@ -261,6 +262,7 @@ class Socket extends CommonDBChild
      **/
     public static function getSocketLinkTypes()
     {
+        /** @var array $CFG_GLPI */
         global $CFG_GLPI;
         $values = [];
         foreach ($CFG_GLPI["socket_types"] as $itemtype) {
@@ -277,6 +279,7 @@ class Socket extends CommonDBChild
      **/
     public static function getSocketAlreadyLinked(string $itemtype, int $items_id): array
     {
+        /** @var \DBmysql $DB */
         global $DB;
         $already_use = [];
         $sub_query = [];
@@ -598,6 +601,7 @@ class Socket extends CommonDBChild
      **/
     public function findID(array &$input)
     {
+        /** @var \DBmysql $DB */
         global $DB;
 
         if (!empty($input["name"])) {
@@ -633,13 +637,14 @@ class Socket extends CommonDBChild
         $this->cleanIfStealNetworkPort();
     }
 
-    public function post_updateItem($history = 1)
+    public function post_updateItem($history = true)
     {
         $this->cleanIfStealNetworkPort();
     }
 
     public function cleanIfStealNetworkPort()
     {
+        /** @var \DBmysql $DB */
         global $DB;
        //find other socket with same networkport and reset it
         if ($this->fields['networkports_id'] > 0) {
@@ -673,6 +678,7 @@ class Socket extends CommonDBChild
 
     public function getTabNameForItem(CommonGLPI $item, $withtemplate = 0)
     {
+        /** @var array $CFG_GLPI */
         global $CFG_GLPI;
         if (!$withtemplate) {
             $nb = 0;
@@ -705,6 +711,7 @@ class Socket extends CommonDBChild
 
     public static function displayTabContentForItem(CommonGLPI $item, $tabnum = 1, $withtemplate = 0)
     {
+        /** @var array $CFG_GLPI */
         global $CFG_GLPI;
         if ($item->getType() == 'Location') {
             self::showForLocation($item);
@@ -725,6 +732,7 @@ class Socket extends CommonDBChild
     public static function showListForItem($item)
     {
 
+        /** @var \DBmysql $DB */
         global $DB;
 
         $canedit = self::canUpdate();
@@ -892,6 +900,7 @@ class Socket extends CommonDBChild
      **/
     public static function showForLocation($item)
     {
+        /** @var \DBmysql $DB */
         global $DB;
 
         $ID       = $item->getField('id');
