@@ -56,7 +56,13 @@ class SoftwareLicense extends CommonTreeDropdown
 
     public function getCloneRelations(): array
     {
-        return [];
+        return [
+            Infocom::class,
+            Contract_Item::class,
+            Document_Item::class,
+            KnowbaseItem_Item::class,
+            Notepad::class
+        ];
     }
 
     public static function getTypeName($nb = 0)
@@ -186,7 +192,6 @@ class SoftwareLicense extends CommonTreeDropdown
 
         $this->deleteChildrenAndRelationsFromDb(
             [
-                Certificate_Item::class,
                 Item_SoftwareLicense::class,
             ]
         );
@@ -220,7 +225,7 @@ class SoftwareLicense extends CommonTreeDropdown
      * @since 0.85
      * @see CommonDBTM::post_updateItem()
      **/
-    public function post_updateItem($history = 1)
+    public function post_updateItem($history = true)
     {
 
         if (in_array("is_valid", $this->updates)) {
@@ -545,6 +550,27 @@ class SoftwareLicense extends CommonTreeDropdown
             'datatype'           => 'string',
         ];
 
+        $tab[] = [
+            'id'                 => '163',
+            'table'              => 'glpi_items_softwarelicenses',
+            'field'              => 'id',
+            'name'               => _x('quantity', 'Number of installations'),
+            'forcegroupby'       => true,
+            'usehaving'          => true,
+            'datatype'           => 'count',
+            'massiveaction'      => false,
+            'joinparams'         => [
+                'jointype'   => 'child',
+                'beforejoin' => [
+                    'table'      => 'glpi_softwarelicenses',
+                    'joinparams' => ['jointype' => 'child'],
+                ],
+                'condition'  => [
+                    'NEWTABLE.is_deleted'          => 0
+                ]
+            ]
+        ];
+
        // add objectlock search options
         $tab = array_merge($tab, ObjectLock::rawSearchOptionsToAdd(get_class($this)));
         $tab = array_merge($tab, Notepad::rawSearchOptionsToAdd());
@@ -702,7 +728,11 @@ class SoftwareLicense extends CommonTreeDropdown
      **/
     public static function cronSoftware($task = null)
     {
-        global $DB, $CFG_GLPI;
+        /**
+         * @var array $CFG_GLPI
+         * @var \DBmysql $DB
+         */
+        global $CFG_GLPI, $DB;
 
         $cron_status = 1;
 
@@ -824,6 +854,7 @@ class SoftwareLicense extends CommonTreeDropdown
      */
     public static function countForVersion($softwareversions_id, $entity = '')
     {
+        /** @var \DBmysql $DB */
         global $DB;
 
         $result = $DB->request([
@@ -847,6 +878,7 @@ class SoftwareLicense extends CommonTreeDropdown
      **/
     public static function countForSoftware($softwares_id)
     {
+        /** @var \DBmysql $DB */
         global $DB;
 
         $iterator = $DB->request([
@@ -901,6 +933,7 @@ class SoftwareLicense extends CommonTreeDropdown
      **/
     public static function showForSoftware(Software $software)
     {
+        /** @var \DBmysql $DB */
         global $DB;
 
         $softwares_id  = $software->getField('id');
@@ -1173,7 +1206,7 @@ class SoftwareLicense extends CommonTreeDropdown
     /**
      * Get fields to display in the unicity error message
      *
-     * @return an array which contains field => label
+     * @return array
      */
     public function getUnicityFieldsToDisplayInErrorMessage()
     {
@@ -1242,6 +1275,7 @@ class SoftwareLicense extends CommonTreeDropdown
 
     public static function getSonsOf($item)
     {
+        /** @var \DBmysql $DB */
         global $DB;
         $entity_assign = $item->isEntityAssign();
         $nb            = 0;
