@@ -90,6 +90,7 @@ class State extends CommonTreeDropdown
      **/
     public static function dropdownBehaviour($name, $lib = "", $value = 0)
     {
+        /** @var \DBmysql $DB */
         global $DB;
 
         $elements = ["0" => __('Keep status')];
@@ -113,7 +114,11 @@ class State extends CommonTreeDropdown
 
     public static function showSummary()
     {
-        global $DB, $CFG_GLPI;
+        /**
+         * @var array $CFG_GLPI
+         * @var \DBmysql $DB
+         */
+        global $CFG_GLPI, $DB;
 
         $state_type = $CFG_GLPI["state_types"];
         $states     = [];
@@ -150,6 +155,8 @@ class State extends CommonTreeDropdown
         }
 
         if (count($states)) {
+            $total = [];
+
            // Produce headline
             echo "<div class='center'><table class='tab_cadrehov'><tr>";
 
@@ -274,7 +281,7 @@ class State extends CommonTreeDropdown
         }
         if (!$this->isUnique($input)) {
             Session::addMessageAfterRedirect(
-                sprintf(__('%1$s must be unique!'), $this->getType(1)),
+                sprintf(__('%1$s must be unique!'), $this->getTypeName(1)),
                 false,
                 ERROR
             );
@@ -515,7 +522,7 @@ class State extends CommonTreeDropdown
     {
         if (!$this->isUnique($input)) {
             Session::addMessageAfterRedirect(
-                sprintf(__('%1$s must be unique per level!'), $this->getType(1)),
+                sprintf(__('%1$s must be unique per level!'), $this->getTypeName(1)),
                 false,
                 ERROR
             );
@@ -534,6 +541,7 @@ class State extends CommonTreeDropdown
      */
     public function isUnique($input)
     {
+        /** @var \DBmysql $DB */
         global $DB;
 
         $unicity_fields = ['states_id', 'name'];
@@ -576,6 +584,7 @@ class State extends CommonTreeDropdown
      */
     protected function getvisibilityFields(): array
     {
+        /** @var array $CFG_GLPI */
         global $CFG_GLPI;
         $fields = [];
         foreach ($CFG_GLPI['state_types'] as $type) {
