@@ -45,7 +45,7 @@ class Unmanaged extends CommonDBTM
 
    // From CommonDBTM
     public $dohistory                   = true;
-    public static $rightname                   = 'config';
+    public static $rightname                   = 'unmanaged';
 
     public static function getTypeName($nb = 0)
     {
@@ -58,6 +58,7 @@ class Unmanaged extends CommonDBTM
         $ong = [];
         $this->addDefaultFormTab($ong)
          ->addStandardTab('NetworkPort', $ong, $options)
+         ->addStandardTab('Domain_Item', $ong, $options)
          ->addStandardTab('Lock', $ong, $options)
          ->addStandardTab('RuleMatchedLog', $ong, $options)
          ->addStandardTab('Log', $ong, $options);
@@ -66,7 +67,7 @@ class Unmanaged extends CommonDBTM
 
 
     /**
-     * Print the unmanagemed form
+     * Print the unmanaged form
      *
      * @param $ID integer ID of the item
      * @param $options array
@@ -144,15 +145,6 @@ class Unmanaged extends CommonDBTM
             'datatype'  => 'dropdown',
         ];
 
-        $tab[] = [
-            'id'        => '9',
-            'table'     => 'glpi_domains',
-            'field'     => 'name',
-            'linkfield' => 'domains_id',
-            'name'      => Domain::getTypeName(1),
-            'datatype'  => 'dropdown',
-        ];
-
         $tab[] = [
             'id'        => '10',
             'table'     => $this->getTable(),
@@ -192,19 +184,18 @@ class Unmanaged extends CommonDBTM
             'name'         => __('IP'),
         ];
 
+        $tab[] = [
+            'id'                 => '31',
+            'table'              => 'glpi_states',
+            'field'              => 'completename',
+            'name'               => __('Status'),
+            'datatype'           => 'dropdown',
+            'condition'          => ['is_visible_unmanaged' => 1]
+        ];
+
         return $tab;
     }
 
-    public function cleanDBonPurge()
-    {
-
-        $this->deleteChildrenAndRelationsFromDb(
-            [
-                NetworkPort::class
-            ]
-        );
-    }
-
     public static function getIcon()
     {
         return "ti ti-question-mark";
@@ -222,7 +213,7 @@ class Unmanaged extends CommonDBTM
     public static function getMassiveActionsForItemtype(
         array &$actions,
         $itemtype,
-        $is_deleted = 0,
+        $is_deleted = false,
         CommonDBTM $checkitem = null
     ) {
         if (self::canUpdate()) {
@@ -232,6 +223,7 @@ class Unmanaged extends CommonDBTM
 
     public static function showMassiveActionsSubForm(MassiveAction $ma)
     {
+        /** @var array $CFG_GLPI */
         global $CFG_GLPI;
         switch ($ma->getAction()) {
             case 'convert':
@@ -249,6 +241,7 @@ class Unmanaged extends CommonDBTM
         CommonDBTM $item,
         array $ids
     ) {
+        /** @var array $CFG_GLPI */
         global $CFG_GLPI;
         switch ($ma->getAction()) {
             case 'convert':
@@ -270,6 +263,7 @@ class Unmanaged extends CommonDBTM
      */
     public function convert(int $items_id, string $itemtype = null)
     {
+        /** @var \DBmysql $DB */
         global $DB;
 
         $this->getFromDB($items_id);
@@ -347,13 +341,8 @@ class Unmanaged extends CommonDBTM
         $this->deleteFromDB(1);
     }
 
-    public static function canDelete()
+    public function useDeletedToLockIfDynamic()
     {
-        return static::canUpdate();
-    }
-
-    public static function canPurge()
-    {
-        return static::canUpdate();
+        return false;
     }
 }
