@@ -171,6 +171,7 @@ class Update
      */
     final public function isUpdatedSchemaConsistent(): bool
     {
+        /** @var \DBmysql $DB */
         global $DB;
 
         $checker = new DatabaseSchemaIntegrityChecker($DB, false, true, true, true, true, true);
@@ -214,7 +215,7 @@ class Update
             // e.g. with `NO_ZERO_DATE` flag `ALTER TABLE` operations fails when a row contains a `0000-00-00 00:00:00` datetime value.
             // Unitary removal of these flags is not pôssible as MySQL 8.0 triggers warning if
             // `STRICT_{ALL|TRANS}_TABLES,NO_ZERO_IN_DATE,NO_ZERO_DATE,ERROR_FOR_DIVISION_BY_ZERO` are not used all together.
-            $sql_mode = $DB->query(sprintf('SELECT @@sql_mode as %s', $DB->quoteName('sql_mode')))->fetch_assoc()['sql_mode'] ?? '';
+            $sql_mode = $DB->doQuery(sprintf('SELECT @@sql_mode as %s', $DB->quoteName('sql_mode')))->fetch_assoc()['sql_mode'] ?? '';
             $sql_mode_flags = array_filter(
                 explode(',', $sql_mode),
                 function (string $flag) {
@@ -230,7 +231,7 @@ class Update
                     );
                 }
             );
-            $DB->query(sprintf('SET SESSION sql_mode = %s', $DB->quote(implode(',', $sql_mode_flags))));
+            $DB->doQuery(sprintf('SET SESSION sql_mode = %s', $DB->quote(implode(',', $sql_mode_flags))));
         }
 
        // To prevent problem of execution time
@@ -436,6 +437,7 @@ class Update
      */
     public static function isDbUpToDate(): bool
     {
+        /** @var array $CFG_GLPI */
         global $CFG_GLPI;
 
         if (!array_key_exists('dbversion', $CFG_GLPI)) {
